#!/bin/bash
set -evx
#
# This script computes the ocean heat content from the NEMO output
#
# Written by Hui Du (based on "/gpfs/projects/ecm86/common/cdftools/scripts/cdfheatc.sh" on BSC)
#
# Created:   October 1, 2010
#            Hui Du (based on "/gpfs/projects/ecm86/common/cdftools/scripts/cdfheatc.sh" on BSC)
# Modified:  October 22, 2010
#            F. Doblas-Reyes
#
########################
### General Settings ###
########################

#
# The data directory should follow the structure ${DATADIR}/${EXPID}/${year}/${member}/
# where ${DATADIR} is the directory where the model output is available from
# $EXPID is the experiment ID
# $year is the starting date of the simulation
# $member is the ensemble member
#

############################ Beginning of user modification#####################
#
# common part 
#
DATA=model # here set model or obs
EXPID=NEMOVAR_COMBINE
EXPID=$1
SDATE=$2
MEMBER=$3
KMIN=$4
KMAX=$5
basin=$6
mxloption=$7
case $EXPID in 
  'NEMOVAR_COMBINE'|'NEMOVAR_S4')
  DATA=obs
  ;;
esac

DATADIR_OBS=/cfunas/exp/ECMWF/${EXPID}/outputs/opa${MEMBER}
DATADIR_MODEL=/cfunas/exp/ecearth/${EXPID}/${SDATE}/fc${MEMBER}/outputs
CON_FILES=/cfu/pub/scripts/CDFTOOLS/constant_files
TMPDIR=/scratch/${USER}/heatc_$EXPID
GRID=grid_T
#
## Heat content parameters 
#
lonmin=0
lonmax=0
latmin=10
latmax=65
kmin=$KMIN
kmax=$KMAX 
#kmin=0
#kmax=0  

function no_use(){
case $mxloption in 
 '0')
  exec=/opt/cdftools/bin/cdfheatc
  kmin=${KMIN}
  kmax=${KMAX}
  para="0 0 0 0 $kmin $kmax" 

  if [[ ${kmin} -eq 1 ]] ; then
   kmin=0
  else
   kmin=`cat ${CON_FILES}/depth.txt |head -${kmin} |tail -1 | awk '{print $2}' | awk '{printf "%.0f",$1}'`;
  fi
   kmax=`cat ${CON_FILES}/depth.txt |head -${kmax} |tail -1 | awk '{print $2}' | awk '{printf "%.0f",$1}'`;
  suffix=${kmin}-${kmax}

  ;;
 '1')
 exec=/home/huidu/download/CDFTOOLS_2.1/cdfheatc-cfu  
 para="$basin $mxloption $lonmin $lonmax $latmin $latmax $kmin $kmax"
 suffix=mxl_atl_10N65N
 ;;
 '-1')
 exec=/home/huidu/download/CDFTOOLS_2.1/cdfheatc-cfu  
 para="$basin $mxloption $lonmin $lonmax $latmin $latmax $kmin $kmax"
 suffix=nonmxl_atl_10N65N
 ;;

esac
}


case $basin in 
 'atl'|'ind'|'pac')
 exec=/home/huidu/download/CDFTOOLS_2.1/cdfheatc-cfu
 para="$basin $mxloption $lonmin $lonmax $latmin $latmax $kmin $kmax"
  if [[ ${kmin} -eq 1 ]] ; then
   kmin=0
  else
   kmin=`cat ${CON_FILES}/depth.txt |head -${kmin} |tail -1 | awk '{print $2}' | awk '{printf "%.0f",$1}'`;
  fi
  kmax=`cat ${CON_FILES}/depth.txt |head -${kmax} |tail -1 | awk '{print $2}' | awk '{printf "%.0f",$1}'`;
  suffix=${basin}_${latmin}N${latmax}N_${kmin}-${kmax}
  case $mxloption in
   1)
   suffix=mxl_${basin}_${latmin}N${latmax}N  
   ;;
   -1)
   suffix=nonmxl_${basin}_${latmin}N${latmax}N
   ;;
  esac
 ;;
 'all')
  exec=/opt/cdftools/bin/cdfheatc
  para="0 0 0 0 $kmin $kmax" 
  if [[ ${kmin} -eq 1 ]] ; then
   kmin=0
  else
   kmin=`cat ${CON_FILES}/depth.txt |head -${kmin} |tail -1 | awk '{print $2}' | awk '{printf "%.0f",$1}'`;
  fi
   kmax=`cat ${CON_FILES}/depth.txt |head -${kmax} |tail -1 | awk '{print $2}' | awk '{printf "%.0f",$1}'`;
  suffix=${kmin}-${kmax}
  ;;
 
esac
## model part 
#
SAVEDIR_MODEL=/cfu/data/diagnostics/ref/heatc/${EXPID}
SAVEDIR_MODEL=/cfunas/diagnostics/postprocessed/heatc/${EXPID}

#
# nemovar part
#
SAVEDIR_OBS=/cfunas/diagnostics/postprocessed/heatc/${EXPID}
YY1=1957
YY2=2009
YYINT=1
case ${EXPID} in 
 NEMOVAR_S4)
 YY2=2011
 ;;
esac

############################ End of user modification #########################
rm -rf $TMPDIR
mkdir -p $TMPDIR
cd $TMPDIR
#
# obtain constant files 
#
cp ${CON_FILES}/depth.txt .
ln -sf ${CON_FILES}/mask.nc .
ln -sf ${CON_FILES}/mesh_hgr.nc .
ln -sf ${CON_FILES}/mesh_zgr.nc .
ln -sf ${CON_FILES}/new_maskglo.nc .
cp ${CON_FILES}/heatc.nc toto.nc # heatc.nc is a file that contains a template for the ohc NetCDF output
prefix=heatc
#
##
#

case $DATA in  # for computing heat content of model
model) 

mkdir -p ${SAVEDIR_MODEL}
 echo "******************** Start fc${member} **********************"


#
# File retrieval and variable selection
#

#
## get extension of a file
#
function get_ext(){
file=$1
echo ${file##*.}
}


year=${SDATE}
member=${MEMBER}
DATADIR=${DATADIR_MODEL}
###
file=`ls ${DATADIR}|head -1`
extension=`get_ext $file`
merged=${EXPID}_${SDATE}_fc${member}_ORCA1
case $extension in
 tar)
 cp ${DATADIR}/MMO_${EXPID}*.tar ./
 files=`ls MMO_${EXPID}*.tar`
 for file in $files; do
  file1=`tar tf $file | grep ${GRID}`
  tar xvf $file ${file1}; rm $file
  gunzip ${file1}
  file2=`basename $file1 .gz`  
 done
 ;;
 gz)
 cp ${DATADIR}/*${GRID}.*.gz ./
 gunzip *.gz
 files=`ls *${GRID}*.nc`
 ;;
 nc)
 cp ${DATADIR}/*${GRID}.nc ./
 files=`ls *${GRID}*.nc`
 ;;
esac

rm -f ${merged}
cdo mergetime *${GRID}.nc ${merged}.nc; rm *${GRID}.nc
chmod 775 ${EXPID}*.nc

#
# Calculation of the ohc
#
output=${prefix}_${merged}_${suffix}
cp ${CON_FILES}/heatc.nc toto.nc # heatc.nc is a file that contains a template for the ohc NetCDF output
ntime=`cdo ntime ${merged}.nc`;
rm -f output.txt
for ((t=1;t<=$ntime;t++)); do
cdo seltimestep,$t ${merged}.nc tmp.nc
rm -f mxl.nc; cdfmxl tmp.nc # to generate mix layer file for compute heat content for mix layer
${exec} tmp.nc $para > tmp.log; rm tmp.nc
thc=`cat tmp.log | grep "Total Heat content"|grep -v volume | awk '{print $5}'`;
uhc=`cat tmp.log | grep "Total Heat content/volume" | awk '{print $5}'`;
echo $t $thc $uhc >> ${output}.txt
ncap2 -h -O -s "thc()=$thc;uhc()=$uhc" toto.nc toto.nc
if [[ $t = 1 ]] ; then
cp toto.nc ${output}.nc
else
ncrcat -h -O ${output}.nc toto.nc ${output}.nc
fi
done
ncks -h -O -v time ${merged}.nc -o time.nc
ncks -h -A time.nc ${output}.nc
#
# Modify headers
#
thc_min=`cat ${output}.txt | awk '{print $2}' | sort -n | head -1`;
thc_max=`cat ${output}.txt | awk '{print $2}' | sort -n | tail -n 1`;
ncatted -h -a valid_min,thc,m,f,$thc_min ${output}.nc
ncatted -h -a valid_max,thc,m,f,$thc_max ${output}.nc
#
uhc_min=`cat ${output}.txt | awk '{print $3}' | sort -n | head -1`;
uhc_max=`cat ${output}.txt | awk '{print $3}' | sort -n | tail -n 1`;
ncatted -h -a valid_min,uhc,m,f,$uhc_min ${output}.nc
ncatted -h -a valid_max,uhc,m,f,$uhc_max ${output}.nc
#  
units=`ncdump -c ${merged}.nc | grep "time:units" | cut -d '"' -f2`;
ncatted -h -a units,time,m,c,"$units" ${output}.nc
ncatted -h -a time,time,d,, ${output}.nc
#
rm -f MMO_${EXPID}_${year}_${member}_*
rm -f ORCA1_MM_*
rm -f ${merged}.nc
#
        echo "******************** END $SDATE member$member  *********************"
#
chmod 775 heatc*.nc
mv heatc*.nc ${SAVEDIR_MODEL} 
cd ..
rm -r ${TMPDIR}
date
;;

obs)   # case conditions 

mkdir -p ${SAVEDIR_OBS}

##########################
mem=${MEMBER}

t=1
output=${prefix}_opa${mem}_${suffix}


#
echo "******************** opa$member *********************"
#  
yy=$YY1

while [[ $yy -le $YY2 ]]; do

cp ${DATADIR_OBS}/*${yy}*${GRID}*.gz .

for file in `ls *.gz`; do #loop for gz files
gunzip -q ${file}
done # loop for gz files


for file in `ls *${GRID}*.nc`; do # loop for nc files
  date=`ls ${file}|cut -f3 -d"_"|cut -c1-6`
  rm -f mxl.nc ; cdfmxl ${file}
  ${exec} ${file} $para > tmp.log
  thc=`cat tmp.log | grep "Total Heat content"|grep -v volume | awk '{print $5}'`;
  uhc=`cat tmp.log | grep "Total Heat content/volume" | awk '{print $5}'`;
  echo $date $thc $uhc >>${output}.txt

 ncap2 -h -s "thc()=$thc;uhc()=$uhc" toto.nc toto2.nc

 if [[ $t = 1 ]] ; then
 mv toto2.nc ${output}.nc ; t=$((t+1))
 else
 mv ${output}.nc vtmp.nc
 ncrcat -h vtmp.nc toto2.nc ${output}.nc;/bin/rm toto2.nc
 fi



  rm -f ${file} tmp.log *tmp 

done #loop for nc files


yy=$((yy+YYINT))

done #loop for years



  thc_min=`cat ${output}.txt | awk '{print $2}' | sort -n | head -1`;
  thc_max=`cat ${output}.txt | awk '{print $2}' | sort -n | tail -n 1`;
  uhc_min=`cat ${output}.txt | awk '{print $3}' | sort -n | head -1`;
  uhc_max=`cat ${output}.txt | awk '{print $3}' | sort -n | tail -n 1`;

  ncatted -h -a valid_min,thc,m,f,$thc_min ${output}.nc
  ncatted -h -a valid_max,thc,m,f,$thc_max ${output}.nc

  ncatted -h -a valid_min,thc,m,f,$uhc_min ${output}.nc
  ncatted -h -a valid_max,thc,m,f,$uhc_max ${output}.nc

  /bin/rm -rf fill*
  /bin/rm -rf tmp*

############ Begin of fix time ###############


tunit=h  #set unit of time


date2stamp () {
    date --utc --date "$1" +%s
}

stamp2date (){
    date --utc --date "$sdate $1 sec" "+%Y-%m-%d %T"
}


dateDiff (){
    case $1 in
        -s)   sec=1; timeunit=seconds;     shift;;
        -m)   sec=60;timeunit=minutes;     shift;;
        -h)   sec=3600; timeunit=hours;  shift;;
        -d)   sec=86400; timeunit=days; shift;;
        *)    sec=86400; timeunit=seconds;
    esac
    dte1=$(date2stamp $1)
    dte2=$(date2stamp $2)
    diffSec=$((dte2-dte1))
    if ((diffSec < 0)); then abs=-1; else abs=1; fi
    echo $((diffSec/sec*abs))
    value=$((diffSec/sec*abs))
 #   return $value
}



sdate=`head -1 ${output}.txt | cut -f1 -d" "`
syy=`echo $sdate|cut -c1-4`
smm=`echo $sdate|cut -c5-6`
ds=${syy}-${smm}-01
#ncatted -h -a units,time,m,c,"${timeunit} since ${syy}-${smm}-01 00:00:00" ${output}.nc
ncatted -h -a units,time,m,c,"hours since ${syy}-${smm}-01 00:00:00" ${output}.nc


# add time information to the output file

n=`wc -l ${output}.txt | awk '{print $1}'`

for ((i=1;i<=$n;i++))
#for i in $(seq 8 1 $n)
 do
 yy=`head -$i ${output}.txt | tail -1|awk '{print $1}'|cut -c1-4`
 mm=`head -$i ${output}.txt | tail -1|awk '{print $1}'|cut -c5-6`
 echo "duhui"
 dateDiff -$tunit $ds $yy-$mm-01
 dt=$value
 echo "duhui dt" $dt
 echo $dt
# ncap2 -h -O -s "time($((i-1)))=$dt" ${output}.nc ${output}.nc
 ncap2 -h -O -s "time($((i-1)))=$dt" ${output}.nc toto.nc; rm ${output}.nc; mv toto.nc ${output}.nc
done



############ End of fix time ##############

 chmod 775 ${output}.*
 mv ${output}.* $SAVEDIR_OBS


/bin/rm -rf $TMPDIR

 echo
 echo
 echo "******************** END  *********************"

 ;; #case conditions

esac

rm -rf $TMPDIR
