#!/bin/bash
set -evx
#
# This script computes the ocean heat content from the NEMO output
#
# Written by Hui Du (based on "/gpfs/projects/ecm86/common/cdftools/scripts/cdfheatc.sh" on BSC)
#
# Created:   October 1, 2010
#            Hui Du (based on "/gpfs/projects/ecm86/common/cdftools/scripts/cdfheatc.sh" on BSC)
# Modified:  October 22, 2010
#            F. Doblas-Reyes
#
########################
### General Settings ###
########################
EXPID=$1 # experiment ID
SDATE=$2
#YEAR_LST=( 19601101 19651101 19701101 19751101 19801101 19851101 19901101 19951101 20001101 20051101 )
MEMBER=$3
DATADIR=/cfunas/exp/ecearth
GRID=icemod
#
# The data directory should follow the structure ${DATADIR}/${EXPID}/${SDATE}/${member}/
# where ${DATADIR} is the directory where the model output is available from
# $EXPID is the experiment ID
# $SDATE is the starting date of the simulation
# $member is the ensemble member
#
TMPDIR=/scratch/${USER}/ice_$EXPID
SAVEDIR=/cfunas/diagnostics/postprocessed/ice/${EXPID}
CON_FILES=/cfu/pub/scripts/CDFTOOLS/constant_files
PREFIX=ice
PATH=${PATH}:/share/apps/cdftools-2.1/intel11/bin:/share/apps/cdo-1.4.5.1/intel11/bin/:/share/apps/nco-3.9.9/intel11/bin/:/share/apps/ferret/bin/:/share/apps/netcdf-3.6.0-p1/intel10/bin/
#
# Create setup
#
mkdir -p ${SAVEDIR}
rm -rf $TMPDIR
mkdir -p $TMPDIR
cd $TMPDIR

ln -sf ${CON_FILES}/mask.nc .
ln -sf ${CON_FILES}/mesh_hgr.nc .

#
## get extension of a file
#
function get_ext(){
file=$1
echo ${file##*.}
}

#
# File retrieval and variable selection
#
member=$MEMBER

source_dir=${DATADIR}/${EXPID}/${SDATE}/fc${member}/outputs
file=`ls ${DATADIR}/${EXPID}/${SDATE}/fc${member}/outputs|head -1`
extension=`get_ext $file`
merged=${EXPID}_${SDATE}_fc${member}_ORCA1
case $extension in
 tar)
 files=`find ${source_dir} -name MMO*${EXPID}_${SDATE}_fc${member}_*.${extension}`
 for file in $files; do
 file1=`tar tf $file | grep ${GRID}`
 tar xvf $file ${file1}
 gunzip ${file1}
 file2=`basename $file1 .gz`  
 done
 rm -f ${merged}
 cdo mergetime ORCA1_MM_*_${GRID}.nc ${merged}.nc
 chmod 777 ${EXPID}*.nc
 ;;
 gz)
 cp ${source_dir}/*${GRID}.*.gz ./
 gunzip *.gz
 rm -f ${merged}
 cdo mergetime *${GRID}.nc ${merged}.nc; rm *${GRID}.nc
 chmod 777 ${EXPID}*.nc
 ;;
 nc)
 cp ${source_dir}/*${GRID}.nc ./
 rm -f ${merged}
 cdo mergetime *${GRID}.nc ${merged}.nc; rm *${GRID}.nc
 chmod 777 ${EXPID}*.nc
 ;;
esac


#
# Calculation of the ohc
#
        output=${PREFIX}_${merged}
        cp ${CON_FILES}/ice_template.nc toto_N.nc # heatc.nc is a file that contains a template for the ohc NetCDF output
        cp ${CON_FILES}/ice_template.nc toto_S.nc 
        ntime=`cdo ntime ${merged}.nc`;
        for t in $(seq 1 1 $ntime); do
            rm -f tmp.nc ice.txt
            cdo seltimestep,$t ${merged}.nc tmp.nc
            cdficediags tmp.nc>ice.txt  
            for d in N S;do
  	    output=${PREFIX}_${merged}
            sia=`grep ${d}Area ice.txt |awk '{print $4}'` 
	    echo $sia
            sie=`grep ${d}Extend ice.txt|awk '{print $4}'`
	    echo ${sia} ${sie}>> ice_${d}.txt 
            ncap2 -h -O -s "sia()=$sia;sie()=$sie" toto_${d}.nc toto_${d}.nc
            if [[ $t = 1 ]] ; then
               cp toto_${d}.nc ${output}_${d}.nc
            else
               ncrcat -h -O ${output}_${d}.nc toto_${d}.nc ${output}_${d}.nc
            fi
            done
        done
        ncks -h -O -v time ${merged}.nc -o time.nc
        ncks -h -A time.nc ${output}_N.nc
        ncks -h -A time.nc ${output}_S.nc
#
# Modify headers
#

      for D in N S; do
        sia_min=`cat ice_${D}.txt | awk '{print $1}' | sort -n | head -1`;
        sia_max=`cat ice_${D}.txt | awk '{print $1}' | sort -n | tail -n 1`;
        ncatted -h -a valid_min,sia,m,f,$sia_min ${output}_${D}.nc
        ncatted -h -a valid_max,sia,m,f,$sia_max ${output}_${D}.nc
#
        sie_min=`cat ice_${D}.txt | awk '{print $2}' | sort -n | head -1`;
        sie_max=`cat ice_${D}.txt | awk '{print $2}' | sort -n | tail -n 1`;
        ncatted -h -a valid_min,sie,m,f,$sie_min ${output}_${D}.nc
        ncatted -h -a valid_max,sie,m,f,$sie_max ${output}_${D}.nc
#  
        units=`ncdump -c time.nc | grep "time:units" | cut -d '"' -f2`;
        ncatted -h -a units,time,m,c,"$units" ${output}_${D}.nc
        ncatted -h -a time,time,d,, ${output}_${D}.nc
#
        rm -f MMO_${EXPID}_${SDATE}_${member}_*
        rm -f ORCA1_MM_*
        rm -f ${merged}.nc

      done
#
#
mv ice*.nc ${SAVEDIR}; #mv ice*.txt ${SAVEDIR}
cd ..
rm -rf ${TMPDIR}
date
