#!/bin/bash
#
# This script is to compute area averaged AMOC from the NEMO output
#
# Written by Hui Du 
#
# Created:   May 25, 2011
#

set -exv

#
## General Settings ###
#
#BASIN=atl  # atl, pac, ind
#LATMIN=30.  #degree
#LATMAX=40.  #degree
#DEPMIN=-2000. #meters
#DEPMAX=-1000. # meters

EXPID=$1  # experiment ID
SDATE=$2
MEMBER=$3
LATMIN=$4  #degree
LATMAX=$5  #degree
DEPMIN=$6 #meters
DEPMAX=$7 # meters
suffix=$8


# please modify the following suffix based LATMIN,LATMAX,DEPMIN and DEPMAX
#suffix=ORCA1_30N40N_1-2km

#
## End of general Settings #####
#

GRID=grid_V
DATA=model  #obs/model

SAVEDIR="/cfunas/diagnostics/postprocessed/moc/${EXPID}"
DATADIR="/cfunas/diagnostics/postprocessed/moc/${EXPID}"


case $EXPID in 
  NEMOVAR_COMBINE)
  DATA=obs
  SAVEDIR="/cfunas/diagnostics/postprocessed/moc/nemovar"
  DATADIR="/cfunas/diagnostics/postprocessed/moc/nemovar"
  ;;
esac

WORKDIR="/scratch/$USER/moc"
MASK_FILE=ecearth_mm_lsm.nc
PATH_MASK="/cfu/pub/scripts/CDFTOOLS/constant_files"
CDFTOOLS=/opt/cdftools/bin
CON_FILES=/cfu/pub/scripts/CDFTOOLS/constant_files
mkdir -p ${SAVEDIR} ${WORKDIR}

cd ${WORKDIR}


	### Actual Computation ###

cd ${WORKDIR}; rm -rf * 

  ln -sf $CON_FILES/mask.nc .
  ln -sf $CON_FILES/mesh_hgr.nc .
  ln -sf $CON_FILES/mesh_zgr.nc .
  ln -sf $CON_FILES/new_maskglo.nc .

mem=$MEMBER

case ${DATA} in 
model)
##########################
    output=moc_${EXPID}_${SDATE}_fc${mem}_${suffix}.nc
    filein=moc_${EXPID}_${SDATE}_fc${mem}.nc

    cp ${DATADIR}/${filein} moc.nc 
    ncrename -d y,lat -v nav_lat,lat moc.nc
   # ncwa -O -a x moc.nc moc.nc    

   ncks -O -v zomsfatl,time moc.nc tmp.nc; rm -f moc.nc
   ncdump tmp.nc > tmp.cdl
   sed -e "s/lat(lat, x)/lat(lat)/g" tmp.cdl > tmp2.cdl
   sed -e "s/zomsfatl(time_counter, depthw, lat, x)/zomsfatl(time_counter, depthw, lat)/g" tmp2.cdl > tmp.cdl
   ncgen -o tmp.nc tmp.cdl


    ncks -d lat,${LATMIN},${LATMAX} -d depthw,${DEPMIN},${DEPMAX} tmp.nc area_moc.nc
    cdo vertmean area_moc.nc area_ave_moc.nc; rm area_moc.nc
    ncap -O -s "coslat[lat]=cos(lat[lat]*3.141592657/180.0)" area_ave_moc.nc area_ave_moc2.nc
    ncwa -w coslat -a lat area_ave_moc2.nc area_ave_moc3.nc
    ncks -O -v zomsfatl,time area_ave_moc3.nc area_ave_moc3.nc
    rm area_ave_moc.nc area_ave_moc2.nc; 
    chmod 770 area_ave_moc3.nc
 #   mv area_ave_moc3.nc member_moc_${mem}.nc
    mv area_ave_moc3.nc ${SAVEDIR}/${output} 

  
#  ncecat member*.nc ${output}; rm member*.nc
#  ncrename -d record,ensemble ${output}
#  ncpdq -O -h -a time,ensemble ${output} ${output}; chmod 770 ${output}
#  mv ${output} ${SAVEDIR}

;;

obs)   # case conditions for model or observation


DATADIR=/cfunas/diagnostics/postprocessed/moc/nemovar
SAVEDIR=/cfunas/diagnostics/postprocessed/moc/nemovar
output=moc_${suffix}.nc

    filein=moc_fc${mem}.nc

    cp ${DATADIR}/${filein} moc.nc
    ncrename -d y,lat -v nav_lat,lat moc.nc
   # ncwa -O -a x moc.nc moc.nc    

   ncks -O -v zomsfatl,time moc.nc tmp.nc
   ncdump tmp.nc > tmp.cdl
   sed -e "s/lat(lat, x)/lat(lat)/g" tmp.cdl > tmp2.cdl
   sed -e "s/zomsfatl(time_counter, depthw, lat, x)/zomsfatl(time_counter, depthw, lat)/g" tmp2.cdl > tmp.cdl
   ncgen -o tmp.nc tmp.cdl


    ncks -d lat,${LATMIN},${LATMAX} -d depthw,${DEPMIN},${DEPMAX} tmp.nc area_moc.nc
    cdo vertmean area_moc.nc area_ave_moc.nc; rm area_moc.nc
    ncap -O -s "coslat[lat]=cos(lat[lat]*3.141592657/180.0)" area_ave_moc.nc area_ave_moc2.nc
    ncwa -w coslat -a lat area_ave_moc2.nc area_ave_moc3.nc
    ncks -O -v zomsfatl,time area_ave_moc3.nc area_ave_moc3.nc
    rm area_ave_moc.nc area_ave_moc2.nc;
    chmod 770 area_ave_moc3.nc
    ncwa -h -O -a x area_ave_moc3.nc area_ave_moc3.nc
    mv area_ave_moc3.nc ${SAVEDIR}/moc_fc${mem}_${suffix}.nc



function combine_mem(){
  ncecat member*.nc ${output}; rm member*.nc
  ncrename -d record,ensemble ${output}
  ncpdq -O -h -a time,ensemble ${output} ${output}; chmod 770 ${output}
  mv ${output} ${SAVEDIR}
}
;;


esac

rm -r ${WORKDIR}

