#!/bin/bash
set -evx
#
# This script computes the ocean heat content from the NEMO output
#
# Written by Hui Du (based on "/gpfs/projects/ecm86/common/cdftools/scripts/cdfheatc.sh" on BSC)
#
# Created:   October 1, 2010
#            Hui Du (based on "/gpfs/projects/ecm86/common/cdftools/scripts/cdfheatc.sh" on BSC)
# Modified:  October 22, 2010
#            F. Doblas-Reyes
#
########################
### General Settings ###
########################
EXPID=$1 # experiment ID
SDATE=$2
#YEAR_LST=( 19601101 19651101 19701101 19751101 19801101 19851101 19901101 19951101 20001101 20051101 )
MEMBER=$3
DATADIR=/cfunas/exp/ecearth
GRID=icemod
#suffix_date=19810801-19810831
suffix_date=*
TYPE=1d # MM/1d
output=ice_${EXPID}_${SDATE}_${MEMBER}.nc
#
# The data directory should follow the structure ${DATADIR}/${EXPID}/${SDATE}/${member}/
# where ${DATADIR} is the directory where the model output is available from
# $EXPID is the experiment ID
# $SDATE is the starting date of the simulation
# $member is the ensemble member
#
TMPDIR=/var/tmp/${USER}/ice_$EXPID
SAVEDIR=/cfunas/diagnostics/postprocessed/ice/${EXPID}
CON_FILES=/cfu/pub/scripts/CDFTOOLS/constant_files
PREFIX=ice
PATH=${PATH}:/share/apps/cdftools-2.1/intel11/bin:/share/apps/cdo-1.4.5.1/intel11/bin/:/share/apps/nco-3.9.9/intel11/bin/:/share/apps/ferret/bin/:/share/apps/netcdf-3.6.0-p1/intel10/bin/
#
# Create setup
#
mkdir -p ${SAVEDIR}
rm -rf $TMPDIR
mkdir -p $TMPDIR
cd $TMPDIR

ln -sf ${CON_FILES}/mask.nc .
ln -sf ${CON_FILES}/mesh_hgr.nc .

#
## get extension of a file
#
function get_ext(){
file=$1
echo ${file##*.}
}

delete_time(){
 ncrename -O -h -v time,kaka $1
 ncks -O -h -x -v kaka $1 $1
}



#
# File retrieval and variable selection
#
member=$MEMBER

source_dir=${DATADIR}/${EXPID}/${SDATE}/${member}/outputs
file=`ls ${DATADIR}/${EXPID}/${SDATE}/${member}/outputs|head -1`
extension=`get_ext $file`
case $extension in
 tar)
 files=`find ${source_dir} -name MMO*${EXPID}_${SDATE}_${member}_${suffix_date}.${extension}`
 for file in $files; do
 file1=`tar tf $file | grep ${GRID}`
 tar xvf $file ${file1}
 gunzip ${file1}
 file2=`basename $file1 .gz`  
 done
 ;;
 gz)
 cp ${source_dir}/*${TYPE}*${GRID}.*.gz ./
 gunzip *.gz
 ;;
 nc)
 cp ${source_dir}/*${TYPE}*${GRID}.nc ./
 ;;
esac


#
# Calculation of the sea ice area and related variables 
#
#cp ${CON_FILES}/ice_template.nc toto_N.nc # heatc.nc is a file that contains a template for the ohc NetCDF output
#cp ${CON_FILES}/ice_template.nc toto_S.nc 

files=`ls *${TYPE}*${GRID}.nc`

# to get time.nc

cdo mergetime $files toto.nc
ncks -h -O -v time toto.nc -o time.nc; rm toto.nc


for f in $files;do

cdficediags $f;
#rm $f;
mv icediags.nc icediags_$f

done

#cdo mergetime icediags_*.nc ${output}
cdo copy icediags_*.nc ${output}

delete_time ${output}
ncks -h -A time.nc ${output}

exit

mv ${output} ${SAVEDIR}; #mv ice*.txt ${SAVEDIR}
cd ..
rm -rf ${TMPDIR}
date
