#!/bin/bash
set -exv

### General Settings ###
########################

GRID=grid_V
DATA=model #/obs
EXPID=$1  # experiment ID,NEMOVAR_COMBINE for observation 
SDATE=$2
MEM=$3
SAVEDIR="/cfunas/diagnostics/postprocessed/moc/${EXPID}"
WORKDIR="/tmp/moc/${EXPID}"

######### End of user modifications########################
case $EXPID in 
  'NEMOVAR_COMBINE')
  data=obs
  SAVEDIR="/cfunas/diagnostics/postprocessed/moc/nemovar"
  ;;
esac


CON_FILES=/cfu/pub/scripts/CDFTOOLS/constant_files
CDFTOOLS_DIR=/opt/cdftools/bin/

mkdir -p ${SAVEDIR}
rm -rf ${WORKDIR}; mkdir -p ${WORKDIR}
cd ${WORKDIR}

ln -sf $CON_FILES/mask.nc .
ln -sf $CON_FILES/mesh_hgr.nc .
ln -sf $CON_FILES/mesh_zgr.nc .
ln -sf $CON_FILES/new_maskglo.nc .
cp ${CDFTOOLS_DIR}/cdfmoc .
	
#
## get extension of a file
#
function get_ext(){
file=$1
echo ${file##*.}
}

mem=${MEM}

case ${DATA} in 
model)
DATADIR=/cfunas/exp/ecearth/${EXPID}/${SDATE}/
 source_dir=${DATADIR}/fc${mem}/outputs

 file=`ls ${source_dir}|head -1`
 extension=`get_ext $file`
 #merged=moc_fc$mem
 merged=${EXPID}_${SDATE}_fc${mem}_ORCA1

 case $extension in
  tar)
   files=`find ${source_dir} -name MMO*${EXPID}_${SDATE}_fc${mem}_*.tar`
   for file in $files; do
     file1=`tar tf $file | grep ${GRID}`
     tar xvf $file ${file1}
     gunzip ${file1}
     file2=`basename $file1 .gz`
     ncks -O -v vomecrty,nav_lon,nav_lat,depthv,time_counter ${file2} ${file2}
   done

   rm -f ${merged}
   cdo mergetime ORCA1_MM_*_${GRID}.nc ${merged}.nc
   chmod 777 ${EXPID}*.nc
  ;;
  gz)
   cp ${source_dir}/*${GRID}.*.gz ./
   gunzip *.gz
   files=`ls *${GRID}*.nc`
   for file in $files;do
     ncks -O -v vomecrty,nav_lon,nav_lat,depthv,time_counter ${file} ${file}
   done
   rm -f ${merged}
   cdo mergetime *${GRID}.nc ${merged}.nc; rm *${GRID}.nc
   chmod 777 ${EXPID}*.nc
  ;;
  nc)
   cp ${source_dir}/*${GRID}.nc ./
   files=`ls *${GRID}*.nc`
   for file in $files;do
    ncks -O -v vomecrty,nav_lon,nav_lat,depthv,time_counter ${file} ${file}
   done
   rm -f ${merged}
   cdo mergetime *${GRID}.nc ${merged}.nc; rm *${GRID}.nc
   chmod 777 ${EXPID}*.nc
  ;;
 esac

 output1=moc_${EXPID}_${SDATE}_fc${mem}

  for t in $(seq 1 1 `cdo ntime ${merged}.nc`); do
    cdo seltimestep,$t ${merged}.nc tmp.nc
    ./cdfmoc tmp.nc 
    cdo cat moc.nc ${output1}.nc
    rm -f  tmp.nc moc.nc 
  done

  unit=`ncdump -c ${merged}.nc | grep "time:units" | cut -d '"' -f2`

  ncks -h -v time ${merged}.nc -o time.nc
  ncks -h -A time.nc ${output1}.nc
  rm -f time.nc
  mv ${output1}.nc ${SAVEDIR}; rm ORCA*
;;

obs)   # case conditions for model or observation

DATADIR=/cfunas/exp/ECMWF/NEMOVAR_COMBINE/outputs/
cp ${CON_FILES}/nemovar_time.nc ./time.nc

 output1=moc_opa${mem}_${DEPMIN}-${DEPMAX}.nc
 files=`ls ${DATADIR}/opa${mem}/*${GRID}*.gz`
 for f in ${files}; do #loop for gz files
  cp ${f} ./moc_tmp.nc.gz
  gunzip moc_tmp.nc.gz
  ./cdfmoc moc_tmp.nc
  cdo cat moc.nc ${output1}
  rm moc.nc moc_tmp.nc

 done #loop for nc files

 ncks -A time.nc ${output1}

 mv ${output1} ${SAVEDIR}

;;

esac

rm -r ${WORKDIR}

