#!/bin/bash

#
# This script is to compute Maximum MOC for Atlantic of NEMOVAR data .
#
# The originial files should be monthly means of grid_V file. 
#
# 
# Written by Hui Du (not writen from scratch, but based on "/gpfs/projects/ecm86/common/cdftools/scripts/cdfmocmaxmoc.sh" 
#
# Institut Català de Ciències del Clima / Climate Forecasting Unit (IC3/CFU)
# Created:   October 1, 2010
#


set -ex
### General Settings ###

#=== Beginning of User modification ==============
expid=i00k # You do not need to change this   
sdates="19601101 19651101 19701101 19751101 19801101 19851101 19901101 19951101 20001101 20051101"
members="fc0 fc1 fc2"  # modify here if you only calculate part of the members 
datadir=/cfunas/diagnostics/postprocessed/moc/${expid}  # No need to change this, unless NEMOVAR data are moved to other directory
workdir=/tmp/huidu/maxmoc
con_files=/cfu/pub/scripts/CDFTOOLS/constant_files # Usually you do not need to change this part
cbasin=atl  # specify which basin you want to compute 
latmin=-60  # specify the minimum  latitude
latmax=60  # specify the maxmum latitude
depmin=300  # specify the minmum depth
depmax=5000  #specify the maxmum depth 
para="$cbasin $latmin $latmax $depmin $depmax"
################### End of user's modification ###############################
mkdir -p $workdir;cd $workdir

if [[ $latmin -lt 0 ]]; then
latname1=$((latmin*-1))S
elif [[ $latmin -eq 0 ]];then
latname1=$latmin
else [[ $latmin -gt 0 ]]
latname1=${latmin}N
fi


if [[ $latmax -lt 0 ]];then
latname2=$((latmax*-1))S
elif [[ $latmax -eq 0 ]];then
latname2=$latmax
else 
[[ $latmax -gt 0 ]]
latname2=${latmax}N
fi

delete_time_counter(){
ncrename -O -h -v time_counter,kaka $1
ncks -O -h -x -v kaka $1 $1
}

delete_dim(){  # $1, is the netcdf file, $2, the dimension 

ncwa -h -O -a $2 $1 -o $1

}
for sdate in $sdates;do
 echo $sdate
 for mem in $members;do 
 file=moc_${expid}_${sdate}_$mem.nc
 output=maxmoc_$expid_${sdate}_$mem.nc
 cp $datadir/$file .
 ncks -h -O -v time ${file} -o time.nc
 nt=`cdo ntime $file`
 cdo seltimestep,1 $file toto.nc
 cdfmaxmoc toto.nc $para ;rm toto.nc
 mv maxmoc.nc $output
 for ((t=2;t<=$nt;t++));do
  cdo seltimestep,$t $file toto.nc
  cdfmaxmoc toto.nc $para ;rm toto.nc
  ncrcat -h -O ${output} maxmoc.nc ${output};rm maxmoc.nc 
 done
 for dim in x y depthw ;do
 delete_dim $output $dim
 done
 ncrename -h -d time_counter,time $output
# delete_time_counter $output
# ncks -h -A time.nc ${output}.nc;rm time.nc;rm $file
 mv ${output} $datadir
 
 done #loop for members 
done # loop for sdates

rm -r $workdir 
