#!/bin/bash

### General Settings ###
########################
expid=b013
years=( 19601101 19651101 19701101 19751101 19801101 19851101 19901101 19951101)
#years=( 19901101 )
members=( fc0 fc1 fc2 fc3 fc4 )
#members=( fc4 )
tmp_path=/tmp/ysoufflet/MOC
data=/mnt/$expid
tmp_dir=$tmp_path/${expid}
#rm -rf $tmp_dir
mkdir -p $tmp_dir
cd $tmp_dir

cdo=`which cdo`
ncrename=`which ncrename`
ncatted=`which ncatted`
ncl=`which ncl`
ncdump=`which ncdump`

# Check the existence of above tools
if tool=$cdo      && test ! -f $tool || \
   tool=$ncrename && test ! -f $tool || \
   tool=$ncatted  && test ! -f $tool || \
   tool=$ncl      && test ! -f $tool; then
 echo "$tool does not exist!!!"
 exit 1
fi 
cdftools=/opt/cdftools/bin 
files=/cfu/pub/scripts/CDFTOOLS/constant_files 


### Stuff for cdfmoc ###
#######################
#  Usage : cdfmoc  V file 
#  Computes the MOC for oceanic basins as described in new_maskglo.nc
#  PARTIAL CELLS VERSION
#  Files mesh_hgr.nc, mesh_zgr.nc ,new_maskglo.nc ,mask.nc 
#  must be in the current directory
#  Output on moc.nc: 
#       variables zomsfglo  : Global ocean 
#       variables zomsfatl  : Atlantic Ocean 
#       variables zomsfinp  : Indo Pacific 
#       variables zomsfind  : Indian Ocean alone
#       variables zomsfpac  : Pacific Ocean alone

grid=grid_V

exec1=cdfmoc
 ### Stuff for cdfmaxmoc ####
	###########################
	#  USAGE: cdfmaxmoc 'ovt_file.nc' cbasin latmin latmax depmin depmax [cdfout]
	#         cbasin is one of atl glo inp ind or pac 
	#  Output on standard output by default
	#  Output on netcdf is available adding cdfout as last argument

	exec2=cdfmaxmoc
	cp $cdftools/$exec2 .

	cbasin=atl
	latmin=-30
	latmax=60
	depmin=50
	depmax=5000

	para2="$cbasin $latmin $latmax $depmin $depmax "
	 prefix2=maxminmoc
	 suffix2=${depmin}-${depmax}_$cbasin

### Actual Computation ###
##########################
for year in ${years[@]}; do
    echo "******************** Start $year **********************"
    date
    cd $tmp_dir
    mkdir -p $tmp_dir/$year
    for member in  ${members[@]}; do
        echo "******************** Start $member **********************"
        echo
	 cd $tmp_dir/$year
	 mkdir -p ${member}
	 cd $tmp_dir/$year/${member}
	 merged=${expid}_${year}_${member}

	 ln -sf $cdftools/$exec1 .
	 ln -sf $cdftools/$exec2 .
	 ln -sf $files/mask.nc .
	 ln -sf $files/mesh_hgr.nc .
	 ln -sf $files/mesh_zgr.nc .
	 ln -sf $files/new_maskglo.nc .

	 prefix1=moc
	 suffix1=global
	 output1=${prefix1}_${merged}_${suffix1}

	 output2=${prefix2}_${merged}_${suffix2}
	 if (( 1 > 0 )) ; then
	  for file in `ls ${data}/${year}/${member}/MMO_${expid}_${year}_${member}_*.tar`; do
	   file1=`tar tf $file | grep grid_V`
	   tar -xvf $file  $file1
	  done

	  gunzip ORCA1_MM_*_${grid}.nc.gz

	 $cdo mergetime ORCA1_MM_*_${grid}.nc ${merged}.nc

	 for t in $(seq 1 1 `$cdo ntime ${merged}.nc`); do
	  $cdo seltimestep,$t ${merged}.nc tmp.nc
	  ./$exec1 tmp.nc
	  mv moc.nc moc_$t.nc
	  $cdo cat moc_$t.nc ${output1}.nc
	  ./$exec2 moc_$t.nc $para2
	  $cdo cat maxmoc.nc ${output2}.nc
	  rm maxmoc.nc tmp.nc moc_$t.nc 
	 done
	fi

	 unit=`$ncdump -c ${merged}.nc | grep "time:units" | cut -d '"' -f2`
	 #change attribute and unit name
	 $ncatted -h -a units,time,m,c,"$unit" ${output1}.nc
	 $ncatted -h -a time,time,d,, ${output1}.nc
	 $ncatted -h -a units,time,m,c,"$unit" ${output2}.nc
	 $ncatted -h -a time,time,d,, ${output2}.nc
	 

	 ncks -h -v time ${merged}.nc -o time.nc
	 ncks -h -A time.nc ${output1}.nc
	 rm -rf MMO_${expid}_${year}_${member}_*
	 rm -rf ORCA1_MM_*
	 rm time.nc
	 ncks -h -v time ${merged}.nc -o time.nc
	 ncks -h -A time.nc ${output2}.nc
         rm time.nc
    
    echo "******************** END $member  *********************"
    done
    echo "******************** END $year  *********************"
done
#
#rm -rf ${merged}.nc

