#!/bin/sh
set -evx 

DATADIR=/tmp/${USER}/MOC
WORKDIR=/tmp/${USER}/MOC
expid=nemovar
MMDD=1101
YYINI=1960
YYEND=2005
YYINT=5
vars=( maxmoc latmaxmoc depthmaxmoc ) 
depthmin=50
depthmax=5000
basin=atl

suffix=${depthmin}-${depthmax}_$basin
cdo=`which cdo`

LASTYEAR=$((YYEND+5))

ndata=$(((YYEND-YYINI)/YYINT+1)) # calculate the number of start dates
nt=$(((YYEND-YYINI+YYINT)*12)) # number of months for ploting, et. number of timesteps

cdate=`seq $YYINI $YYINT $YYEND`
echo $ndata $cdate

cyear=""

for ((i=1;i<=$ndata;i++));do

tmpc=`echo $cdate|cut -f$i -d" "`
if [[ i -eq 1 ]]; then
cyear=${cyear}${tmpc}
else
cyear=${cyear}","${tmpc}
fi
done
echo $cyear

yy1=$YYINI
mm1=`echo $MMDD|cut -c1-2`


[[ -d $WORKDIR ]] || mkdir -p $WORKDIR
cd ${WORKDIR}
plotsdir="/tmp/${USER}/plots"
[[ -d $plotsdir ]] || mkdir -p $plotsdir
#
# Write the R script testing ncdf (in temporary plot_test in the workdir)
#
obs0=${DATADIR}/nemovar/opa0/maxminmoc_nemovar_opa0_${depthmin}-${depthmax}_${basin}.nc 


# 
# the following piece of code tries to extract the observational data based on the year and month
#
nt_obs=`cdo ntime $obs0`

for ((i=1;i<=$nt_obs;i++)) do
yy=`cdo showyear -seltimestep,$i $obs0`
mm=`cdo showmon -seltimestep,$i $obs0`
if [[ $yy -eq $yy1 && $mm -eq $mm1 ]]; then
st_obs=$i
break
fi

done
output=${expid}_${YYINI}-${YYEND}_${suffix}.png

cat>$WORKDIR/plot_test<<EOF

library(ncdf)
source("/cfu/scratch/dvolpi/MSC_Project/rclim_gm.txt")

for (v in c("maxmoc","latmaxmoc","depthmaxmoc")) {
outputfile=paste("$plotsdir/clim_",v,"_${output}",sep="")
png(outputfile,width=800,height=600)
par(mfrow=c(3,1))

maxmoc_obs=array(dim=c($nt,5))
model_clim=array(dim=c($YYINT*12))
#initialize that array
model_clim[]=0
print("Computing model climate")

for (j in c("0","1","2","3","4")) {
file=paste("${DATADIR}/${expid}/opa",j,"/maxminmoc_${expid}_opa",j,"_${suffix}.nc",sep="")
fnc=open.ncdf(file)
tvar=get.var.ncdf(fnc,v)
index_j=as.integer(j)+1
index_t1=as.integer(${st_obs})
index_t2=index_t1+$nt-1
maxmoc_obs[,index_j]=tvar[index_t1:index_t2]
for ( k in seq(1,$nt,60)) {
model_clim[1:60]=model_clim[1:60]+maxmoc_obs[k:k+60-1,index_j]
}
}
model_clim=model_clim/($ndata*5)

print("Computing anomalies")
#Compute anomalies
obs_anomalies=array(dim=c($nt,6))

obs_anomalies[]=0

for (j in c("0","1","2","3","4")) {
index_j=as.integer(j)+1
for ( k in 1:$nt) {
if (k%%60==0){
index_k=60
}
else {
index_k=k%%60
}
obs_anomalies[k,index_j]=maxmoc_obs[k,index_j]-model_clim[index_k]
}
}

#Do an ensemble mean of those anomalies
for (j in 1:5) {
obs_anomalies[,6]=obs_anomalies[,6]+obs_anomalies[,j]
}
obs_anomalies[,6]=obs_anomalies[,6]/5
print("done!")

print("Smoothing anomalies")
#Applying running means anomalies
smt_anomalies=array(dim=c($nt,6))

for (j in 1:6) {
for ( k in 4:596 ) {
smt_anomalies[k,j]=(obs_anomalies[k-3,j]+obs_anomalies[(k+3),j])/12+(obs_anomalies[k-1,j]+obs_anomalies[k-2,j]+obs_anomalies[k,j]+obs_anomalies[k+1,j]+obs_anomalies[k+2,j])/6
}
}

#Putting everything back into a big area
print("putting things back into bigger area")
anom2=array(dim=c($nt,6))
anom2=smt_anomalies
empty=array(dim=$nt)
empty_ts=ts(empty,start=c($YYINI,11),end=c($LASTYEAR,10),frequency=12)

ulimit=max(obs_anomalies,na.rm=FALSE)+0.5
print(ulimit)
llimit=min(obs_anomalies,na.rm=FALSE)-0.5
print(llimit)
if ( v==c("depthmaxmoc") ) {
llimit=max(anom2,na.rm=FALSE)+0.5
print(ulimit)
ulimit=min(anom2,na.rm=FALSE)-0.5
print(llimit)
}


#plot(empty_ts,ylim=c(ulimit,llimit),ylab="")
#color=rainbow($ndata)
#par(new=TRUE)
matplot(obs_anomalies[,1:5],type="l",lty=c(1),ylim=c(llimit,ulimit),col=1,ylab="",labels=FALSE,axes=FALSE)
#par(new=TRUE)
#matplot(anom2[,6],type="l",lty=1,lwd=3,lend=2,ylim=c(llimit,ulimit),col=1,ylab="",labels=FALSE,axes=FALSE)

#plot(empty_ts,ylim=c(llimit,ulimit),ylab="")
#par(new=TRUE)
#matplot(anom2[,6],type="l",lty=1,lwd=3,lend=2,ylim=c(llimit,ulimit),col=1,ylab="",labels=FALSE,axes=FALSE)


#plot(model_clim,type="l",lty=c(1),col=1,ylab="")
}



dev.off()
#
# Closing the R script
#
EOF
#cat plot_test # uncommented: it shows the R script in the screen
#
# Run the R script
#
R CMD BATCH $WORKDIR/plot_test
echo "Please go to ${plotsdir} to check the plots and the log files"
cp plot_test  /cfu/scratch/$USER/log 
cp plot_test.Rout  /cfu/scratch/$USER/log
#
chmod -R 775 ${plotsdir}
eog ${plotsdir}/clim_${expid}*moc*.png
