#
# This script plot the climatology of near the surface temperature for land and ocean dataset
#
#!/bin/sh
#set -evx
WORKDIR="/tmp/${USER}/MOC/$$"
[[ -d $WORKDIR ]] || mkdir -p $WORKDIR
cd ${WORKDIR}
plotsdir="/tmp/${USER}/plots"
[[ -d $plotsdir ]] || mkdir -p $plotsdir

#echo 'Please provide the experiment ID:'
#read EXPID
EXPID=b013

yyini=1960
yyend=2005
mmini=11
mmend=10
nmonth=60

freq_forecast=5
members=5

FULL_PATH=$WORKDIR/$EXPID
VAR=maxmoc
#
# Write the R script that will be stored in gm_plot in the workdir
#
cat>$WORKDIR/climatology<<EOF
source("/cfu/scratch/dvolpi/MSC_Project/rclim_gm.txt")
library(ncdf)
#
# Parameters
# Store the data coming from bash
var="${VAR}"
freq_forecast=${freq_forecast}
nmr=6 # nmr: number of months in the running-mean for the smoothing
forecast_ini=$yyini
forecast_mmini=$mmini
forecast_end=$yyend
nmonth=$nmonth  # number of month for each run
methods=$members  # number of methods
nyear=(forecast_end-forecast_ini)/freq_forecast+1 #  number of forecasts run (one of 120 months per year)
fr_plots=freq_forecast # frequency of the forecast plot (every 5 years)
YY_INI=yyini
YY_END=yyend+nmonth/12
FULL_PATH="${FULL_PATH}"
#
# Read DePreSys: store in an array the different methods for each year of forecast -array of dimension (nmonth,methods,nyear) (120,9,46)-
#
ensembles=array(dim=c(nmonth,methods,nyear))
leadtime_values=array(dim=c(nmonth,methods,nyear))
reftime_values=array(dim=c(nmonth,methods,nyear))
#
# Loop over the initial years of the forecasts
#
year=0
for (j in forecast_ini:forecast_end) {
    year=year+1
    counter=0
    #
    # Loop over the methods
    #
    for (i in 0:4) {
	infile=paste("$FULL_PATH/",i,"1101/fc",j,",sep="") 
        file=open.ncdf(infile)
        #tas_${TYPE}=netcdfread(file,"leadtime","tas")
        tas_${TYPE}=get.var.ncdf(file,"tas") 
        counter=counter+1
        ensembles_${TYPE}[,counter,year]=c(tas_${TYPE})
        lead_${TYPE}=get.var.ncdf(file,"leadtime") 
        leadtime_values[,counter,year]=c(lead_${TYPE})
        ref_${TYPE}=get.var.ncdf(file,"reftime") 
        reftime_values[,counter,year]=c(ref_${TYPE})
    }
}
longname_lead=att.get.ncdf(file,"leadtime","long_name")
standardname_lead=att.get.ncdf(file,"leadtime","standard_name")
units_lead=att.get.ncdf(file,"leadtime","units")
#
longname_lead\$value
standardname_lead\$value
units_lead\$value
#
longname_ref=att.get.ncdf(file,"reftime","long_name")
standardname_ref=att.get.ncdf(file,"reftime","standard_name")
units_ref=att.get.ncdf(file,"reftime","units")
#
longname_tas=att.get.ncdf(file,"tas","long_name")
standardname_tas=att.get.ncdf(file,"tas","standard_name")
units_tas=att.get.ncdf(file,"tas","units")
fill_tas=att.get.ncdf(file,"tas","_FillValue")
data_tas=att.get.ncdf(file,"tas","data_type")
unitlong_tas=att.get.ncdf(file,"tas","unit_long")
cell_tas=att.get.ncdf(file,"tas","cell_methods")
#
# Calculate the climatology for the 120 months of forecast -output array (nmonth,methods) (120,9)-
#
ensembles_${TYPE}_climatology=array(dim=c(nmonth,methods))
sum=array(dim=c(methods)) 
#
# Loop over the timesteps of each forecast 
#
for (month in 1:nmonth){
    counter_yy=1
    dividend=0
    sum[]=0
    for (yy in seq(forecast_ini,forecast_end,freq_forecast)) {
	counter_meth=0
        year_check=yy+as.integer((month-1)/12)
        rest=(month %% 12) + forecast_mmini
        if (rest >12) {
           rest=rest-12
        }  
        #rest
        #
        # The value is add to the sum only if it belongs to the last year of obs and it is one of the month for which the obs is available or if it belongs to a year smaller than the the last year of obs
        #
	if ((( year_check == yyend_reanalysis) & ( rest <= mmend_reanalysis)) || ( year_check < yyend_reanalysis )) {
           if (((year_check == yyini_reanalysis) & (rest >= mmini_reanalysis)) || (year_check > yyini_reanalysis)) {
              dividend=dividend+1
	      for (i in first_name:last_name) {
	          counter_meth=counter_meth+1
	          #
	          # summation of all the nth value of each forecast
	          #
	          sum[counter_meth]=sum[counter_meth]+ensembles_${TYPE}[month,counter_meth,counter_yy]
	      }
           }	
 	}
        counter_yy=counter_yy+(1*freq_forecast)
    }
    counter_meth=0 
    for (j in first_name:last_name) {
	counter_meth=counter_meth+1
	ensembles_${TYPE}_climatology[month,counter_meth]=sum[counter_meth]/dividend
    }
}

#
# Calculate the anomalies of the forecasts
#
counter=0
count_ar_time=0
year_dim=as.integer(nyear/freq_forecast)
if ((nyear%%freq_forecast) != 0) {
   year_dim=year_dim+1
}
year_dim
nyear
freq_forecast
ensembles_${TYPE}_anomalies=array(dim=c(nmonth,methods,year_dim))
dim(ensembles_${TYPE}_anomalies)
dim(reftime_values)
dim(leadtime_values)
leadtime_values[,1,1]
leadtime_values[,1,6]
reftime_values[,1,6]
reftime_values[,1,1]
#
# Variable to compute the IQR
#
InterQR=array(dim=c(nmonth,year_dim))
x=array(dim=9)
for (yy in seq(1,nyear,freq_forecast)) {
    real_yy=forecast_ini-1+yy
    counter_ar_time=1+(counter*freq_forecast)
    counter=counter+1
    for (meth in 1:methods) {
        real_meth=first_name-1+meth
	for (mm in 1:nmonth) {
	    ensembles_${TYPE}_anomalies[mm,meth,counter]=ensembles_${TYPE}[mm,meth,yy]-ensembles_${TYPE}_climatology[mm,meth]
        }
        #
        # Creating netcdf with the results
        #
        time=dim.def.ncdf("time",units_ref\$value,reftime_values[,meth,counter_ar_time],unlim=TRUE)
        leadtime=var.def.ncdf("leadtime",units_lead\$value,list(time),1.e+12,longname_lead\$value)
        reftime=var.def.ncdf("reftime",units_ref\$value,list(time),1.e+12,longname_ref\$value)
        tas=var.def.ncdf("tas",units_tas\$value,list(time),fill_tas\$value,longname_tas\$value)
        ncdf_title=paste("$plotsdir/anomalies_DePreSys_",TYPE,"_",var,"_",real_yy,"_meth",real_meth,"_",freq_forecast,"yy.nc",sep="")
        ncnew=create.ncdf(ncdf_title,list(leadtime,reftime,tas))
        att.put.ncdf(ncnew,"leadtime","standard_name",standardname_lead\$value)
        att.put.ncdf(ncnew,"reftime","standard_name",standardname_ref\$value)
        att.put.ncdf(ncnew,"tas","data_type",data_tas\$value)
        att.put.ncdf(ncnew,"tas","unit_long",unitlong_tas\$value)
        att.put.ncdf(ncnew,"tas","cell_methods",cell_tas\$value)
        put.var.ncdf(ncnew,reftime, reftime_values[,meth,counter_ar_time])
        put.var.ncdf(ncnew,leadtime, leadtime_values[,meth,counter_ar_time])
        put.var.ncdf(ncnew,tas,ensembles_${TYPE}_anomalies[,meth,counter])
        
        close.ncdf(ncnew)
    }
    for (mm in 1:nmonth) {
        for (meth in 1:methods) {
            x[meth]=ensembles_${TYPE}_anomalies[mm,meth,counter]
        }
    InterQR[mm,counter]=IQR(x, na.rm=TRUE)
    }
}
#
# Close the R program
#
EOF
cat climatology
#
# run the R script
#
R CMD BATCH $WORKDIR/climatology
#
