

#
# Read the reanalysis data
#
infile=paste(FULL_PATH,"/gm_tas_",TYPE,"_",var,".nc",sep="") 
if (as.character(var) == "ghcn"){
   infile=paste(FULL_PATH,"/gm_tas_ghcn.nc",sep="") 
}
file=open.ncdf(infile)
reanalysis_${TYPE}=get.var.ncdf(file,name)
time_reanalysis=get.var.ncdf(file,"time") 
units_time=att.get.ncdf(file,"time","units")
calendar_time=att.get.ncdf(file,"time","calendar")
#
if (as.character(var) == "ghcn"){
fill_rean=att.get.ncdf(file,name,"_FillValue")
longname_rean="near-surface temperature"
units_rean="K"
}else {
      longname_rean=att.get.ncdf(file,name,"long_name")
      longname_rean=longname_rean\$value
      units_rean=att.get.ncdf(file,name,"units")
      units_rean=units_rean\$value
      fill_rean=att.get.ncdf(file,name,"_FillValue")
}
#
# Calculate the factor that indicates the initial time step of the reanalysis with respect of the initial step of the forecast
# Check over the domain: 
#
if (( yyini_reanalysis < forecast_ini ) || (( forecast_ini == yyini_reanalysis ) & ( mmini_reanalysis < forecast_mmini ))) { # i.e. if the reanalysis starts before the forecasts 
   size="bigger"
   factor=(forecast_ini-yyini_reanalysis)*12+(forecast_mmini-mmini_reanalysis)+1
   total=nti_reanalysis-factor+1
   time_reanal=array(dim=total)
   time_reanal=time_reanalysis[factor:nti_reanalysis]
} else {
   size="smaller"
   factor=(yyini_reanalysis-forecast_ini)*12+(mmini_reanalysis-forecast_mmini)+1
   total=nti_reanalysis
   time_reanal=time_reanalysis
}
#reanalysis_${TYPE}=netcdfread(file,"time",name)
#
# Create the array for the climatology 
#
reanalysis_${TYPE}_climatology=array(dim=c(nmonth))
sum=array(dim=c(nmonth))
dividend=array(dim=c(nmonth)) # to calculate the climatology
counter_yy=0
dividend[]=0
sum[]=0
for (yy in seq (forecast_ini,forecast_end,freq_forecast)) {
    counter_yy=counter_yy+(1*freq_forecast)
    counter_mm=(counter_yy-1)*12 # count the timestep from the beginning of the forecast
    for (mm in 1:nmonth) {
	counter_mm=counter_mm+1
	#
	# a indicates the postion inside the array of the reanalysis
	#
        if (as.character(size) == "bigger") {
           a=counter_mm+factor-1
        } else {     
	   a=counter_mm-factor+1
        }
	if  ((a <= nti_reanalysis) & ((as.character(size) == "bigger") || (counter_mm >= factor))){ # check over a because in the last year of the forecast (2005) it runs a loop over 120 months, which goes out of bound of the reanalysis data.
	   dividend[mm]=dividend[mm]+1
	   sum[mm]=sum[mm]+reanalysis_${TYPE}[a]
	   }
	}
}
for (mm in 1:nmonth) {
    reanalysis_${TYPE}_climatology[mm]=sum[mm]/dividend[mm]
}
#
# To calculate the anomalies for the observation it is needed a climatology over 12 months (eraint)
#
reanalysis_${TYPE}_clim_anom=array(dim=c(12))
#year_dim=as.integer(total/freq_forecast)
#if ((total %% freq_forecast) != 0){
#   year_dim=year_dim+1
#}
#year_dim
reanalysis_${TYPE}_anomalies=array(dim=c(total))
dim(reanalysis_${TYPE}_anomalies)
for (month in 1:12){
    reanalysis_${TYPE}_clim_anom[month]=mean(reanalysis_${TYPE}_climatology[seq(month,nmonth,12)])
}
position=1
if (as.character(size) == "smaller") {
   factor=1
   counter=forecast_mmini
   while (counter != mmini_reanalysis) {
         position=position+1
         counter=counter+1
         if ( counter == 13) {
            counter=1
         }
   }
}
counter=0
for (month in factor:nti_reanalysis){
    counter=counter+1
    reanalysis_${TYPE}_anomalies[counter]=reanalysis_${TYPE}[month]-reanalysis_${TYPE}_clim_anom[position]
    position=position+1
    # Check over the counter: when it arrives to the 13th month it goes back to 1
    if ( position == 13) {
       position=1
    }
}
dim(reanalysis_${TYPE}_anomalies)
dim(time_reanal)
# Creating netcdf with the results
#
time=dim.def.ncdf("time",units_time\$value,time_reanal,unlim=TRUE)
reanal=var.def.ncdf("tas",units_rean,list(time),fill_rean\$value,longname_rean)
ncdf_title=paste("$plotsdir/anomalies_",var,"_",TYPE,"_",freq_forecast,"yy.nc",sep="")
ncnew=create.ncdf(ncdf_title,reanal)
att.put.ncdf(ncnew,"time","calendar",calendar_time\$value)
put.var.ncdf(ncnew,tas,reanalysis_${TYPE}_anomalies)
close.ncdf(ncnew)
#
time=array(dim=c(nmonth))
for (mm in 1:nmonth){
	time[mm]=mm
}
colours= c("red3", "darkorange1", "yellow", "chartreuse", "darkgreen", "cornflowerblue", "blue2", "darkmagenta", "plum", "purple4" )
#
# plot of the climatology
#
TITLE=paste("/cfu/scratch/${USER}/MSC_Project/plots/new/climatology_tas_Assim_",TYPE,"_",var,"_",freq_forecast,"yy.ps",sep="") 
plot_title=paste("Near surface temperature ",TYPE," climatology: DePreSys Assim \n ",freq_forecast,"-year start dates and ",var," Reanalysis",sep="")
legend_name=paste(var," Reanalysis",sep="" )
maxim=max(reanalysis_${TYPE}_climatology,ensembles_${TYPE}_climatology[,])
minim=min(reanalysis_${TYPE}_climatology,ensembles_${TYPE}_climatology[,])
postscript(TITLE,width=550,height=550)
par(cex.main=2.2)
par(cex.axis=1.4)
par(cex.lab=1.7)
plot(time,reanalysis_${TYPE}_climatology,xlim=range(time,time),ylim=range((minim-0.5),(maxim+0.5)),type="l",col="black",lwd=3,main=plot_title,xlab="time (months)",ylab="Temperature (K)")
#mtext(plot_title, side=3, line=0.2, cex=1.8)
#mtext(expression(paste(atop(paste('Plot of Observed vs. Predicted  Values for'), 'the PDGFR Dataset'))), side=3, line=0,cex=2)
legend(0,(maxim+0.5),legend_name,lwd=3,col='black')
for (method in 1:methods) {
	lines(time[],ensembles_${TYPE}_climatology[,method],col=colours[method])
}
dev.off()
#
# Write an array for the time
#
T_steps=((YY_END-YY_INI)+1)*12
time_years=array(dim=c(T_steps))
zeros=array(0,dim=c(T_steps))
ensembles_ini=array(dim=c(year_dim))
ensembles_end=array(dim=c(year_dim))
counter=0
counter_yy=0
pos=0
for (year in YY_INI:YY_END){
    month=1
    mm=0
    for (month in 1:12){
	counter=counter+1
        mm=mm+(1/12)
	time_years[counter]=year+mm
        if ( year >= forecast_ini) {
    	   counter_yy=counter_yy+1
           if (( month == forecast_mmini ) & (( counter_yy == 1 ) || ( ((counter_yy-1) %% freq_forecast) == 0 ))) {
              pos=pos+1
	      ensembles_ini[pos]=counter
	      ensembles_end[pos]=ensembles_ini[pos]+nmonth-1
           }	
        }
	if ((yyini_reanalysis == year) & (mmini_reanalysis == month)) {
           if (as.character(size) == "bigger"){
	      reanalysis_ini=counter+factor-1
           }else {
              reanalysis_ini=counter 
           }
	   reanalysis_end=counter+nti_reanalysis-1
	}		
    }
}
#
# Plot of the anomalies
#
dim(time_years[(reanalysis_ini):(reanalysis_end)])
dim(reanalysis_${TYPE}_anomalies)
dim(ensembles_${TYPE}_anomalies)
index=0
nplots=1+as.integer((forecast_end-forecast_ini)/fr_plots)
TITLE=paste("/cfu/scratch/${USER}/MSC_Project/plots/new/anomalies_tas_Assim_",TYPE,"_",var,"_",freq_forecast,"yy.ps",sep="") 
maxim=max(reanalysis_${TYPE}_anomalies,ensembles_${TYPE}_anomalies[,,])
minim=min(reanalysis_${TYPE}_anomalies,ensembles_${TYPE}_anomalies[,,])
plot_title=paste("Near surface temperature",TYPE," anomalies: DePreSys Assim \n",freq_forecast,"-year start dates and ",var," Reanalysis",sep="")
legend_name=paste(var," Reanalysis",sep="" )
postscript(TITLE,width=550,height=550)
par(cex.main=2.2)
par(cex.axis=1.4)
par(cex.lab=1.7)
plot(time_years[(reanalysis_ini):(reanalysis_end)],reanalysis_${TYPE}_anomalies,xlim=range(time_years,time_years),ylim=range((minim-0.1),(maxim+0.2)),type="l",col="black",lwd=2,main=plot_title,xlab="time (Years)",ylab="Temperature (K)")
legend(forecast_ini,(maxim+0.2),legend_name,lwd=3,col='black')
for (j in 1:nplots) {
    if (freq_forecast == 1){
       index=fr_plots*(j-1)+1 # corresponds to the timestep of the forecast
    }else{
       index=index+1
    }
    for (method in 1:methods) {
	lines(time_years[(ensembles_ini[index]):(ensembles_end[index])],ensembles_${TYPE}_anomalies[,method,index],col=colours[j])
    }
}
lines(time_years[(reanalysis_ini):(reanalysis_end)],reanalysis_${TYPE}_anomalies,col="black",lwd=2)
lines(time_years,zeros,col="red",lwd=2)
dev.off()

