#
# This script plot the average interquartile range between the memebrs of DePreSys (mad and sd)
#
#!/bin/sh
#set -evx
WORKDIR="/cfu/scratch/${USER}/$$"
[[ -d $WORKDIR ]] || mkdir -p $WORKDIR
cd ${WORKDIR}
plotsdir="/cfu/scratch/${USER}/MSC_Project/plots"
[[ -d $plotsdir ]] || mkdir -p $plotsdir
echo 'Select the type of dataset for the climatology: global data (global), land only (land), ocean only (ocean)'
read TYPE
#
# Write the R script that will be stored in gm_plot in the workdir
#
cat>$WORKDIR/iqr<<EOF
source("/cfu/scratch/dvolpi/MSC_Project/rclim_gm.txt")
library(ncdf)
#
# Read DePreSys: store in an array the different methods for each year of forecast 
#
TYPE="${TYPE}"
forecast_ini=1960
forecast_mmini=11
forecast_end=2005
nmonth=120  # number of month for each run
methods=9  # number of methods
nyear=46 #  number of forecasts run (one of 120 months per year)
aux="${TYPE}"
ensembles_${TYPE}=array(dim=c(nmonth,methods,nyear))
year=0
for (j in forecast_ini:forecast_end) {
    year=year+1
    counter=0
    first_name=10 # name of the first method 
    last_name=18  # name of the last method
    #
    # Loop over the methods
    #
    for (i in first_name:last_name) {
	infile=paste("/cfu/scratch/dvolpi/ENSEMBLES/decadal/DePreSys/2502/s051/m0",i,"/monthly_mean/tas_6hourly/gm_tas_",TYPE,"_",j,"1101.nc",sep="") 
        file=open.ncdf(infile)
        tas_${TYPE}=get.var.ncdf(file,"tas") 
        counter=counter+1
        ensembles_${TYPE}[,counter,year]=c(tas_${TYPE})
    }
}
#
# set the array which is going to be filled with the iqr of each start date for each forecast time step (mad and sd)
#
iqr_${TYPE}=array(dim=c(nmonth,nyear))
mad_${TYPE}=array(dim=c(nmonth,nyear))
sd_${TYPE}=array(dim=c(nmonth,nyear))
maxmin_${TYPE}=array(dim=c(nmonth,nyear))
for (i in 1:nmonth) {
    for (j in 1:nyear) {
        iqr_${TYPE}[i,j]=IQR(ensembles_${TYPE}[i,,j])
        mad_${TYPE}[i,j]=mad(ensembles_${TYPE}[i,,j])
        sd_${TYPE}[i,j]=sd(ensembles_${TYPE}[i,,j])
        maxmin_${TYPE}[i,j]=max(ensembles_${TYPE}[i,,j])-min(ensembles_${TYPE}[i,,j])
    }
}
#
# set the array that is going to store the average over the different start dates
#
iqr_average_${TYPE}=array(dim=c(nmonth))
mad_average_${TYPE}=array(dim=c(nmonth))
sd_average_${TYPE}=array(dim=c(nmonth))
maxmin_average_${TYPE}=array(dim=c(nmonth))
for (j in 1:nmonth) {
    iqr_average_${TYPE}[j]=mean(iqr_${TYPE}[j,])
    mad_average_${TYPE}[j]=mean(mad_${TYPE}[j,])
    sd_average_${TYPE}[j]=mean(sd_${TYPE}[j,])
    maxmin_average_${TYPE}[j]=mean(maxmin_${TYPE}[j,])
}
time=array(dim=c(nmonth))
for (mm in 1:nmonth){
	time[mm]=mm
}

#
# plot of the average iqr
#
TITLE=paste("/cfu/scratch/${USER}/MSC_Project/plots/IQR_",TYPE,"_Assim.ps",sep="") 
plot_title=paste("IQR for near surface temperature ",TYPE," DePreSys Assim data",sep="")
legend_name=paste("IQR ",TYPE," data",sep="" )
maxim=max(iqr_average_${TYPE}[])
minim=min(iqr_average_${TYPE}[])
postscript(TITLE,width=550,height=550)
par(cex.main=2.2)
par(cex.axis=1.4)
par(cex.lab=1.7)
plot(time,iqr_average_${TYPE},xlim=range(time,time),ylim=range((minim),(maxim+0.05)),type="l",col="black",lwd=3,main=plot_title,xlab="Forecast time (months)",ylab="IQR (K)")
legend(0,(maxim+0.05),legend_name,lwd=3,col='black')
dev.off()
#
# plot of the average MAD
#
TITLE=paste("/cfu/scratch/${USER}/MSC_Project/plots/MAD_",TYPE,"_Assim.ps",sep="") 
plot_title=paste("Median absolute deviation for near surface \n temperature ",TYPE," DePreSys Assim data",sep="")
legend_name=paste("Mad ",TYPE," data",sep="" )
maxim=max(mad_average_${TYPE}[])
minim=min(mad_average_${TYPE}[])
postscript(TITLE,width=550,height=550)
par(cex.main=2.2)
par(cex.axis=1.4)
par(cex.lab=1.7)
plot(time,mad_average_${TYPE},xlim=range(time,time),ylim=range((minim),(maxim+0.05)),type="l",col="black",lwd=3,main=plot_title,xlab="Forecast time (months)",ylab="MAD (K)")
legend(0,(maxim+0.05),legend_name,lwd=3,col='black')
dev.off()
#
# plot of the average SD
#
TITLE=paste("/cfu/scratch/${USER}/MSC_Project/plots/SD_",TYPE,"_Assim.ps",sep="") 
plot_title=paste("Standard deviation for near surface \n temperature ",TYPE," DePreSys Assim data",sep="")
legend_name=paste("Sd ",TYPE," data",sep="" )
maxim=max(sd_average_${TYPE}[])
minim=min(sd_average_${TYPE}[])
postscript(TITLE,width=550,height=550)
par(cex.main=2.2)
par(cex.axis=1.4)
par(cex.lab=1.7)
plot(time,sd_average_${TYPE},xlim=range(time,time),ylim=range((minim),(maxim+0.05)),type="l",col="black",lwd=3,main=plot_title,xlab="Forecast time (months)",ylab="SD (K)")
legend(0,(maxim+0.05),legend_name,lwd=3,col='black')
dev.off()
#
# plot of the average MAX-MIN
#
TITLE=paste("/cfu/scratch/${USER}/MSC_Project/plots/MaxMin_",TYPE,"_Assim.ps",sep="") 
plot_title=paste("Difference of Max and Min values of ensemble members \n for near surface temperature ",TYPE," DePreSys Assim data",sep="")
legend_name=paste("Max-Min ",TYPE," data",sep="" )
maxim=max(maxmin_average_${TYPE}[])
minim=min(maxmin_average_${TYPE}[])
postscript(TITLE,width=550,height=550)
par(cex.main=2.2)
par(cex.axis=1.4)
par(cex.lab=1.7)
plot(time,maxmin_average_${TYPE},xlim=range(time,time),ylim=range((minim),(maxim+0.05)),type="l",col="black",lwd=3,main=plot_title,xlab="Forecast time (months)",ylab="Max-Min (K)")
legend(0,(maxim+0.05),legend_name,lwd=3,col='black')
dev.off()


# Centered moving averages for IQR
# nmr: number of months in the running-mean
# ntf: temporal length of the output file (f/final)
nmr=6
ntf=nmonth-(2*nmr)
iqr_smt_${TYPE}=array(dim=c(ntf)) # _smt: smoothed
counter=0
for (j in (1+nmr):(nmonth-nmr)){
    counter=counter+1
    # First, averaging the two extreme values; it takes into account half of the weight in the mean  
    iqr_smt_${TYPE}[counter]=(iqr_average_${TYPE}[j-nmr]+iqr_average_${TYPE}[j+nmr])/(2*(2*nmr))
    # Second, adding the equally-weighted values around the centered time-position 'j'
    for (k in -(nmr-1):(nmr-1)){
        iqr_smt_${TYPE}[counter]=iqr_smt_${TYPE}[counter]+(iqr_average_${TYPE}[j-k]/(2*nmr))
    }
    #ensembles_${TYPE}_smt_clim[counter,methods]=ensembles_${TYPE}_smt_clim[counter,methods]-273.15 # [ K to ºC ]
}
#
# plot the smoothed IQR
#
TITLE=paste("/cfu/scratch/${USER}/MSC_Project/plots/IQR_smt_",TYPE,"_Assim.ps",sep="") 
plot_title=paste("Smoothed IQR for near surface temperature ",TYPE," DePreSys Assim data",sep="")
legend_name=paste("IQR ",TYPE," data",sep="" )
maxim=max(iqr_smt_${TYPE}[])
minim=min(iqr_smt_${TYPE}[])
postscript(TITLE,width=550,height=550)
par(cex.main=2.2)
par(cex.axis=1.4)
par(cex.lab=1.7)
plot(time[(1+nmr):(nmonth-nmr)],iqr_smt_${TYPE},xlim=range(time,time),ylim=range((minim),(maxim+0.05)),type="l",col="black",lwd=3,main=plot_title,xlab="Forecast time (months)",ylab="IQR (K)")
legend(0,(maxim+0.05),legend_name,lwd=3,col='black')
dev.off()

# Centered moving averages for maxmin
# nmr: number of months in the running-mean
# ntf: temporal length of the output file (f/final)
nmr=6
ntf=nmonth-(2*nmr)
maxmin_smt_${TYPE}=array(dim=c(ntf)) # _smt: smoothed
counter=0
for (j in (1+nmr):(nmonth-nmr)){
    counter=counter+1
    # First, averaging the two extreme values; it takes into account half of the weight in the mean  
    maxmin_smt_${TYPE}[counter]=(maxmin_average_${TYPE}[j-nmr]+maxmin_average_${TYPE}[j+nmr])/(2*(2*nmr))
    # Second, adding the equally-weighted values around the centered time-position 'j'
    for (k in -(nmr-1):(nmr-1)){
        maxmin_smt_${TYPE}[counter]=maxmin_smt_${TYPE}[counter]+(maxmin_average_${TYPE}[j-k]/(2*nmr))
    }
    #ensembles_${TYPE}_smt_clim[counter,methods]=ensembles_${TYPE}_smt_clim[counter,methods]-273.15 # [ K to ºC ]
}
#
# plot the smoothed Max-Min
#
TITLE=paste("/cfu/scratch/${USER}/MSC_Project/plots/MaxMin_smt_",TYPE,"_Assim.ps",sep="") 
plot_title=paste("Smoothed difference of Max and Min values of ensemble \n members for near surface temperature ",TYPE," DePreSys Assim",sep="")
legend_name=paste("IQR ",TYPE," data",sep="" )
maxim=max(maxmin_smt_${TYPE}[])
minim=min(maxmin_smt_${TYPE}[])
postscript(TITLE,width=550,height=550)
par(cex.main=2.2)
par(cex.axis=1.4)
par(cex.lab=1.7)
plot(time[(1+nmr):(nmonth-nmr)],maxmin_smt_${TYPE},xlim=range(time,time),ylim=range((minim),(maxim+0.05)),type="l",col="black",lwd=3,main=plot_title,xlab="Forecast time (months)",ylab="Max-Min (K)")
legend(0,(maxim+0.05),legend_name,lwd=3,col='black',cex=1.7)
dev.off()


EOF
cat iqr
#
# run the R script
#
R CMD BATCH $WORKDIR/iqr
#
rm -rf $WORKDIR


#plot_title=paste("Air temperature smoothed ",TYPE," climatology: DePreSys and ",var," Reanalysis",sep="")
#legend_name=paste(var," Reanalysis",sep="" )
#maxim=max(reanalysis_${TYPE}_smt_clim,ensembles_${TYPE}_smt_clim[,])
#minim=min(reanalysis_${TYPE}_smt_clim,ensembles_${TYPE}_smt_clim[,])
#postscript(TITLE,width=550,height=550)
#plot(time[(1+nmr):(nmonth-nmr)],reanalysis_${TYPE}_smt_clim,xlim=range(time,time),ylim=range((minim-0.5),(maxim+0.5)),type="l",col="black",lwd=3,main=plot_title,xlab="time (months)",ylab="Temperature (K)")
#legend(0,(maxim+0.5),legend_name,lwd=3,col='black')
#for (method in 1:methods) {
#    lines(time[(1+nmr):(nmonth-nmr)],ensembles_${TYPE}_smt_clim[,method],col=colours[method])
#}
#dev.off()





