#!/bin/bash

### General Settings ###
########################
expid=b013
#members=( fc4 )
#members=( fc0 fc1 fc2 fc3 fc4 )
tmp_path=/scratch/MOC/obs
members=( opa0 )

cdo=`which cdo`
ncrename=`which ncrename`
ncatted=`which ncatted`
ncdump=`which ncdump`

cdftools=/opt/cdftools/bin 
files=/cfu/pub/scripts/CDFTOOLS/constant_files 


### Stuff for cdfmoc ###
#######################
#  Usage : cdfmoc  V file 
#  Computes the MOC for oceanic basins as described in new_maskglo.nc
#  PARTIAL CELLS VERSION
#  Files mesh_hgr.nc, mesh_zgr.nc ,new_maskglo.nc ,mask.nc 
#  must be in the current directory
#  Output on moc.nc: 
#       variables zomsfglo  : Global ocean 
#       variables zomsfatl  : Atlantic Ocean 
#       variables zomsfinp  : Indo Pacific 
#       variables zomsfind  : Indian Ocean alone
#       variables zomsfpac  : Pacific Ocean alone

grid=grid_V

exec1=cdfmoc
 ### Stuff for cdfmaxmoc ####
	###########################
	#  USAGE: cdfmaxmoc 'ovt_file.nc' cbasin latmin latmax depmin depmax [cdfout]
	#         cbasin is one of atl glo inp ind or pac 
	#  Output on standard output by default
	#  Output on netcdf is available adding cdfout as last argument

	exec2=cdfmaxmoc
	cp $cdftools/$exec2 .

	cbasin=atl
	latmin=-30
	latmax=70
	depmin=50
	depmax=5000

	para2="$cbasin $latmin $latmax $depmin $depmax "
	 prefix2=maxminmoc
	 suffix2=${depmin}-${depmax}_$cbasin
	
	### Actual Computation ###
##########################
for member in  ${members[@]}; do
        echo "******************** Start $member **********************"
	merged=moc_$member
        output2=${prefix2}_${merged}_${suffix2}
	ln -sf $cdftools/$exec2 .
	ln -sf $files/mask.nc .
	ln -sf $files/mesh_hgr.nc .
	ln -sf $files/mesh_zgr.nc .
	ln -sf $files/new_maskglo.nc .

	prefix1=moc
	suffix1=global
	output1=${prefix1}_${merged}_${suffix1}


	for t in $(seq 1 1 `$cdo ntime ${merged}.nc`); do
	  $cdo seltimestep,$t ${merged}.nc tmp.nc
	  ./$exec2 tmp.nc $para2
	  $cdo cat maxmoc.nc ${output2}.nc
	  rm maxmoc.nc tmp.nc  
	done

	unit=`$ncdump -c ${merged}.nc | grep "time:units" | cut -d '"' -f2`
	#change attribute and unit name
	$ncatted -h -a units,time,m,c,"$unit" ${output2}.nc
	$ncatted -h -a time,time,d,, ${output2}.nc
	 

	ncks -h -v time ${merged}.nc -o time.nc
	ncks -h -A time.nc ${output2}.nc
	rm time.nc
    
    echo "******************** END $member  *********************"
done

