#!/bin/sh
set -evx 

DATADIR=/tmp/${USER}/MOC
WORKDIR=/tmp/${USER}/MOC
expid=b013
MMDD=1101
YYINI=1960
YYEND=1990
YYINT=5
vars=( maxmoc latmaxmoc depthmaxmoc ) 
depthmin=50
depthmax=5000
basin=atl

# Check arguments 
#check.arg(){
#if [ "$1" = "" ]
#then
#  echo "Usage: please specify one of the arguments of global/land/sea!" 
#  exit
#fi
#}

#if [[ $ifglobal -eq 1 ]]; then 
#suffix=global
#para=""
#else
#suffix=${lonname1}-${lonname2}_${latname1}-${latname2}
#para="-sellonlatbox,$lonmin,$lonmax,$latmin,$latmax"
#fi
suffix=${depthmin}-${depthmax}_$basin
cdo=`which cdo`

title="Maximum MOC for the atlantic basin. (Sv)"



LASTYEAR=$((YYEND+5))

ndata=$(((YYEND-YYINI)/5+1)) # calculate the number of start dates
nt=$(((YYEND-YYINI+5)*12)) # number of months for ploting, et. number of timesteps

cdate=`seq $YYINI $YYINT $YYEND`
echo $ndata $cdate

cyear=""

for ((i=1;i<=$ndata;i++));do

tmpc=`echo $cdate|cut -f$i -d" "`
if [[ i -eq 1 ]]; then
cyear=${cyear}${tmpc}
else
cyear=${cyear}","${tmpc}
fi
done
echo $cyear

yy1=$YYINI
mm1=`echo $MMDD|cut -c1-2`


[[ -d $WORKDIR ]] || mkdir -p $WORKDIR
cd ${WORKDIR}
plotsdir="/tmp/${USER}/plots"
[[ -d $plotsdir ]] || mkdir -p $plotsdir
#
# Write the R script testing ncdf (in temporary plot_test in the workdir)
#
for var in ${vars[@]}; do
	$cdo selname,$var ${DATADIR}/obs/maxminmoc_opa0_${depthmin}-${depthmax}_${basin}.nc out.nc
	mv out.nc ${DATADIR}/obs/
	obs0=${DATADIR}/obs/out.nc


# 
# the following piece of code tries to extract the observational data based on the year and month
#
	nt_obs=`cdo ntime $obs0`

for ((i=1;i<=$nt_obs;i++)) do
yy=`cdo showyear -seltimestep,$i $obs0`
mm=`cdo showmon -seltimestep,$i $obs0`
if [[ $yy -eq $yy1 && $mm -eq $mm1 ]]; then
st_obs=$i
break
fi

done

#routput=sst_${expid}_${suffix}_${YYINI}-${YYEND}.ps
output=${var}_${expid}_${YYINI}-${YYEND}.png

#ghnc=${DATADIR}/ghnc/gm_tas_ghcn.nc

cat>$WORKDIR/plot_test<<EOF

library(ncdf)

${var}_model=array(dim=c($nt,5,$ndata))
${var}_obs=array(dim=c($nt,5))

for (i in c($cyear)) {
for (j in c("0","1","2","3","4")) {
file=paste("${DATADIR}/${expid}/",i,"${MMDD}/fc",j,"/maxminmoc_${expid}_",i,"$MMDD","_fc",j,"_${suffix}.nc",sep="")
fnc=open.ncdf(file)
tvar=get.var.ncdf(fnc,"$var")
index_j=as.integer(j)+1
index_i=(as.integer(i)-1960)/5+1
index_t1=((as.integer(i)-1960)/5)*60+1
index_t2=index_t1+59
${var}_model[index_t1:index_t2,index_j,index_i]=tvar
}
}


file=paste("${obs0}",sep="")
fnc=open.ncdf(file)
tvar=get.var.ncdf(fnc,"$var")
index_j=as.integer(j)+1
index_t1=as.integer(${st_obs})
index_t2=index_t1+$nt-1
${var}_obs[,index_j]=tvar[index_t1:index_t2]


empty=array(dim=$nt)
empty_ts=ts(empty,start=c($YYINI,11),end=c($LASTYEAR,10),frequency=12)



ulimit=max(${var}_obs,${var}_model,na.rm=TRUE)+0.5
llimit=min(${var}_obs,${var}_model,na.rm=TRUE)-0.5
#
#postscript("$plotsdir/${output}",width=550,height=300)
png("$plotsdir/${output}",width=550,height=300)

plot(empty_ts,ylim=c(llimit,ulimit),ylab="")

par(new=TRUE)
matplot(${var}_obs,lty=1,type="l",ylim=c(llimit,ulimit),col=1,ylab="${title}",main="Time series of ${title}",labels=FALSE,axes=FALSE)



color=rainbow($ndata)
for (i in 1:$ndata) {
par(new=TRUE)
matplot(${var}_model[,1:5,i],type="l",lty=c(1),ylim=c(llimit,ulimit),col=color[i],ylab="",labels=FALSE,axes=FALSE)
} 

par(new=TRUE)
#matplot(t2[,1:5,1],type="l",ylim=c(llimit,ulimit),col=2:6,ylab="",labels=FALSE,axes=FALSE)
par(new=TRUE)
#matplot(t2[,1:5,2],type="l",ylim=c(llimit,ulimit),col=2:6,ylab="",labels=FALSE,axes=FALSE)
#par(new=TRUE)
#matplot(t2[,1:5,3],type="l",ylim=c(llimit,ulimit),col=2:6,ylab="",labels=FALSE,axes=FALSE)
par(xpd=TRUE)
#legend(0,ulimit,c("Ncep Reanalysis","fc0","fc1","fc2","fc3","fc4"),lwd=c(1,1),col=1:6)
legend(0,ulimit,"NEMOVAR",lwd=1,col=1)


dev.off()
#
# Closing the R script
#
EOF
#cat plot_test # uncommented: it shows the R script in the screen
#
# Run the R script
#
R CMD BATCH $WORKDIR/plot_test
echo "Please go to ${plotsdir} to check the plots and the log files"
cp plot_test  /cfu/scratch/$USER/log 
cp plot_test.Rout  /cfu/scratch/$USER/log
#
chmod 775 ${plotsdir}/${output}
eog ${plotsdir}/${output}
rm ${DATADIR}/obs/out.nc
done
