#!/bin/sh
set -evx 

DATADIR=/tmp/${USER}/MOC
WORKDIR=/tmp/${USER}/MOC
expid=b014
MMDD=1101
YYINI=1960
YYEND=2005
YYINT=5
vars=( maxmoc latmaxmoc depthmaxmoc ) 
depthmin=50
depthmax=5000
basin=atl

suffix=${depthmin}-${depthmax}_$basin
cdo=`which cdo`

LASTYEAR=$((YYEND+5))

ndata=$(((YYEND-YYINI)/5+1)) # calculate the number of start dates
nt=$(((YYEND-YYINI+5)*12)) # number of months for ploting, et. number of timesteps

cdate=`seq $YYINI $YYINT $YYEND`
echo $ndata $cdate

cyear=""

for ((i=1;i<=$ndata;i++));do

tmpc=`echo $cdate|cut -f$i -d" "`
if [[ i -eq 1 ]]; then
cyear=${cyear}${tmpc}
else
cyear=${cyear}","${tmpc}
fi
done
echo $cyear

yy1=$YYINI
mm1=`echo $MMDD|cut -c1-2`


[[ -d $WORKDIR ]] || mkdir -p $WORKDIR
cd ${WORKDIR}
plotsdir="/tmp/${USER}/plots"
[[ -d $plotsdir ]] || mkdir -p $plotsdir
#
# Write the R script testing ncdf (in temporary plot_test in the workdir)
#
obs0=${DATADIR}/nemovar/opa0/maxminmoc_nemovar_opa0_${depthmin}-${depthmax}_${basin}.nc 


# 
# the following piece of code tries to extract the observational data based on the year and month
#
nt_obs=`cdo ntime $obs0`

for ((i=1;i<=$nt_obs;i++)) do
yy=`cdo showyear -seltimestep,$i $obs0`
mm=`cdo showmon -seltimestep,$i $obs0`
if [[ $yy -eq $yy1 && $mm -eq $mm1 ]]; then
st_obs=$i
break
fi

done
output=MaxMoc_${expid}_${YYINI}-${YYEND}_${suffix}.png

cat>$WORKDIR/plot_test<<EOF

library(ncdf)
png("$plotsdir/${output}",width=800,height=600)
par(mfrow=c(3,1))


for (v in c("maxmoc","latmaxmoc","depthmaxmoc")) {
#for (v in c("depthmaxmoc")) {
maxmoc_model=array(dim=c($nt,5,$ndata))
maxmoc_obs=array(dim=c($nt,5))

for (i in c($cyear)) {
for (j in c("0","1","2","3","4")) {
#for (j in c("0")) {
file=paste("${DATADIR}/${expid}/",i,"${MMDD}/fc",j,"/maxminmoc_${expid}_",i,"$MMDD","_fc",j,"_${suffix}.nc",sep="")
fnc=open.ncdf(file)
tvar=get.var.ncdf(fnc,v)
index_j=as.integer(j)+1
index_i=(as.integer(i)-${YYINI})/${YYINT}+1
index_t1=((as.integer(i)-${YYINI})/${YYINT})*${YYINT}*12+1
index_t2=index_t1+${YYINT}*12-1
print(index_j)
print(index_i)
print(index_t1)
print(index_t2)
maxmoc_model[index_t1:index_t2,index_j,index_i]=tvar
}
}


for (j in c("0","1","2","3","4")) {
#for (j in c("0")) {
file=paste("${DATADIR}/nemovar/opa",j,"/maxminmoc_nemovar_opa",j,"_${depthmin}-${depthmax}_${basin}.nc",sep="")
fnc=open.ncdf(file)
#longname=
longname=att.get.ncdf(fnc,v,"long_name")\$value
print(longname)
title=paste("Time series of ",longname, " from $YYINI until $YYEND")

tvar=get.var.ncdf(fnc,v)
index_j=as.integer(j)+1
index_t1=as.integer(${st_obs})
index_t2=index_t1+$nt-1
maxmoc_obs[,index_j]=tvar[index_t1:index_t2]
}

empty=array(dim=$nt)
empty_ts=ts(empty,start=c($YYINI,11),end=c($LASTYEAR,10),frequency=12)

ulimit=max(maxmoc_obs,maxmoc_model,na.rm=TRUE)+0.5
print(ulimit)
llimit=min(maxmoc_obs,maxmoc_model,na.rm=TRUE)-0.5
print(llimit)
if ( v==c("depthmaxmoc") ) {
llimit=max(maxmoc_obs,maxmoc_model,na.rm=TRUE)+0.5
print(ulimit)
ulimit=min(maxmoc_obs,maxmoc_model,na.rm=TRUE)-0.5
print(llimit)
}

#
#postscript("$plotsdir/${output}",width=550,height=300)

plot(empty_ts,ylim=c(llimit,ulimit),ylab="")
par(new=TRUE)
matplot(maxmoc_obs,lty=1,type="l",ylim=c(llimit,ulimit),col=1,ylab=longname,main=title,labels=FALSE,axes=FALSE)



color=rainbow($ndata)
for (i in 1:$ndata) {
par(new=TRUE)
matplot(maxmoc_model[,1:5,i],type="l",lty=c(1),ylim=c(llimit,ulimit),col=color[i],ylab="",labels=FALSE,axes=FALSE)
} 
}


dev.off()
#
# Closing the R script
#
EOF
#cat plot_test # uncommented: it shows the R script in the screen
#
# Run the R script
#
R CMD BATCH $WORKDIR/plot_test
echo "Please go to ${plotsdir} to check the plots and the log files"
cp plot_test  /cfu/scratch/$USER/log 
cp plot_test.Rout  /cfu/scratch/$USER/log
#
chmod 775 ${plotsdir}/${output}
eog ${plotsdir}/${output}
