#!/bin/bash
set -evx
#
# This script is to compute ocean heat content of from EC-Earth output .
#
# Written by Hui Du (based on "/gpfs/projects/ecm86/common/cdftools/scripts/cdfheatc.sh" on BSC)
#
# Created:   October 1, 2010
#

cd /cfu/scratch/huidu/cdfheatc_28904

imin=0
imax=0
jmin=0
jmax=0
kmin=1
kmax=24



### General Settings ###
########################
export NCARG_ROOT=/opt/ncl

##### Beginning of user's modifications################################ 


merged=b013_19851101_fc0_ORCA1
output=ohc_b013_19851101_fc0_ORCA1_0-657_global


  ntime=`cdo ntime ${merged}.nc`;
  for t in $(seq 1 1 $ntime); do
   cdo seltimestep,$t ${merged}.nc tmp.nc
   ./cdfheatc tmp.nc $para > tmp.log
   thc=`cat tmp.log | grep "Total Heat content :" | awk '{print $5}'`;
   uhc=`cat tmp.log | grep "Total Heat content/volume" | awk '{print $5}'`;
   echo $t $thc $uhc >> ${output}.txt

### create fill.ncl ###
#######################
cat > fill.ncl << EOF
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
;***********************************
begin

 foutput=addfile("${output}.nc","w")
 fmerged=addfile("${merged}.nc","w")
 foutput->thc($t-1)=$thc
 foutput->uhc($t-1)=$uhc
 foutput->time($t-1)=fmerged->time($t-1)

end
EOF
### fill.ncl created ###
   ncl fill.ncl

   rm -rf fill*
   rm -rf tmp*
  done

  thc_min=`cat ${output}.txt | awk '{print $2}' | sort -n | head -1`;
  thc_max=`cat ${output}.txt | awk '{print $2}' | sort -n | tail -n 1`;
  ncatted -h -a valid_min,thc,m,f,$thc_min ${output}.nc
  ncatted -h -a valid_max,thc,m,f,$thc_max ${output}.nc

  uhc_min=`cat ${output}.txt | awk '{print $3}' | sort -n | head -1`;
  uhc_max=`cat ${output}.txt | awk '{print $3}' | sort -n | tail -n 1`;
  ncatted -h -a valid_min,uhc,m,f,$uhc_min ${output}.nc
  ncatted -h -a valid_max,uhc,m,f,$uhc_max ${output}.nc
  
  units=`$ncdump -c ${merged}.nc | grep "time:units" | cut -d '"' -f2`;
  ncatted -h -a units,time,m,c,"$units" ${output}.nc
  ncatted -h -a time,time,d,, ${output}.nc

  echo
  ls -lrth
  rm -rf MMO_${expid}_${year}_${member}_*
  rm -rf ORCA1_MM_*
  rm -rf ${merged}.nc
  echo
  echo "******************** END $member  *********************"

done

 echo "******************** END $year  *********************"

done

mv ohc*.nc ${save_dir}; mv ohc*.txt ${save_dir}

cd ~

rm -rf ${tmp_dir}
date

