#bin/bash
set -evx


#
# This script is to compute global mean values of SST from the ocean output of EC-Earth .
#
# Written by Hui Du
#
# Created:   October 8, 2010
#



######### Begin of user modifications#########################
grid=grid_T
EXP="b013"  # experiment ID
seasons="1101"  # 
mems=( fc0 fc1 fc2 fc3 fc4 )
var=sosstsst
yyini=1990
yyend=2005
yyint=5
save_dir="/cfu/scratch/$USER/sst/${EXP}"
WORKDIR="/tmp/$USER/sst_$$"
ferret='/opt/ferret/bin/ferret'
mask_file=ecearth_mm_lsm.nc
PATH_MASK="/cfu/pub/scripts/CDFTOOLS/constant_files"
script_dir="/cfu/pub/scripts/CDFTOOLS/scripts"
ifglobal=0  # If calculate global mean or regional, set it as 1 for global, otherwise, set it to 0

lonmin=-180
lonmax=180
latmin=-60
latmax=65

######### End of user modifications########################


export FER_GO=.
export FER_DATA=.


#
# Parameters
#
#
# Working directory
#


[[ -d $save_dir ]] || mkdir -p $save_dir


[[ -d $WORKDIR ]] || mkdir -p $WORKDIR

cd ${WORKDIR}



###
if [[ $latmin -lt 0 ]]; then
latname1=$((latmin*-1))S
elif [[ $latmin -eq 0 ]];then
latname1=$latmin
else [[ $latmin -gt 0 ]]
latname1=${latmin}N
fi


if [[ $latmax -lt 0 ]];then
latname2=$((latmax*-1))S
elif [[ $latmax -eq 0 ]];then
latname2=$latmax
else 
[[ $latmax -gt 0 ]]
latname2=${latmax}N
fi



if [[ $lonmin -lt 0 ]]; then
lonname1=$((lonmin*-1))W
elif [[ $lonmin -eq 0 ]];then
lonname1=$lonmin
else [[ $lonmin -gt 0 ]]
lonname1=${lonmin}E
fi


if [[ $lonmax -lt 0 ]];then
lonname2=$((lonmax*-1))W
elif [[ $lonmax -eq 0 ]];then
lonname2=$lonmax
else
[[ $lonmax -gt 0 ]]
lonname2=${lonmax}E
fi

if [[ $ifglobal -eq 1 ]]; then 
suffix=global
para=""
else
suffix=${lonname1}-${lonname2}_${latname1}-${latname2}
para="-sellonlatbox,$lonmin,$lonmax,$latmin,$latmax"
fi



####




###############################################################################################
#
# while looping over the list of variables it stores the name of the variable in the nc file
#
#for VAR in ${VAR_LST} ; do
#    case ${VAR} in
#        hflsd) NCNAME=lhtfl
#	       mask_name=land_sea_gaussian_mask.nc
#	       SUF=_step6h
#        ;;
#        hfssd) NCNAME=shtfl
#	       mask_name=land_sea_gaussian_mask.nc
#	       SUF=_step6h
#        ;;
#	psl) NCNAME=slp
#	     mask_name=land_sea_mask.nc
#	     SUF=_6hourly
#        ;;
#	rls) NCNAME=nlwrs 
#	     mask_name=land_sea_gaussian_mask.nc
#	     SUF=_step6h
#        ;;
#	rss) NCNAME=nswrs
#             mask_name=land_sea_gaussian_mask.nc
#	     SUF=_step6h
#	;;
#	tas) NCNAME=air
#	     SUF=_6hourly
#	     mask_name=land_sea_gaussian_mask.nc
#        ;;
#    esac 
############################################################################################3

   
#    cdo gtc,0.5 ${PATH_MASK}/${mask_file} MASK_land ## Create the mask for the land

#    cdo ltc,0.5 ${PATH_MASK}/${mask_file} MASK_sea  ##Create the mask for the ocean

# create ferret file for interpolating model output from ORCA1 grid to regular grid


ferret='/opt/ferret/bin/ferret'
script_file="ferret_script.jnl"

cp ${script_dir}/orca_interp.jnl .
cp ${PATH_MASK}/OPAT_to_2x2.nc .

cat >${script_file} <<EOF
go orca_interp.jnl $var.nc
let/unit="Celsius"/title="NEMO Sea Surface Temperature" SST=sosstsst1[k=1]
set memory/size=2000
save/file="SST_mon_2x2.nc"/clobber SST
EOF
#echo "go ${script_file}; quit" | ${ferret} -nojnl -gif
#rm -f ${script_file}




for expid in ${EXP}; do  # loop for experiments 

for season in ${seasons}; do #loop for seasons

for mem in ${mems[@]}; do # loop for numbers


    year=$yyini
    #
    # Loop to copy only the files of the specific period
    #
    while [[ ${year} -le ${yyend} ]];  do  # loop for starting years

        sdate=${year}${season}
        data_path=/scratch/${expid}/${sdate}/${mem}

        for file in `ls ${data_path}/MMO*.tar`; do 
	 grid_T_file=`tar tf ${file}|grep ${grid}` 
         tar xvf ${file} ${grid_T_file}
	 gunzip ${grid_T_file}
	done


        
        for file in `ls ORCA1*${grid}*.nc`;do
	
	cdo -selname,${var} ${file} ${var}_${file}
	rm -f ${file}
	done       
         
	files=`ls ${var}*.nc`
        cdo mergetime ${files} ${var}.nc
        echo "go ${script_file}; quit" | ${ferret} -nojnl -gif

        OUTFILE=gm_sst_${expid}_${sdate}_${mem}_$suffix.nc

        cdo fldmean $para SST_mon_2x2.nc ${OUTFILE}
        #
        # Apply the mask to toto1.nc
        #
        # I delete lat and lon and save the rest into toto3_${TYPE}.nc
      #  ncwa -O -h -a lat,lon toto2_${TYPE}.nc toto3_${TYPE}.nc
        # I put the info that I want plus the data of the global mean in a new file
      #  ncks -O -h -v ${NCNAME},time toto3_${TYPE}.nc -o toto4_${TYPE}.nc
        #
        # Writing the output
        #

        rm -f ${var}*.nc SST_mon_2x2.nc #clean up

        year=$((year+yyint))
  
 # save data     
     mkdir -p ${save_dir}/${sdate}
     mv ${OUTFILE} ${save_dir}/${sdate}
   
    done  #loop for years (start dates)


 done # loop for seasons
 done # loop for members
 done # loop for expid


cd

rm -rf $WORKDIR

