#bin/bash
set -evx


#
# This script is to compute global mean values of SST from NEMOVAR.
#
# Written by Hui Du
#
# Created:   October 8, 2010
#



######### Begin of user modifications#########################

ferret='/opt/ferret/bin/ferret'
grid=grid_T
expid="fa9p"  # experiment ID
seasons="1101"  # 
mems="0 1 2 3 4"
mems=( 0 )
var=sosstsst
yyint=5
save_dir="/cfu/scratch/$USER/sst/nemovar"
WORKDIR="/cfu/scratch/$USER/$$"
ferret='/opt/ferret/bin/ferret'
PATH_MASK="/cfu/pub/scripts/CDFTOOLS/constant_files"
script_dir="/cfu/pub/scripts/CDFTOOLS/scripts"
data_dir="/cfu/data/EC-Earth/prepIFS/${expid}"
ncl=/opt/ncl/bin/ncl
ncatted=/usr/local/bin/ncatted
ncrename=/usr/local/bin/ncrename
ifglobal=1  # If calculate global mean or regional, set it as 1 for global, otherwise, set it to 0

lonmin=-180
lonmax=180
latmin=-60
latmax=65
sec=3600
timeunit=hours
######### End of user modifications########################

export NCARG_ROOT=/opt/ncl  # Set NCARG environment for using NCL
export FER_GO=.
export FER_DATA=.

#
# Parameters
#
#
# Working directory
#


[[ -d $save_dir ]] || mkdir -p $save_dir


[[ -d $WORKDIR ]] || mkdir -p $WORKDIR

cd ${WORKDIR}



###
if [[ $latmin -lt 0 ]]; then
latname1=$((latmin*-1))S
elif [[ $latmin -eq 0 ]];then
latname1=$latmin
else [[ $latmin -gt 0 ]]
latname1=${latmin}N
fi


if [[ $latmax -lt 0 ]];then
latname2=$((latmax*-1))S
elif [[ $latmax -eq 0 ]];then
latname2=$latmax
else 
[[ $latmax -gt 0 ]]
latname2=${latmax}N
fi



if [[ $lonmin -lt 0 ]]; then
lonname1=$((lonmin*-1))W
elif [[ $lonmin -eq 0 ]];then
lonname1=$lonmin
else [[ $lonmin -gt 0 ]]
lonname1=${lonmin}E
fi


if [[ $lonmax -lt 0 ]];then
lonname2=$((lonmax*-1))W
elif [[ $lonmax -eq 0 ]];then
lonname2=$lonmax
else
[[ $lonmax -gt 0 ]]
lonname2=${lonmax}E
fi

if [[ $ifglobal -eq 1 ]]; then 
suffix=global
para=""
else
suffix=${lonname1}-${lonname2}_${latname1}-${latname2}
para="-sellonlatbox,$lonmin,$lonmax,$latmin,$latmax"
fi

#

cd $data_dir/opa0/outputs; ls *${grid}* > $WORKDIR/tmp.txt; cd $WORKDIR

cut -f3 -d"_" tmp.txt|cut -c1-6 > date.txt; rm -f tmp.txt

nt=`cat date.txt|wc -l`
yy=`head -1 date.txt|cut -c1-4`
mm=`head -1 date.txt|cut -c5-6`
sdate=${yy}-${mm}-1
####





##
date2stamp () {
    date --utc --date "$1" +%s
}

stamp2date (){
    date --utc --date "$sdate $1 sec" "+%Y-%m-%d %T"
}


dateDiff (){
    case $1 in
        -s)   sec=1; timeunit=seconds;     shift;;
        -m)   sec=60;timeunit=minutes;     shift;;
        -h)   sec=3600; timeunit=hours;  shift;;
        -d)   sec=86400; timeunit=days; shift;;
        *)    sec=86400; timeunit=seconds;
    esac
    dte1=$(date2stamp $1)
    dte2=$(date2stamp $2)
    diffSec=$((dte2-dte1))
    if ((diffSec < 0)); then abs=-1; else abs=1; fi
    echo $((diffSec/sec*abs))
    value=$((diffSec/sec*abs))
    return $value
}



###

# create NCL scritps

cat>addtime.ncl << EOF
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
;***********************************
begin
 f=addfile("ncl.nc","w")
 f->TIME(t-1)=tvalue
end
EOF
# end of creating NCL scritps
#

# get the year and month of NEMOVAR data for adding time because NEMOVAR files do not have any time information.
# the only way to calculate time is to by using year and month from the file name



#
#


############################################################################################3


# create ferret file for interpolating model output from ORCA1 grid to regular grid


script_file="ferret_script.jnl"

cp ${script_dir}/orca_interp.jnl .
cp ${PATH_MASK}/OPAT_to_2x2.nc .

cat >${script_file} <<EOF
go orca_interp.jnl $var.nc
let/unit="Celsius"/title="NEMOVAR Sea Surface Temperature" SST=sosstsst1[k=1]
set memory/size=2000
save/file="SST_mon_2x2.nc"/clobber SST
EOF
#echo "go ${script_file}; quit" | ${ferret} -nojnl -gif
#rm -f ${script_file}


for mem in ${mems[@]}; do # loop for numbers

	OUTFILE=nemovar_sst_fc${mem}.nc
       data_path=${data_dir}/opa${mem}/outputs
    #
    # Loop to copy only the files of the specific period
    #
   for ((i=1;i<=$nt;i++)); do
	yymm=`head -$i date.txt|tail -1`
        cp ${data_path}/${expid}*${yymm}*${grid}* .
        wait

        file=`ls ${expid}*${yymm}*${grid}*.gz` 
	gunzip ${file}
 	file=`ls ${expid}*${yymm}*${grid}*.nc`	
        
	cdo -selname,${var} ${file} tmp.nc; cdo cat tmp.nc ${var}.nc; rm -f ${file} tmp.nc
         
    done #loop for times steps




#	cdo mergetime tmp_${var}_*.nc ${var}.nc; rm -f tmp_${var}_*.nc 
        echo "go ${script_file}; quit" | ${ferret} -nojnl -gif; rm ${var}.nc
	
	mv SST_mon_2x2.nc ncl.nc
	chmod 775 ncl.nc
	dte1=`date2stamp $sdate`
	for ((step=1;step<=$nt;step++));do
        yy=`head -$step date.txt|tail -1|cut -c1-4`
        mm=`head -$step date.txt|tail -1|cut -c5-6`
	tmp=${yy}-${mm}-1
	dte2=`date2stamp $tmp`
	diffSec=$((dte2-dte1))
	if ((diffSec < 0)); then abs=-1; else abs=1; fi
	value=$((diffSec/sec*abs))


	ncl addtime.ncl t=$step tvalue=$value

	done


#	$ncrename -h -v TIME,time ncl.nc
	$ncatted -h -a units,TIME,c,c,"${timeunit} since ${sdate} 00:00:00" ncl.nc 
	mv ncl.nc ${save_dir}/$OUTFILE

 ##     cdo fldmean $para SST_mon_2x2.nc ${OUTFILE}
        #
        # Apply the mask to toto1.nc
        #
        # I delete lat and lon and save the rest into toto3_${TYPE}.nc
      #  ncwa -O -h -a lat,lon toto2_${TYPE}.nc toto3_${TYPE}.nc
        # I put the info that I want plus the data of the global mean in a new file
      #  ncks -O -h -v ${NCNAME},time toto3_${TYPE}.nc -o toto4_${TYPE}.nc
        #
        # Writing the output
        #

# add time information to the output



done # loop for members


cd

rm -rf $WORKDIR

