#bin/bash
#$ -N gm_model_sst.gg
#$ -S /bin/bash
#$ -o /share/scratch/cfu/$USER/logs
#$ -j y
set -evx
# modules setup
source /opt/modules/init/bash

# setup the intel env variables
module load intel/intel-11

# setup the mpi env
module load openmpi/intel-11

# netcdf module
module load netcdf3.6.3/intel11

# request sge only run the job on infiniband enabled nodes

# tell OpenMPI to only use infiniband
export OMPI_MCA_btl=openib,sm,self
export PATH=/share/apps/nco-3.9.9/intel11/bin:$PATH
export PATH=/share/apps/cdo-1.4.5.1/intel11/bin:$PATH


#
# This script is to compute global mean values of 2-meter temperature from the "GG" files from EC-Earth output .
#
# Written by Hui Du (based on Danilla's script)
#
# Created:   October 1, 2010
#



######### Begin of user modifications#########################
EXP="b014"  # experiment ID
MMDD_LST="1101"  # 
MEMBER_LST=( fc0 fc1 fc2 fc3 fc4 )
MEMBER_LST=( fc2 fc3 fc4 )
#MEMBER_LST=( fc4 )
VARS="SSTK"
YYINI=1960
YYEND=1960
YYINT=5
SAVEDIR="/share/scratch/cfu/$USER/analysis/sst/${EXP}"
DATADIR="/share/data/cfu/exp/ecearth/"
WORKDIR="/share/scratch/cfu/$USER/tmp/gm_sst.gg_$$"
MASK_FILE=ecearth_mm_lsm.nc
PATH_MASK="/share/data/cfu/tools/CDFTOOLS/constant_files"
IFGLOBAL=0  # If calculate global mean or regional, set it as 1 for global, otherwise, set it to 0

LONMIN=-180
LONMAX=180
LATMIN=-60
LATMAX=65

######### End of user modifications########################


#
# Parameters
#
#
# Working directory
#


[[ -d $SAVEDIR ]] || mkdir -p $SAVEDIR


[[ -d $WORKDIR ]] || mkdir -p $WORKDIR

cd ${WORKDIR}


###
if [[ $LATMIN -lt 0 ]]; then
latname1=$((LATMIN*-1))S
elif [[ $LATMIN -eq 0 ]];then
latname1=$LATMIN
else [[ $LATMIN -gt 0 ]]
latname1=${LATMIN}N
fi


if [[ $LATMAX -lt 0 ]];then
latname2=$((LATMAX*-1))S
elif [[ $LATMAX -eq 0 ]];then
latname2=$LATMAX
else 
[[ $LATMAX -gt 0 ]]
latname2=${LATMAX}N
fi



if [[ $LONMIN -lt 0 ]]; then
lonname1=$((LONMIN*-1))W
elif [[ $LONMIN -eq 0 ]];then
lonname1=$LONMIN
else [[ $LONMIN -gt 0 ]]
lonname1=${LONMIN}E
fi


if [[ $LONMAX -lt 0 ]];then
lonname2=$((LONMAX*-1))W
elif [[ $LONMAX -eq 0 ]];then
lonname2=$LONMAX
else
[[ $LONMAX -gt 0 ]]
lonname2=${LONMAX}E
fi

if [[ $IFGLOBAL -eq 1 ]]; then 
suffix=global
para=""
else
suffix=${lonname1}-${lonname2}_${latname1}-${latname2}
para="-sellonlatbox,$LONMIN,$LONMAX,$LATMIN,$LATMAX"
fi



####




###############################################################################################
#
# while looping over the list of variables it stores the name of the variable in the nc file
#
#for VAR in ${VAR_LST} ; do
#    case ${VAR} in
#        hflsd) NCNAME=lhtfl
#	       mask_name=land_sea_gaussian_mask.nc
#	       SUF=_step6h
#        ;;
#        hfssd) NCNAME=shtfl
#	       mask_name=land_sea_gaussian_mask.nc
#	       SUF=_step6h
#        ;;
#	psl) NCNAME=slp
#	     mask_name=land_sea_mask.nc
#	     SUF=_6hourly
#        ;;
#	rls) NCNAME=nlwrs 
#	     mask_name=land_sea_gaussian_mask.nc
#	     SUF=_step6h
#        ;;
#	rss) NCNAME=nswrs
#             mask_name=land_sea_gaussian_mask.nc
#	     SUF=_step6h
#	;;
#	tas) NCNAME=air
#	     SUF=_6hourly
#	     mask_name=land_sea_gaussian_mask.nc
#        ;;
#    esac 
############################################################################################3

   
    cdo gtc,0.5 ${PATH_MASK}/${MASK_FILE} MASK_land ## Create the mask for the land

    cdo ltc,0.5 ${PATH_MASK}/${MASK_FILE} MASK_sea  ##Create the mask for the ocean


for expid in ${EXP}; do  # loop for experiments 

for season in ${MMDD_LST}; do #loop for MMDD_LST

for mem in ${MEMBER_LST[@]}; do # loop for numbers

for var in ${VARS}; do # loop for variables 


    year=$YYINI
    #
    # Loop to copy only the files of the specific period
    #
    while [[ ${year} -le ${YYEND} ]];  do  # loop for starting years

        sdate=${year}${season}
        data_path=${DATADIR}/${expid}/${sdate}/${mem}/outputs
    #    cp ${data_path}/MMA* .
    #    scp forseti:${data_path}/MMA* .

        for file in `ls ${data_path}/MMA*.tar`; do 
	 file1=`tar tf ${file}|grep GG` 
	 for file2 in ${file1};do
	 tar xvf ${file} ${file2} 
	 done
	done

	gunzip *GG*.gz
        
        for file in `ls MMA*GG*.nc`;do
	
	cdo seltimestep,1 -selname,${var} ${file} ${var}_${file}
	rm -f ${file}
	done       
         
	files=`ls ${var}*.nc`
        cdo mergetime ${files} ${var}.nc

	for TYPE in land sea global ; do
        OUTFILE=gm_${var}_${TYPE}_${expid}_${sdate}_${mem}_$suffix.nc
        #
        # Apply the mask to toto1.nc
        #
        if [[ $TYPE = "land" || $TYPE = "sea" ]] ; then
           cdo ifthen MASK_${TYPE} ${var}.nc ${var}_${TYPE}.nc
        else
           cp ${var}.nc ./${var}_${TYPE}.nc
        fi
        #
        # Compute the global mean of toto1_* and store it in toto2_*.nc
        #
        cdo fldmean $para ${var}_${TYPE}.nc ${OUTFILE}
        # I delete lat and lon and save the rest into toto3_${TYPE}.nc
      #  ncwa -O -h -a lat,lon toto2_${TYPE}.nc toto3_${TYPE}.nc
        # I put the info that I want plus the data of the global mean in a new file
      #  ncks -O -h -v ${NCNAME},time toto3_${TYPE}.nc -o toto4_${TYPE}.nc
        #
        # Writing the output
        #
	done  # loop for types (for example, land, ocean and global)

        rm -f ${var}*.nc #clean up

        year=$((year+YYINT))
  
 # save data     
     mkdir -p ${SAVEDIR}/${sdate}
     mv gm_${var}*.nc ${SAVEDIR}/${sdate}
   
    done  #loop for years (start dates)

 done # loop for variables 

 done # loop for MMDD_LST
 done # loop for members
 done # loop for expid


cd

rm -rf $WORKDIR

