#bin/bash

#$ -N gm_sst 
#$ -S /bin/bash
#$ -o /share/scratch/cfu/$USER/logs
#$ -j y

set -evx
# modules setup
source /opt/modules/init/bash

# setup the intel env variables
module load intel/intel-11

# setup the mpi env
module load openmpi/intel-11

# netcdf module
module load netcdf3.6.3/intel11

# request sge only run the job on infiniband enabled nodes

# tell OpenMPI to only use infiniband
export OMPI_MCA_btl=openib,sm,self
export PATH=/share/apps/nco-3.9.9/intel11/bin:$PATH
export PATH=/share/apps/cdo-1.4.5.1/intel11/bin:$PATH
export PATH=/share/apps/ferret/bin:$PATH


##############################################################################################################################
# This script is to compute global mean values of SST from the ocean output (NEMO ORCA1 files) of EC-Earth .
#
# Written by Hui Du
#
# Created:   October 8, 2010
##############################################################################################################################



######### Begin of user modifications#########################
grid=grid_T
EXP="b014"  # experiment ID
MMDD_LST="1101"  # 
MEMBER_LST=( fc0 fc1 fc2 fc3 fc4 )
#MEMBER_LST=( fc4 )
var=sosstsst
YYINI=1990
YYEND=2005
YYINT=5
SAVEDIR="/share/scratch/cfu/${USER}/analysis/sst/${EXP}"
DATADIR="/share/data/cfu/exp/ecearth"
WORKDIR="/share/scratch/cfu/$USER/tmp/sst_$JOB_ID"
MASK_FILE=ecearth_mm_lsm.nc
PATH_MASK="/share/data/cfu/tools/CDFTOOLS/constant_files"
SCRIPTDIR="/share/data/cfu/tools/CDFTOOLS/scripts"
IFGLOBAL=0  # If calculate global mean or regional, set it as 1 for global, otherwise, set it to 0

LONMIN=-180
LONMAX=180
LATMIN=-60
LATMAX=65

######### End of user modifications########################

export FER_GO=.
export FER_DATA=.


#
# Parameters
#
#
# Working directory
#


[[ -d $SAVEDIR ]] || mkdir -p $SAVEDIR


[[ -d $WORKDIR ]] || mkdir -p $WORKDIR

cd ${WORKDIR}



###
if [[ $LATMIN -lt 0 ]]; then
latname1=$((LATMIN*-1))S
elif [[ $LATMIN -eq 0 ]];then
latname1=$LATMIN
else [[ $LATMIN -gt 0 ]]
latname1=${LATMIN}N
fi


if [[ $LATMAX -lt 0 ]];then
latname2=$((LATMAX*-1))S
elif [[ $LATMAX -eq 0 ]];then
latname2=$LATMAX
else 
[[ $LATMAX -gt 0 ]]
latname2=${LATMAX}N
fi



if [[ $LONMIN -lt 0 ]]; then
lonname1=$((LONMIN*-1))W
elif [[ $LONMIN -eq 0 ]];then
lonname1=$LONMIN
else [[ $LONMIN -gt 0 ]]
lonname1=${LONMIN}E
fi


if [[ $LONMAX -lt 0 ]];then
lonname2=$((LONMAX*-1))W
elif [[ $LONMAX -eq 0 ]];then
lonname2=$LONMAX
else
[[ $LONMAX -gt 0 ]]
lonname2=${LONMAX}E
fi

if [[ $IFGLOBAL -eq 1 ]]; then 
suffix=global
para=""
else
suffix=${lonname1}-${lonname2}_${latname1}-${latname2}
para="-sellonlatbox,$LONMIN,$LONMAX,$LATMIN,$LATMAX"
fi



####




###############################################################################################
#
# while looping over the list of variables it stores the name of the variable in the nc file
#
#for VAR in ${VAR_LST} ; do
#    case ${VAR} in
#        hflsd) NCNAME=lhtfl
#	       mask_name=land_sea_gaussian_mask.nc
#	       SUF=_step6h
#        ;;
#        hfssd) NCNAME=shtfl
#	       mask_name=land_sea_gaussian_mask.nc
#	       SUF=_step6h
#        ;;
#	psl) NCNAME=slp
#	     mask_name=land_sea_mask.nc
#	     SUF=_6hourly
#        ;;
#	rls) NCNAME=nlwrs 
#	     mask_name=land_sea_gaussian_mask.nc
#	     SUF=_step6h
#        ;;
#	rss) NCNAME=nswrs
#             mask_name=land_sea_gaussian_mask.nc
#	     SUF=_step6h
#	;;
#	tas) NCNAME=air
#	     SUF=_6hourly
#	     mask_name=land_sea_gaussian_mask.nc
#        ;;
#    esac 
############################################################################################3

   
#    cdo gtc,0.5 ${PATH_MASK}/${MASK_FILE} MASK_land ## Create the mask for the land

#    cdo ltc,0.5 ${PATH_MASK}/${MASK_FILE} MASK_sea  ##Create the mask for the ocean

# create ferret file for interpolating model output from ORCA1 grid to regular grid


ferret='/share/apps/ferret/bin/ferret'
script_file="ferret_script.jnl"

cp ${SCRIPTDIR}/orca_interp.jnl .
cp ${PATH_MASK}/OPAT_to_2x2.nc .

cat >${script_file} <<EOF
go orca_interp.jnl $var.nc
let/unit="Celsius"/title="NEMO Sea Surface Temperature" SST=sosstsst1[k=1]
set memory/size=2000
save/file="SST_mon_2x2.nc"/clobber SST
EOF
#echo "go ${script_file}; quit" | ${ferret} -nojnl -gif
#rm -f ${script_file}




for expid in ${EXP}; do  # loop for experiments 

for season in ${MMDD_LST}; do #loop for MMDD_LST

for mem in ${MEMBER_LST[@]}; do # loop for numbers


    year=$YYINI
    #
    # Loop to copy only the files of the specific period
    #
    while [[ ${year} -le ${YYEND} ]];  do  # loop for starting years

        sdate=${year}${season}
        data_path=${DATADIR}/${expid}/${sdate}/${mem}/outputs

        for file in `ls ${data_path}/MMO*.tar`; do 
	 grid_T_file=`tar tf ${file}|grep ${grid}` 
         tar xvf ${file} ${grid_T_file}
	 gunzip ${grid_T_file}
	done


        
        for file in `ls ORCA1*${grid}*.nc`;do
	
	cdo -selname,${var} ${file} ${var}_${file}
	rm -f ${file}
	done       
         
	files=`ls ${var}*.nc`
        cdo mergetime ${files} ${var}.nc
        echo "go ${script_file}; quit" | ${ferret} -nojnl -gif

        OUTFILE=gm_sst_${expid}_${sdate}_${mem}_$suffix.nc

        cdo fldmean $para SST_mon_2x2.nc ${OUTFILE}
        #
        # Apply the mask to toto1.nc
        #
        # I delete lat and lon and save the rest into toto3_${TYPE}.nc
      #  ncwa -O -h -a lat,lon toto2_${TYPE}.nc toto3_${TYPE}.nc
        # I put the info that I want plus the data of the global mean in a new file
      #  ncks -O -h -v ${NCNAME},time toto3_${TYPE}.nc -o toto4_${TYPE}.nc
        #
        # Writing the output
        #

        rm -f ${var}*.nc SST_mon_2x2.nc #clean up

        year=$((year+YYINT))
  
 # save data     
     mkdir -p ${SAVEDIR}/${sdate}
     mv ${OUTFILE} ${SAVEDIR}/${sdate}
   
    done  #loop for years (start dates)


 done # loop for MMDD_LST
 done # loop for members
 done # loop for expid


cd

rm -rf $WORKDIR

