#bin/bash
#$ -N global_mean_model.t2
#$ -S /bin/bash
#$ -o /share/scratch/cfu/$USER/logs
#$ -j y
#$ -q all.q

set -evx


set -evx


#
# This script is to compute global mean values of 2-meter temperature from the "GG" files from EC-Earth output .
#
# Written by Hui Du (based on Danilla's script)
#
# Created:   October 1, 2010
#



######### Begin of user modifications#########################
EXP="b013"  # experiment ID
seasons="1101"  # 
mems=( fc0 fc1 fc2 fc3 fc4 )
mems=( fc4 )
vars="T2M"
yyini=2000
yyend=2000
yyint=5
save_dir="/share/scratch/cfu/$USER/analysis/t2/${EXP}"
DATADIR="/share/data/cfu/exp/ecearth"
WORKDIR="/tmp/$USER/$$"
mask_file=ecearth_mm_lsm.nc
PATH_MASK="/share/data/cfu/tools/CDFTOOLS/constant_files"
ifglobal=0  # If calculate global mean or regional, set it as 1 for global, otherwise, set it to 0

lonmin=-180
lonmax=180
latmin=-60
latmax=65

######### End of user modifications########################
PATH=${PATH}:/share/apps/cdftools-2.1/intel11/bin:/share/apps/cdo-1.4.5.1/intel11/bin/:/share/apps/nco-3.9.9/intel11/bin/:/share/apps/ferret/bin/:/share/apps/netcdf-3.6.0-p1/intel10/bin/

#
# Parameters
#
#
# Working directory
#


[[ -d $save_dir ]] || mkdir -p $save_dir


[[ -d $WORKDIR ]] || mkdir -p $WORKDIR

cd ${WORKDIR}


###
if [[ $latmin -lt 0 ]]; then
latname1=$((latmin*-1))S
elif [[ $latmin -eq 0 ]];then
latname1=$latmin
else [[ $latmin -gt 0 ]]
latname1=${latmin}N
fi


if [[ $latmax -lt 0 ]];then
latname2=$((latmax*-1))S
elif [[ $latmax -eq 0 ]];then
latname2=$latmax
else 
[[ $latmax -gt 0 ]]
latname2=${latmax}N
fi



if [[ $lonmin -lt 0 ]]; then
lonname1=$((lonmin*-1))W
elif [[ $lonmin -eq 0 ]];then
lonname1=$lonmin
else [[ $lonmin -gt 0 ]]
lonname1=${lonmin}E
fi


if [[ $lonmax -lt 0 ]];then
lonname2=$((lonmax*-1))W
elif [[ $lonmax -eq 0 ]];then
lonname2=$lonmax
else
[[ $lonmax -gt 0 ]]
lonname2=${lonmax}E
fi

if [[ $ifglobal -eq 1 ]]; then 
suffix=global
para=""
else
suffix=${lonname1}-${lonname2}_${latname1}-${latname2}
para="-sellonlatbox,$lonmin,$lonmax,$latmin,$latmax"
fi



####




###############################################################################################
#
# while looping over the list of variables it stores the name of the variable in the nc file
#
#for VAR in ${VAR_LST} ; do
#    case ${VAR} in
#        hflsd) NCNAME=lhtfl
#	       mask_name=land_sea_gaussian_mask.nc
#	       SUF=_step6h
#        ;;
#        hfssd) NCNAME=shtfl
#	       mask_name=land_sea_gaussian_mask.nc
#	       SUF=_step6h
#        ;;
#	psl) NCNAME=slp
#	     mask_name=land_sea_mask.nc
#	     SUF=_6hourly
#        ;;
#	rls) NCNAME=nlwrs 
#	     mask_name=land_sea_gaussian_mask.nc
#	     SUF=_step6h
#        ;;
#	rss) NCNAME=nswrs
#             mask_name=land_sea_gaussian_mask.nc
#	     SUF=_step6h
#	;;
#	tas) NCNAME=air
#	     SUF=_6hourly
#	     mask_name=land_sea_gaussian_mask.nc
#        ;;
#    esac 
############################################################################################3

   
    cdo gtc,0.5 ${PATH_MASK}/${mask_file} MASK_land ## Create the mask for the land

    cdo ltc,0.5 ${PATH_MASK}/${mask_file} MASK_sea  ##Create the mask for the ocean


for expid in ${EXP}; do  # loop for experiments 

for season in ${seasons}; do #loop for seasons

for mem in ${mems[@]}; do # loop for numbers

for var in ${vars}; do # loop for variables 


    year=$yyini
    #
    # Loop to copy only the files of the specific period
    #
    while [[ ${year} -le ${yyend} ]];  do  # loop for starting years

        sdate=${year}${season}
        data_path=${DATADIR}/${expid}/${sdate}/${mem}/outputs
    #    cp ${data_path}/MMA* .
    #    scp forseti:${data_path}/MMA* .

        for file in `ls ${data_path}/MMA*.tar`; do 
	 file1=`tar tf ${file}|grep GG` 
	 for file2 in ${file1};do
	 tar xvf ${file} ${file2} 
	 done
	done

	gunzip *GG*.gz
        
        for file in `ls MMA*GG*.nc`;do
	
	cdo seltimestep,1 -selname,${var} ${file} ${var}_${file}
	rm -f ${file}
	done       
         
	files=`ls ${var}*.nc`
        cdo mergetime ${files} ${var}.nc

	for TYPE in land sea global ; do
        OUTFILE=gm_${var}_${TYPE}_${expid}_${sdate}_${mem}_$suffix.nc
        #
        # Apply the mask to toto1.nc
        #
        if [[ $TYPE = "land" || $TYPE = "sea" ]] ; then
           cdo ifthen MASK_${TYPE} ${var}.nc ${var}_${TYPE}.nc
        else
           cp ${var}.nc ./${var}_${TYPE}.nc
        fi
        #
        # Compute the global mean of toto1_* and store it in toto2_*.nc
        #
        cdo fldmean $para ${var}_${TYPE}.nc ${OUTFILE}
        # I delete lat and lon and save the rest into toto3_${TYPE}.nc
      #  ncwa -O -h -a lat,lon toto2_${TYPE}.nc toto3_${TYPE}.nc
        # I put the info that I want plus the data of the global mean in a new file
      #  ncks -O -h -v ${NCNAME},time toto3_${TYPE}.nc -o toto4_${TYPE}.nc
        #
        # Writing the output
        #
	done  # loop for types (for example, land, ocean and global)

        rm -f ${var}*.nc #clean up

        year=$((year+yyint))
  
 # save data     
     mkdir -p ${save_dir}/${sdate}
     mv gm_${var}*.nc ${save_dir}/${sdate}
   
    done  #loop for years (start dates)

 done # loop for variables 

 done # loop for seasons
 done # loop for members
 done # loop for expid


cd

rm -rf $WORKDIR

