#!/bin/bash
set -x
### General Settings ###
########################
#
#This script is to compute ocean heat content of NEMOVAR, writen by Hui, 1/10/2010
#

############## Beginning of user modification#############

EXPID=fa9p
MEMBERS=( opa0 opa1 opa2 opa3 opa4 )
TMPDIR=/share/scratch/cfu/${USER}/tmp/heatc_nemovar_$$
SAVEDIR=/share/scratch/cfu/$USER/analysis/heatc/nemovar
DATADIR=/share/data/cfu/data/ecmwf/${EXPID}
CDFTOOLS=/share/apps/cdftools-2.1/intel11/bin
CON_FILES=/share/data/cfu/tools/CDFTOOLS/constant_files
GRID=grid_T
YY1=1957
YY2=2009
YYINT=1

IMIN=0
IMAX=0
JMIN=0
JMAX=0
KMIN=1
KMAX=20 # 24 for 657m, 20 for 315m

############# End of User modification#####################

PATH=$PATH:${CDFTOOLS}
exec=cdfheatc
rm -rf $TMPDIR
mkdir -p $TMPDIR
mkdir -p $SAVEDIR
cd $TMPDIR



# Check the existence of above tools
check(){
if tool=cdo      && test ! -f $tool || \
   tool=ncrename && test ! -f $tool || \
   tool=ncatted  && test ! -f $tool || \
   tool=ncl      && test ! -f $tool; then
 echo "tool does not exist!!!"
 exit 1
fi
}

#check


### Stuff for cdfheatc ###
##########################
#  Usage : cdfheatc  gridTfile  [IMIN IMAX JMIN JMAX KMIN KMAX]
#  Computes the heat content in the specified area (Joules)
#  IMIN IMAX JMIN JMAX KMIN KMAX can be given in option
#     if IMIN = 0 then ALL i are taken
#     if JMIN = 0 then ALL j are taken
#     if KMIN = 0 then ALL k are taken
#  PARTIAL CELLS VERSION
#  Files mesh_hgr.nc, mesh_zgr.nc ,mask.nc
#  must be in the current directory
#  Output on standard output

ln -sf $CON_FILES/mask.nc .
ln -sf $CON_FILES/mesh_hgr.nc .
ln -sf $CON_FILES/mesh_zgr.nc .
cp $CON_FILES/heatc.nc .
cp $CON_FILES/depth.txt .

para="$IMIN $IMAX $JMIN $JMAX $KMIN $KMAX"


cd $TMPDIR


if [[ ${KMIN} -eq 0 ]] 
then
KMIN=0
else
KMIN=`cat depth.txt |head -${KMIN} |tail -1 | awk '{print $2}' | awk '{printf "%.0f",$1}'`;
fi


KMAX=`cat depth.txt |head -${KMAX} |tail -1 | awk '{print $2}' | awk '{printf "%.0f",$1}'`;



prefix=heatc
suffix=${KMIN}-${KMAX}
cp heatc.nc toto.nc;chmod 775 toto.nc

### Actual Computation ###
##########################
for mem in ${MEMBERS[@]}; do # loop for MEMBERS

t=1
output=${prefix}_${mem}_${suffix}


#
echo "******************** $member *********************"
#  
yy=$YY1

while [[ $yy -le $YY2 ]]; do

cp ${DATADIR}/${mem}/${EXPID}*${yy}*${GRID}*.gz .

for file in `ls *.gz`; do #loop for gz files
gunzip ${file}
done # loop for gz files


for file in `ls ${EXPID}*.nc`; do # loop for nc files
  date=`ls ${file}|cut -f3 -d"_"|cut -c1-6`
  $exec ${file} $para > tmp.log
  thc=`cat tmp.log | grep "Total Heat content :" | awk '{print $5}'`;
  uhc=`cat tmp.log | grep "Total Heat content/volume" | awk '{print $5}'`;
  echo $date $thc $uhc >>${output}.txt

 ncap2 -h -s "thc()=$thc;uhc()=$uhc" toto.nc toto2.nc

 if [[ $t = 1 ]] ; then
 mv toto2.nc ${output}.nc ; t=$((t+1))
 else
 mv ${output}.nc vtmp.nc
 ncrcat -h vtmp.nc toto2.nc ${output}.nc;rm toto2.nc
 fi



  rm -f ${file} tmp.log *tmp 

done #loop for nc files


yy=$((yy+YYINT))

done #loop for years



  thc_min=`cat ${output}.txt | awk '{print $2}' | sort -n | head -1`;
  thc_max=`cat ${output}.txt | awk '{print $2}' | sort -n | tail -n 1`;
  uhc_min=`cat ${output}.txt | awk '{print $3}' | sort -n | head -1`;
  uhc_max=`cat ${output}.txt | awk '{print $3}' | sort -n | tail -n 1`;

  ncatted -h -a valid_min,thc,m,f,$thc_min ${output}.nc
  ncatted -h -a valid_max,thc,m,f,$thc_max ${output}.nc

  ncatted -h -a valid_min,thc,m,f,$uhc_min ${output}.nc
  ncatted -h -a valid_max,thc,m,f,$uhc_max ${output}.nc

  rm -rf fill*
  rm -rf tmp*

############ Begin of fix time ###############


tunit=h  #set unit of time


date2stamp () {
    date --utc --date "$1" +%s
}

stamp2date (){
    date --utc --date "$sdate $1 sec" "+%Y-%m-%d %T"
}


dateDiff (){
    case $1 in
        -s)   sec=1; timeunit=seconds;     shift;;
        -m)   sec=60;timeunit=minutes;     shift;;
        -h)   sec=3600; timeunit=hours;  shift;;
        -d)   sec=86400; timeunit=days; shift;;
        *)    sec=86400; timeunit=seconds;
    esac
    dte1=$(date2stamp $1)
    dte2=$(date2stamp $2)
    diffSec=$((dte2-dte1))
    if ((diffSec < 0)); then abs=-1; else abs=1; fi
    echo $((diffSec/sec*abs))
    value=$((diffSec/sec*abs))
    return $value
}



sdate=`head -1 ${output}.txt | cut -f1 -d" "`
syy=`echo $sdate|cut -c1-4`
smm=`echo $sdate|cut -c5-6`
ds=${syy}-${smm}-01

fill_nc(){

n=`wc -l ${output}.txt | awk '{print $1}'`

for ((i=1;i<=$n;i++));do
date=`head -$i ${output}.txt | tail -1|cut -f1 -d" "`
yy=`echo $date|cut -c1-4`
mm=`echo $date|cut -c5-6`
tmp=$yy-$mm-01

dateDiff -$tunit $ds $tmp
dt=$value

ncap2 -h -O -s "time($((i-1)))=$dt" ${output}.nc ${output}.nc


done


syy=`echo $sdate|cut -c1-4`
smm=`echo $sdate|cut -c5-6`

  ncatted -h -a units,time,m,c,"${timeunit} since ${syy}-${smm}-01 00:00:00" ${output}.nc


  rm -rf fill*
  rm -rf tmp*

}

fill_nc





############ End of fix time ##############


 mv ${output}.* $SAVEDIR

done # loop for MEMBERS 

rm -rf $TMPDIR

 echo
 echo
 echo "******************** END  *********************"


