#!/bin/bash

#$ -N heatc
#$ -S /bin/bash
#$ -o /share/scratch/cfu/$USER/logs
#$ -j y

set -evx
#
# This script computes the ocean heat content from the NEMO output
#
# Written by Hui Du (based on "/gpfs/projects/ecm86/common/cdftools/scripts/cdfheatc.sh" on BSC)
#
# Created:   October 1, 2010
#            Hui Du (based on "/gpfs/projects/ecm86/common/cdftools/scripts/cdfheatc.sh" on BSC)
# Modified:  October 22, 2010
#            F. Doblas-Reyes
#
########################
### General Settings ###
########################

#
# The data directory should follow the structure ${DATADIR}/${EXPID}/${year}/${member}/
# where ${DATADIR} is the directory where the model output is available from
# $EXPID is the experiment ID
# $year is the starting date of the simulation
# $member is the ensemble member
#

############################ Beginning of user modification#####################
#
# common part 
#
DATA=model # here set model or obs
#DATA=obs # here set model or obs
EXPID=fa9p
EXPID=nem1
MEMBER_LST=( 0 1 2 3 4 )
MEMBER_LST=( 0 ) 
CDFTOOLS=/share/apps/cdftools-2.1/intel11/bin
CON_FILES=/share/data/cfu/common/CDFTOOLS/constant_files
TMPDIR=/share/scratch/cfu/${USER}/tmp/heatc_${EXPID}_$$
GRID=grid_T
imin=0
imax=0
jmin=0
jmax=0
kmin=21
kmax=24  # 24 for about 657m and 20 for 315m


#
# model part 
#
DATADIR_MODEL=/share/data/cfu/exp/nemo-ecearth/${EXPID}
SAVEDIR_MODEL=/share/scratch/cfu/huidu/analysis/heatc/${EXPID}
#YEAR_LST=( 19601101 19651101 19701101 19751101 19801101 19851101 19901101 19951101 20001101 20051101 )
YEAR_LST=( 19890201 )



#
# nemovar part
#
DATADIR_OBS=/share/data/cfu/data/ecmwf/${EXPID}
SAVEDIR_OBS=/share/scratch/cfu/${USER}/analysis/heatc/nemovar/${EXPID}
YY1=1957
YY2=2009
YYINT=1



############################ End of user modification #########################
PATH=${PATH}:/share/apps/cdftools-2.1/intel11/bin:/share/apps/cdo-1.4.5.1/intel11/bin/:/share/apps/nco-3.9.9/intel11/bin/:/share/apps/ferret/bin/:/share/apps/netcdf-3.6.0-p1/intel10/bin/   # define the path of cdftools executables 
/bin/rm -rf $TMPDIR
mkdir -p $TMPDIR
cd $TMPDIR
#
# obtain constant files 
#
cp ${CON_FILES}/depth.txt .
ln -sf ${CON_FILES}/mask.nc .
ln -sf ${CON_FILES}/mesh_hgr.nc .
ln -sf ${CON_FILES}/mesh_zgr.nc .
cp ${CON_FILES}/heatc.nc toto.nc # heatc.nc is a file that contains a template for the ohc NetCDF output
#
##
#
para="$imin $imax $jmin $jmax $kmin $kmax"
if [[ ${kmin} -eq 1 ]] ; then
kmin=0
else
kmin=`cat depth.txt |head -${kmin} |tail -1 | awk '{print $2}' | awk '{printf "%.0f",$1}'`;
fi 
kmax=`cat depth.txt |head -${kmax} |tail -1 | awk '{print $2}' | awk '{printf "%.0f",$1}'`;
prefix=heatc
suffix=${kmin}-${kmax}
#
##
#

case $DATA in  # for computing heat content of model
model) 

mkdir -p ${SAVEDIR_MODEL}

#
# Loop over start dates and members
#
for year in ${YEAR_LST[@]}; do
    echo "******************** Model ${EXPID} Start $year **********************"
    date
    for member in ${MEMBER_LST[@]}; do
        echo "******************** Start fc${member} **********************"
        echo
#
# File retrieval and variable selection
#
        source_dir=${DATADIR_MODEL}/${year}/fc${member}/outputs
        files=`find ${source_dir} -name MMO*${EXPID}_${year}_fc${member}_*.tar`
        for file in $files; do
            file1=`tar tf $file | grep ${GRID}`
            tar xvf $file ${file1}
            gunzip ${file1}
            file2=`echo $file1 |cut -c1-36`  # not a good way, need better solution 
            /bin/rm -f ${file2}.tmp
            ncks -v votemper,nav_lon,nav_lat,deptht,time_counter ${file2} -o ${file2}.tmp
            mv ${file2}.tmp ${file2}
        done
        merged=${EXPID}_${year}_fc${member}_ORCA1
        /bin/rm -f ${merged}
        cdo mergetime ORCA1_MM_*_${GRID}.nc ${merged}.nc
        chmod 777 ${EXPID}*.nc
#
# Calculation of the ohc
#
        output=${prefix}_${merged}_${suffix}
        cp ${CON_FILES}/heatc.nc toto.nc # heatc.nc is a file that contains a template for the ohc NetCDF output
        ntime=`cdo ntime ${merged}.nc`;
        /bin/rm -f output.txt
        for t in $(seq 1 1 $ntime); do
            /bin/rm -f tmp.nc
            cdo seltimestep,$t ${merged}.nc tmp.nc
            cdfheatc tmp.nc $para > tmp.log
            thc=`cat tmp.log | grep "Total Heat content :" | awk '{print $5}'`;
            uhc=`cat tmp.log | grep "Total Heat content/volume" | awk '{print $5}'`;
            echo $t $thc $uhc >> ${output}.txt
            ncap2 -h -O -s "thc()=$thc;uhc()=$uhc" toto.nc toto.nc
            if [[ $t = 1 ]] ; then
               cp toto.nc ${output}.nc
            else
               ncrcat -h -O ${output}.nc toto.nc ${output}.nc
            fi
        done
        ncks -h -O -v time ${merged}.nc -o time.nc
        ncks -h -A time.nc ${output}.nc
#
# Modify headers
#
        thc_min=`cat ${output}.txt | awk '{print $2}' | sort -n | head -1`;
        thc_max=`cat ${output}.txt | awk '{print $2}' | sort -n | tail -n 1`;
        ncatted -h -a valid_min,thc,m,f,$thc_min ${output}.nc
        ncatted -h -a valid_max,thc,m,f,$thc_max ${output}.nc
#
        uhc_min=`cat ${output}.txt | awk '{print $3}' | sort -n | head -1`;
        uhc_max=`cat ${output}.txt | awk '{print $3}' | sort -n | tail -n 1`;
        ncatted -h -a valid_min,uhc,m,f,$uhc_min ${output}.nc
        ncatted -h -a valid_max,uhc,m,f,$uhc_max ${output}.nc
#  
        units=`ncdump -c ${merged}.nc | grep "time:units" | cut -d '"' -f2`;
        ncatted -h -a units,time,m,c,"$units" ${output}.nc
        ncatted -h -a time,time,d,, ${output}.nc
#
        /bin/rm -f MMO_${EXPID}_${year}_${member}_*
        /bin/rm -f ORCA1_MM_*
        /bin/rm -f ${merged}.nc
#
        echo "******************** END $member  *********************"
    done
    echo "******************** END $year  *********************"
done
#
mv heatc*.nc ${SAVEDIR_MODEL}; mv heatc*.txt ${SAVEDIR_MODEL}
cd ..
/bin/rm -rf ${TMPDIR}
date

;;

obs)   # case conditions 

mkdir -p ${SAVEDIR_OBS}

##########################
for mem in ${MEMBER_LST[@]}; do # loop for MEMBERS

t=1
output=${prefix}_opa${mem}_${suffix}


#
echo "******************** opa$member *********************"
#  
yy=$YY1

while [[ $yy -le $YY2 ]]; do

cp ${DATADIR_OBS}/opa${mem}/${EXPID}*${yy}*${GRID}*.gz .

for file in `ls *.gz`; do #loop for gz files
gunzip ${file}
done # loop for gz files


for file in `ls ${EXPID}*.nc`; do # loop for nc files
  date=`ls ${file}|cut -f3 -d"_"|cut -c1-6`
  cdfheatc ${file} $para > tmp.log
  thc=`cat tmp.log | grep "Total Heat content :" | awk '{print $5}'`;
  uhc=`cat tmp.log | grep "Total Heat content/volume" | awk '{print $5}'`;
  echo $date $thc $uhc >>${output}.txt

 ncap2 -h -s "thc()=$thc;uhc()=$uhc" toto.nc toto2.nc

 if [[ $t = 1 ]] ; then
 mv toto2.nc ${output}.nc ; t=$((t+1))
 else
 mv ${output}.nc vtmp.nc
 ncrcat -h vtmp.nc toto2.nc ${output}.nc;/bin/rm toto2.nc
 fi



  /bin/rm -f ${file} tmp.log *tmp 

done #loop for nc files


yy=$((yy+YYINT))

done #loop for years



  thc_min=`cat ${output}.txt | awk '{print $2}' | sort -n | head -1`;
  thc_max=`cat ${output}.txt | awk '{print $2}' | sort -n | tail -n 1`;
  uhc_min=`cat ${output}.txt | awk '{print $3}' | sort -n | head -1`;
  uhc_max=`cat ${output}.txt | awk '{print $3}' | sort -n | tail -n 1`;

  ncatted -h -a valid_min,thc,m,f,$thc_min ${output}.nc
  ncatted -h -a valid_max,thc,m,f,$thc_max ${output}.nc

  ncatted -h -a valid_min,thc,m,f,$uhc_min ${output}.nc
  ncatted -h -a valid_max,thc,m,f,$uhc_max ${output}.nc

  /bin/rm -rf fill*
  /bin/rm -rf tmp*

############ Begin of fix time ###############


tunit=h  #set unit of time


date2stamp () {
    date --utc --date "$1" +%s
}

stamp2date (){
    date --utc --date "$sdate $1 sec" "+%Y-%m-%d %T"
}


dateDiff (){
    case $1 in
        -s)   sec=1; timeunit=seconds;     shift;;
        -m)   sec=60;timeunit=minutes;     shift;;
        -h)   sec=3600; timeunit=hours;  shift;;
        -d)   sec=86400; timeunit=days; shift;;
        *)    sec=86400; timeunit=seconds;
    esac
    dte1=$(date2stamp $1)
    dte2=$(date2stamp $2)
    diffSec=$((dte2-dte1))
    if ((diffSec < 0)); then abs=-1; else abs=1; fi
    echo $((diffSec/sec*abs))
    value=$((diffSec/sec*abs))
    return $value
}



sdate=`head -1 ${output}.txt | cut -f1 -d" "`
syy=`echo $sdate|cut -c1-4`
smm=`echo $sdate|cut -c5-6`
ds=${syy}-${smm}-01

fill_nc(){

n=`wc -l ${output}.txt | awk '{print $1}'`

for ((i=1;i<=$n;i++));do
date=`head -$i ${output}.txt | tail -1|cut -f1 -d" "`
yy=`echo $date|cut -c1-4`
mm=`echo $date|cut -c5-6`
tmp=$yy-$mm-01

dateDiff -$tunit $ds $tmp
dt=$value

ncap2 -h -O -s "time($((i-1)))=$dt" ${output}.nc ${output}.nc


done


syy=`echo $sdate|cut -c1-4`
smm=`echo $sdate|cut -c5-6`

  ncatted -h -a units,time,m,c,"${timeunit} since ${syy}-${smm}-01 00:00:00" ${output}.nc


  /bin/rm -rf fill*
  /bin/rm -rf tmp*

}

fill_nc





############ End of fix time ##############


 mv ${output}.* $SAVEDIR_OBS

done # loop for MEMBERS 

/bin/rm -rf $TMPDIR

 echo
 echo
 echo "******************** END  *********************"

 ;; #case conditions

esac
