# Checking 
#!/bin/sh
#set -evx # uncommented: it prints the commands in the screen
#
# 


DATADIR=MyDIR
WORKDIR="/cfu/scratch/${USER}/$$"
EXPID=MyEXPID
MMDD=1101
YYINI=1960
YYEND=1995
YYINT=5
type=global
type=land
type=sea
default_var=thc
format=PLOT_FORMAT  # plot format,  1 for postscript and 0 for png
var=thc
imin=0
imax=0
jmin=0
jmax=0
dep1=DEPTH1 # set 5051m, 657m or 315m
dep2=DEPTH2 # set 5051m, 657m or 315m
#dep2=5051 # set 5051m, 657m or 315m


if [ "$1" = "" ]
then
  echo "Usage: heatc.mat.sh followed by thc/uhc!" 
  exit

fi

#




if [ "$var" = "thc" ]
then
  mtitle="Global ocean Heat Content for ${dep1}-${dep2}m" 
  ytitle="OHC(10^22 Joules)" 
  factor=1/10^22
else
  mitle="Unit Heat Content for ${dep1}-${dep2}m "
  factor="OHC (Joules/m3)"
fi

echo $title







LASTYEAR=$((YYEND+YYINT))
#LASTYEAR=1991
ndata=$(((YYEND-YYINI)/YYINT+1)) # calculate the number of start dates
file=${DATADIR}/${EXPID}/heatc_${EXPID}_${YYINI}${MMDD}_fc0_ORCA1_${dep1}-${dep2}.nc

length=`cdo ntime ${file}`
nt=$((length*ndata))
MMINI=`cdo showmon -seltimestep,1 ${file}`
#LASTYEAR=`cdo showyear -seltimestep,$nt ${file}`
#MMEND=`cdo showmon -seltimestep,$nt ${file}`
MMEND=10
cdate=`seq $YYINI $YYINT $YYEND`
echo $ndata $cdate

cyear=""

for ((i=1;i<=$ndata;i++));do

tmpc=`echo $cdate|cut -f$i -d" "`
if [[ i -eq 1 ]]; then
cyear=${cyear}${tmpc}
else
cyear=${cyear}","${tmpc}
fi
done
echo $cyear

yy1=$YYINI
mm1=`echo $MMDD|cut -c1-2`


[[ -d $WORKDIR ]] || mkdir -p $WORKDIR
cd ${WORKDIR}
plotsdir="/cfu/scratch/${USER}/plots"
[[ -d $plotsdir ]] || mkdir -p $plotsdir
#
# Write the R script testing ncdf (in temporary plot_test in the workdir)
#

# 
# the following piece of code tries to extract the observational data based on the year and month
#

nemovar=$DATADIR/nemovar/heatc_fc0_${dep1}-${dep2}.nc
nt_obs=`cdo ntime $nemovar`

for ((i=1;i<=$nt_obs;i++)); do
yy=`cdo showyear -seltimestep,$i $nemovar`
mm=`cdo showmon -seltimestep,$i $nemovar`
if [[ $yy -eq $yy1 && $mm -eq $mm1 ]]; then
st_obs=$i
break
fi

done


suffix=heatc_${var}_${EXPID}_${dep1}-${dep2}_${YYINI}-${YYEND}

case ${format} in 
  ps)
  output=${suffix}.ps
  plot_option=postscript
  display=gv
  ;;
  png)
  output=${suffix}.png
  plot_option=png
  display=eog
  ;;
esac

#ghnc=${DATADIR}/ghnc/gm_tas_ghcn.nc

cat>$WORKDIR/plot_test<<EOF

library(ncdf)

empty=array(dim=$nt)
ohc_model=array(dim=c($nt,5,$ndata))
ohc_obs=array(dim=c($nt,5))


for (i in c("0","1","2","3","4")) {
#for (i in c("1","2")) {
file=paste("${DATADIR}/nemovar/","heatc_fc",i,"_${dep1}-${dep2}.nc",sep="")
fnc=open.ncdf(file)
var=get.var.ncdf(fnc,"$var")*${factor}
index_i=as.integer(i)+1
index_t1=as.integer(${st_obs})
index_t2=index_t1+$nt-1
ohc_obs[,index_i]=var[index_t1:index_t2]
}





for (i in c($cyear)) {
#for (j in c("0","1","2","3","4")) {
for (j in c("0")) {
#file=paste("${DATADIR}/${EXPID}/","ohc_","${EXPID}_",i,"${MMDD}_","fc",j,"_ORCA1_","${imin}-${imax}_","${jmin}-${jmax}_","${dep1}-${dep2}",".nc",sep="")
file=paste("${DATADIR}/${EXPID}/","heatc_","${EXPID}_",i,"${MMDD}_","fc",j,"_ORCA1_","${dep1}-${dep2}",".nc",sep="")
fnc=open.ncdf(file)
var=get.var.ncdf(fnc,"$var")*${factor}
index_j=as.integer(j)+1
index_i=(as.integer(i)-${YYINI})/${YYINT}+1
index_t1=((as.integer(i)-${YYINI})/${YYINT})*${length}+1
index_t2=index_t1+${length}-1
ohc_model[index_t1:index_t2,index_j,index_i]=var
}
}



empty_ts=ts(empty,start=c($YYINI,$MMINI),end=c($LASTYEAR,$MMEND),frequency=12)


ulimit=max(ohc_obs,ohc_model,na.rm=TRUE)
llimit=min(ohc_obs,ohc_model,na.rm=TRUE)
middle=(ulimit+llimit)/2+(ulimit-llimit)*0.2
right=$nt+$nt/12
#
#
#postscript("$plotsdir/${output}",width=550,height=550)
${plot_option}("$plotsdir/${output}",width=550,height=300)
#par(mai=c(1,1,1,2.5))

plot(empty_ts,ylim=c(llimit,ulimit),ylab="")

par(new=TRUE)
matplot(ohc_obs,lty=1,type="l",ylim=c(llimit,ulimit),col=1,ylab="${ytitle}",main="${mtitle}",labels=FALSE,axes=FALSE)

color=rainbow($ndata)
for (i in 1:$ndata) {
par(new=TRUE)
#matplot(ohc_model[,1:5,i],lty=1,type="l",ylim=c(llimit,ulimit),col=color[i],ylab="",labels=FALSE,axes=FALSE)
matplot(ohc_model[,1,1],lty=1,type="l",ylim=c(llimit,ulimit),col=color[i],ylab="",labels=FALSE,axes=FALSE)
} 

#par(new=TRUE)
#matplot(t2[,1:5,1],type="l",ylim=c(llimit,ulimit),col=2:6,ylab="",labels=FALSE,axes=FALSE)
par(new=TRUE)
#matplot(t2[,1:5,2],type="l",ylim=c(llimit,ulimit),col=2:6,ylab="",labels=FALSE,axes=FALSE)
#par(new=TRUE)
#matplot(t2[,1:5,3],type="l",ylim=c(llimit,ulimit),col=2:6,ylab="",labels=FALSE,axes=FALSE)
par(xpd=TRUE)
#legend(0,ulimit,c("Ncep Reanalysis","fc0","fc1","fc2","fc3","fc4"),lwd=c(1,1),col=1:6)
#legend(right,middle,c("nemovar_fc0","nemovar_fc1","nemovar_fc2","nemovar_fc3","nemovar_fc4","model_fc0","model_fc1","model_fc2","model_fc3","model_fc4"),lty=c(1,1,1,1,1,2,2,2,2,2),col=1:5)
legend(0,ulimit,c("NEMOVAR","NEMO-only"),lty=1,col=c(1,2))
#legend(0,ulimit,c("NEMOVAR","NEMO-only(ERAInterim forcing)"),lty=1,col=c(1,color(1)))


dev.off()
#
# Closing the R script
#
EOF
#cat plot_test # uncommented: it shows the R script in the screen
#
# Run the R script
#
R CMD BATCH $WORKDIR/plot_test
echo "Please go to ${plotsdir} to check the plots and the log files"
cp plot_test  /cfu/scratch/$USER/log 
cp plot_test.Rout  /cfu/scratch/$USER/log
#
rm -rf $WORKDIR
chmod 775 ${plotsdir}/${output}

case ${format} in 
  ps)
#  ps2pdf ${plotsdir}/${output} ${plotsdir}/${suffix}.pdf
  ;;
esac

${display} ${plotsdir}/${output}
