#!/bin/bash

###########################################################################################################################
## This script is a general scirpt to compute Maximum MOC based on the coputed nemovar moc 
##
## The originial files should be monthly means of grid_V file. 
##
## 
## Written by Hui Du (not writen from scratch, but based on "/gpfs/projects/ecm86/common/cdftools/scripts/cdfmocmaxmoc.sh" 
##
## Institut Català de Ciències del Clima / Climate Forecasting Unit (IC3/CFU)
## Created:   October 1, 2010
############################################################################################################################


set -x
### General Settings ###
#
####################### Beginning of ser modification #########################################
#
# to run this script, you have to make sure you moc_$mem.nc in "data" directory
#
export NCARG_ROOT=/opt/ncl  # Set NCARG environment for using NCL
#members="opa0 opa1 opa2 opa3 opa4"  # modify here if you only calculate part of the members 
members="opa0 opa1 opa2 opa3 opa4"  # modify here if you only calculate part of the members 
tmp_dir=/cfu/scratch/$USER/nemovar_maxmoc_$$  # For this part, you can modify, but not ncessary. 
save_dir=/cfu/scratch/$USER/maxmoc_nemovar  # Here you can specify where you want to save the output
data=/cfu/scratch/$USER/moc_nemovar  # Here you can specify where you want to save the output
cdftools=/opt/cdftools/bin  # This is usual directoy for CDFTOLLS if it has been installed to your computer.  
con_files=/cfu/pub/scripts/CDFTOOLS/constant_files # Directoy for the constant files CDFTOOLS use. No need to modify
#
cdo=/usr/local/bin/cdo # you need to check if this is correct,otherwise modify it. 
ncrename=/usr/local/bin/ncrename # you need to check if this is correct,otherwise modify it.
ncatted=/usr/local/bin/ncatted # you need to check if this is correct,otherwise modify it.
ncl=/opt/ncl/bin/ncl # you need to check if this is correct,otherwise modify it.
#
cbasin=atl  # specify which basin you want to compute 
latmin=-60  # specify the minimum  latitude
latmax=60  # specify the maxmum latitude
depmin=200  # specify the minmum depth
depmax=2500  #specify the maxmum depth 
#
######################### End of user modification   ###########################################

if [[ $latmin -lt 0 ]]; then
latname1=$((latmin*-1))S
elif [[ $latmin -eq 0 ]];then
latname1=$latmin
else [[ $latmin -gt 0 ]]
latname1=${latmin}N
fi


if [[ $latmax -lt 0 ]];then
latname2=$((latmax*-1))S
elif [[ $latmax -eq 0 ]];then
latname2=$latmax
else 
[[ $latmax -gt 0 ]]
latname2=${latmax}N
fi



save_dir_maxmoc=$save_dir/${cbasin}_${latname1}-${latname2}_${depmin}-${depmax}

rm -rf $tmp_dir
mkdir -p $tmp_dir
mkdir -p $save_dir_maxmoc

cd $tmp_dir


# Check the existence of above tools
if tool=$cdo      && test ! -f $tool || \
   tool=$ncrename && test ! -f $tool || \
   tool=$ncatted  && test ! -f $tool || \
   tool=$ncl      && test ! -f $tool; then
 echo "$tool does not exist!!!"
 exit 1
fi

cp $HOME/cdfmaxmoc .  # buggy part, you need to copy cdfmaxmoc from your cdftools directory. 

ln -sf $con_files/mask.nc .
ln -sf $con_files/mesh_hgr.nc .
ln -sf $con_files/mesh_zgr.nc .
ln -sf $con_files/new_maskglo.nc .

para="$cbasin $latmin $latmax $depmin $depmax"

##
date2stamp () {
    date --utc --date "$1" +%s
}

stamp2date (){
    date --utc --date "$sdate $1 sec" "+%Y-%m-%d %T"
}


dateDiff (){
    case $1 in
        -s)   sec=1; timeunit=seconds;     shift;;
        -m)   sec=60;timeunit=minutes;     shift;;
        -h)   sec=3600; timeunit=hours;  shift;;
        -d)   sec=86400; timeunit=days; shift;;
        *)    sec=86400; timeunit=seconds;
    esac
    dte1=$(date2stamp $1)
    dte2=$(date2stamp $2)
    diffSec=$((dte2-dte1))
    if ((diffSec < 0)); then abs=-1; else abs=1; fi
    echo $((diffSec/sec*abs))
    value=$((diffSec/sec*abs))
    return $value
}

###

# create NCL scritps

cat>addtime.ncl << EOF
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
;***********************************
begin
 f=addfile("ncl.nc","w")
 f->time(t-1)=tvalue
end
EOF
# end of creating NCL scritps
#
################################# Computation ###################################
#
for mem in ${members}; do # loop for members

 echo "******************** $mem *********************"
 echo

file=moc_${mem}.nc 

cp $data/$file .
nt=`cdo ntime $file`
iyear=`cdo showyear -seltimestep,1 $file`
iyear=${iyear// /}  # to get rid of the annoying spaces
eyear=`cdo showyear -seltimestep,$nt $file`
eyear=${eyear// /} 
imon=`cdo showmon -seltimestep,1 $file`
imon=${imon// /}
emon=`cdo showmon -seltimestep,$nt $file`
emon=${emon// /}

yy1=$((iyear+1))
yy2=$((eyear-1))
sdate=$iyear-$imon-1

# using cdo to compute maxmoc
for ((i=1;i<=$nt;i++));do
$cdo seltimestep,$i $file toto.nc
./cdfmaxmoc toto.nc $para; mv maxmoc.nc tmp_maxmoc_${i}.nc; rm toto.nc 
done
rm -f $file
$cdo mergetime tmp_maxmoc*.nc maxmoc_${mem}.nc;chmod 775 maxmoc_${mem}.nc  # mv maxmoc_${mem}.nc $save_dir1
rm -f *_maxmoc*.nc 
# end of computation of maxmoc
####################################### Beginning of fix time #########################################33

mv maxmoc_${mem}.nc ncl.nc

# special case when 

if [[ $iyear -eq $eyear ]]

then

it=0
for ((i=$imon;i<=$emon;i++)); do

dateDiff -h $sdate ${iyear}-$i-1
dt=$value
$ncl addtime.ncl t=$it tvalue=$dt
it=$((it+1))

done

fi


# first year
ts=1
for ((i=$imon;i<=12;i++));do

dateDiff -h $sdate ${iyear}-$i-1
dt=$value
$ncl addtime.ncl t=$ts tvalue=$dt 
ts=$((ts+1))
done


# for year having 12 months 

if [[ $yy1 -le $yy2 ]] 
then 

#
for ((year=$yy1;year<=$yy2;year++));do
 for ((i=1;i<=12;i++)); do
 dateDiff -h $sdate ${year}-$i-1
 dt=$value
 ts=$((13-imon+(year-yy1)*12+i))

 $ncl addtime.ncl t=$ts tvalue=$dt
 done

done
#

else

fi

# for last year
for ((i=1;i<=$emon;i++)); do

dateDiff -h $sdate ${eyear}-$i-1 
dt=$value

ts=$((13-imon+(yy2-yy1+1)*12+i))

$ncl addtime.ncl t=$ts tvalue=$dt
done

# end last year

mv ncl.nc $file

$ncatted -h -a units,time,m,c,"${timeunit} since ${sdate} 00:00:00" ${file}

mv ${file} ${save_dir_maxmoc}/maxmoc_${mem}.nc  # save outputs to the directory specified 

########################################## End of fix time####################################

 echo "$mem Done"
done # loop for members

rm -r mask.nc mesh*.nc  new_maskglo.nc

cd 
rm -r $tmp_dir # clean up 
echo "Computations Done"
echo 
