#!/bin/bash

#
# This script is to compute MOC and Maximum MOC for Atlantic of NEMOVAR data .
#
# The originial files should be monthly means of grid_V file. 
#
# 
# Written by Hui Du (not writen from scratch, but based on "/gpfs/projects/ecm86/common/cdftools/scripts/cdfmocmaxmoc.sh" 
#
# Institut Català de Ciències del Clima / Climate Forecasting Unit (IC3/CFU)
# Created:   October 1, 2010
#


set -x
### General Settings ###
########################
export NCARG_ROOT=/opt/ncl

#=== Beginning of User modification ==============
expid=fa9p # You do not need to change this   
#members="opa1 opa2 opa3 opa4"  # modify here if you only calculate part of the members 
members="opa1 opa2 opa3 opa4"  # modify here if you only calculate part of the members 
tmp_path=/cfu/scratch/$USER   #Usually you do not need to modify this part
tmp_dir=$tmp_path/nemovar_moc_$$  # For this part, you can modify, but not ncessary. 
save_dir=/cfu/scratch/$USER/moc_nemovar  # Here you can specify where you want to save the output
save_dir_maxmoc=/cfu/scratch/$USER/${latname1}-${latname2}_${depmin}-${depmax}
data=/cfu/data/EC-Earth/prepIFS/fa9p  # No need to change this, unless NEMOVAR data are moved to other directory
cdftools=/opt/cdftools/bin  # This is usual directoy for CDFTOLLS if it has been installed to your computer. If you do have not had this tools and your machines are 64bits, you can use the exe from Hui's mahcine. 
con_files=/cfu/pub/scripts/CDFTOOLS/constant_files # Usually you do not need to change this part

cdo=/usr/local/bin/cdo # you need to check if this is correct,otherwise modify it. 
ncrename=/usr/local/bin/ncrename # you need to check if this is correct,otherwise modify it.
ncatted=/usr/local/bin/ncatted # you need to check if this is correct,otherwise modify it.
ncl=/opt/ncl/bin/ncl # you need to check if this is correct,otherwise modify it.

cbasin=atl  # specify which basin you want to compute 
latmin=-60  # specify the minimum  latitude
latmax=60  # specify the maxmum latitude
depmin=200  # specify the minmum depth
depmax=2500  #specify the maxmum depth 


YY1=1957
YY1=`ls ${data}/opa0/outputs/${expid}* | head -1|cut -f3 -d"_"|cut -c1-4`
YY2=2009
YY2=`ls ${data}/opa0/outputs/${expid}* | tail -1|cut -f3 -d"_"|cut -c1-4`
YYINT=1


################### End of user's modification ###############################

if [[ $latmin -lt 0 ]]; then
latname1=$((latmin*-1))S
elif [[ $latmin -eq 0 ]];then
latname1=$latmin
else [[ $latmin -gt 0 ]]
latname1=${latmin}N
fi


if [[ $latmax -lt 0 ]];then
latname2=$((latmax*-1))S
elif [[ $latmax -eq 0 ]];then
latname2=$latmax
else 
[[ $latmax -gt 0 ]]
latname2=${latmax}N
fi



rm -rf ${tmp_dir}
mkdir -p ${tmp_dir}
mkdir -p ${save_dir}
mkdir -p ${save_dir_maxmoc}
cd $tmp_dir



#get the start year and month of the NEMOVAR data
sdate=`ls ${data}/opa0/outputs/${expid}* | head -1|cut -f3 -d"_"|cut -c1-6` 


# Check the existence of above tools
if tool=$cdo      && test ! -f $tool || \
   tool=$ncrename && test ! -f $tool || \
   tool=$ncatted  && test ! -f $tool || \
   tool=$ncl      && test ! -f $tool; then
 echo "$tool does not exist!!!"
 exit 1
fi

cp $HOME/cdfmoc .
cp $HOME/cdfmaxmoc .

grid=grid_V

exec1=cdfmoc
#scp $USER@forseti:${cdftools}/${exec1} .  # this command is for running the script at other machines, but you have to set the ssh keys files so that no password is need to scp a file. 
ln -sf $con_files/mask.nc .
ln -sf $con_files/mesh_hgr.nc .
ln -sf $con_files/mesh_zgr.nc .
ln -sf $con_files/new_maskglo.nc .

exec2=cdfmaxmoc
#scp $USER@forseti:${cdftools}/$exec2 .

#para="$cbasin $latmin $latmax $depmin $depmax cdfout"
para="$cbasin $latmin $latmax $depmin $depmax"

tmp_kmin=$kmin
tmp_kmax=$kmax


############ calcualte time between any two dates ###############


t_unit=h  #set unit of time

syy=`echo $sdate|cut -c1-4`
smm=`echo $sdate|cut -c5-6`
rdate=$syy-$smm-1

date2stamp () {
    date --utc --date "$1" +%s
}

stamp2date (){
    date --utc --date "$rdate $1 sec" "+%Y-%m-%d %T"
}


dateDiff (){
    case $1 in
        -s)   sec=1; timeunit=seconds;     shift;;
        -m)   sec=60;timeunit=minutes;     shift;;
        -h)   sec=3600; timeunit=hours;  shift;;
        -d)   sec=86400; timeunit=days; shift;;
        *)    sec=86400; timeunit=seconds;
    esac
    dte1=$(date2stamp $1)
    dte2=$(date2stamp $2)
    diffSec=$((dte2-dte1))
    if ((diffSec < 0)); then abs=-1; else abs=1; fi
    echo $((diffSec/sec*abs))
    value=$((diffSec/sec*abs))
    return $value
}

# usage: dateDiff -${t_unit} $ds $tmp # where
############ end of calculation of time ##############################

### Actual Computation ###
##########################
for mem in ${members}; do # loop for members

 echo "******************** $mem *********************"
 echo
YY=$YY1


### create ncl script to add time information to the moc file ###
#######################
cat > addtime.ncl << EOF
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
;***********************************
begin

 f=addfile("ncl.nc","w")
 f->time_counter(0)=tvalue

end
EOF

#######################################################


while [[ $YY -le $YY2 ]]; do

cp $data/${mem}/outputs/${expid}*${YY}*${grid}*.gz .

for file in `ls *.gz`; do #loop for gz files
gunzip ${file}
done # loop for gz files
chmod 777 *.nc

for file in `ls ${expid}*.nc`; do # loop for nc files

  yy=`ls ${file}|cut -f3 -d"_"|cut -c1-4`
  mm=`ls ${file}|cut -f3 -d"_"|cut -c5-6`
  dateDiff -${t_unit} $rdate ${yy}-${mm}-1
  dt=$value
  
#  ./$exec1 ${file} 
  ./cdfmoc ${file}

  $ncatted -h -a units,time,m,c,"hours since $syy-$smm-1 00:00:00" moc.nc
  mv moc.nc ncl.nc; $ncl tvalue=$dt addtime.ncl; mv ncl.nc moc_${file} 

#  ./$exec2 moc_${file} $para; mv maxmoc.nc maxmoc_${file}  
  ./cdfmaxmoc moc_${file} $para; 

  $ncatted -h -a units,time,m,c,"hours since $syy-$smm-1 00:00:00" maxmoc.nc
  mv maxmoc.nc maxmoc_${file}  
  rm -r ${file}
#  t=$((t+1))

done #loop for nc files


YY=$((YY+YYINT))

done #loop for years

files=`ls moc_*.nc`
cdo mergetime ${files} moc_${mem}.nc; rm ${files} 
$ncatted -h -a units,time,m,c,"hours since $syy-$smm-1 00:00:00" moc_${mem}.nc

files=`ls maxmoc_*.nc`
cdo mergetime ${files} maxmoc_${mem}.nc; rm ${files}
$ncatted -h -a units,time,m,c,"hours since $syy-$smm-1 00:00:00" maxmoc_${mem}.nc


mv moc_${mem}.nc ${save_dir}
mv maxmoc_${mem}.nc ${save_dir_maxmoc}
done # loop for members


rm -r *.ncl  mask.nc mesh*.nc  new_maskglo.nc


cd 

rm -r $tmp_dir 






echo "Done"

