# Checking 
#!/bin/sh
#set -evx # uncommented: it prints the commands in the screen
#
# 


DATADIR=/cfu/scratch/${USER}/heatc
WORKDIR="/cfu/scratch/${USER}/$$"
expid=b013
MMDD=0201
YYINI=1989
YYEND=1989
YYINT=5
type=global
type=land
type=sea
default_var=thc
var=$1
imin=0
imax=0
jmin=0
jmax=0
dep1=0
dep2=657 # set 5051m, 657m or 315m
# Check arguments 


if [ "$1" = "" ]
then
  echo "Usage: heatc.mat.sh followed by thc/uhc!" 
  exit

fi

#




if [ "$var" = "thc" ]
then
  title="Total Heat Content (10^22 Joules) from depth of 0-${dep2}" 
  factor=1/10^22
else
  title="Unit Heat Content (Joules/m3) from depth of 0-${dep2}"
  factor=1
fi

echo $title







LASTYEAR=$((YYEND+5))

ndata=$(((YYEND-YYINI)/5+1)) # calculate the number of start dates
nt=$(((YYEND-YYINI+5)*12)) # number of months for ploting, et. number of timesteps

cdate=`seq $YYINI $YYINT $YYEND`
echo $ndata $cdate

cyear=""

for ((i=1;i<=$ndata;i++));do

tmpc=`echo $cdate|cut -f$i -d" "`
if [[ i -eq 1 ]]; then
cyear=${cyear}${tmpc}
else
cyear=${cyear}","${tmpc}
fi
done
echo $cyear

yy1=$YYINI
mm1=`echo $MMDD|cut -c1-2`


[[ -d $WORKDIR ]] || mkdir -p $WORKDIR
cd ${WORKDIR}
plotsdir="/cfu/scratch/${USER}/analysis"
[[ -d $plotsdir ]] || mkdir -p $plotsdir
#
# Write the R script testing ncdf (in temporary plot_test in the workdir)
#

# 
# the following piece of code tries to extract the observational data based on the year and month
#

nemovar=$DATADIR/nemovar/ohc_fc0_0-5051_global.nc
nt_obs=`cdo ntime $nemovar`

for ((i=1;i<=$nt_obs;i++)); do
yy=`cdo showyear -seltimestep,$i $nemovar`
mm=`cdo showmon -seltimestep,$i $nemovar`
if [[ $yy -eq $yy1 && $mm -eq $mm1 ]]; then
st_obs=$i
break
fi

done


#output=heatc_${var}_${expid}_${YYINI}-${YYEND}.ps
output=heatc_${var}_${expid}_${YYINI}-${YYEND}.png
#ghnc=${DATADIR}/ghnc/gm_tas_ghcn.nc

cat>$WORKDIR/plot_test<<EOF

library(ncdf)

empty=array(dim=$nt)
ohc_model=array(dim=c($nt,5,$ndata))
ohc_obs=array(dim=c($nt,5))


#for (i in c("0","1","2","3","4")) {
for (i in c("1","2")) {
file=paste("${DATADIR}/nemovar/","ohc_fc",i,"_${dep1}-${dep2}_global.nc",sep="")
fnc=open.ncdf(file)
var=get.var.ncdf(fnc,"$var")*${factor}
index_i=as.integer(i)+1
index_t1=as.integer(${st_obs})
index_t2=index_t1+$nt-1
ohc_obs[,index_i]=var[index_t1:index_t2]
}





for (i in c($cyear)) {
for (j in c("0","1","2","3","4")) {
#file=paste("${DATADIR}/${expid}/","ohc_","${expid}_",i,"${MMDD}_","fc",j,"_ORCA1_","${imin}-${imax}_","${jmin}-${jmax}_","${dep1}-${dep2}",".nc",sep="")
file=paste("${DATADIR}/${expid}/","ohc_","${expid}_",i,"${MMDD}_","fc",j,"_ORCA1_","${dep1}-${dep2}",".nc",sep="")
fnc=open.ncdf(file)
var=get.var.ncdf(fnc,"$var")*${factor}
index_j=as.integer(j)+1
index_i=(as.integer(i)-${YYINI})/5+1
index_t1=((as.integer(i)-${YYINI})/5)*60+1
index_t2=index_t1+59
ohc_model[index_t1:index_t2,index_j,index_i]=var
}
}



empty_ts=ts(empty,start=c($YYINI,11),end=c($LASTYEAR,10),frequency=12)


ulimit=max(ohc_obs,ohc_model,na.rm=TRUE)
llimit=min(ohc_obs,ohc_model,na.rm=TRUE)
middle=(ulimit+llimit)/2+(ulimit-llimit)*0.2
right=$nt+$nt/12
#
#
#postscript("$plotsdir/${output}",width=550,height=550)
png("$plotsdir/${output}",width=550,height=300)
#par(mai=c(1,1,1,2.5))

plot(empty_ts,ylim=c(llimit,ulimit),ylab="")

par(new=TRUE)
matplot(ohc_obs,lty=1,type="l",ylim=c(llimit,ulimit),col=1,ylab="${title}",main="Ocean heat content",labels=FALSE,axes=FALSE)

color=rainbow($ndata)
for (i in 1:$ndata) {
par(new=TRUE)
matplot(ohc_model[,1:5,i],lty=1,type="l",ylim=c(llimit,ulimit),col=color[i],ylab="",labels=FALSE,axes=FALSE)
} 

#par(new=TRUE)
#matplot(t2[,1:5,1],type="l",ylim=c(llimit,ulimit),col=2:6,ylab="",labels=FALSE,axes=FALSE)
par(new=TRUE)
#matplot(t2[,1:5,2],type="l",ylim=c(llimit,ulimit),col=2:6,ylab="",labels=FALSE,axes=FALSE)
#par(new=TRUE)
#matplot(t2[,1:5,3],type="l",ylim=c(llimit,ulimit),col=2:6,ylab="",labels=FALSE,axes=FALSE)
par(xpd=TRUE)
#legend(0,ulimit,c("Ncep Reanalysis","fc0","fc1","fc2","fc3","fc4"),lwd=c(1,1),col=1:6)
#legend(right,middle,c("nemovar_fc0","nemovar_fc1","nemovar_fc2","nemovar_fc3","nemovar_fc4","model_fc0","model_fc1","model_fc2","model_fc3","model_fc4"),lty=c(1,1,1,1,1,2,2,2,2,2),col=1:5)
legend(0,ulimit,"NEMOVAR",lty=1,col=1)


dev.off()
#
# Closing the R script
#
EOF
#cat plot_test # uncommented: it shows the R script in the screen
#
# Run the R script
#
R CMD BATCH $WORKDIR/plot_test
echo "Please go to ${plotsdir} to check the plots and the log files"
cp plot_test  /cfu/scratch/$USER/log 
cp plot_test.Rout  /cfu/scratch/$USER/log
#
rm -rf $WORKDIR
gv ${plotsdir}/${output}
