# Checking 
#!/bin/sh
#set -evx # uncommented: it prints the commands in the screen
#
# 

####### Beginning of user modifications#############
DATADIR=/cfu/scratch/${USER}/precip
WORKDIR="/cfu/scratch/${USER}/$$"
expid=b013
MMDD=1101
YYINI=1960
YYEND=$1
YYINT=5
type=land
type=sea
type=land
data_obs=gpcc/gm_prlr_gpcc.nc
suffix=global
var=precip
format=1  # plot format,  1 for postscript and 0 for png
########### End of user modifications ##############

# Check arguments 

if [ "$1" = "" ]
then
  echo "Usage: please specify specify the ending year!" 
  exit
fi


#






LASTYEAR=$((YYEND+5))

ndata=$(((YYEND-YYINI)/5+1)) # calculate the number of start dates
nt=$(((YYEND-YYINI+5)*12)) # number of months for ploting, et. number of timesteps

cdate=`seq $YYINI $YYINT $YYEND`
echo $ndata $cdate

cyear=""

for ((i=1;i<=$ndata;i++));do

tmpc=`echo $cdate|cut -f$i -d" "`
if [[ i -eq 1 ]]; then
cyear=${cyear}${tmpc}
else
cyear=${cyear}","${tmpc}
fi
done
echo $cyear

yy1=$YYINI
mm1=`echo $MMDD|cut -c1-2`


[[ -d $WORKDIR ]] || mkdir -p $WORKDIR
cd ${WORKDIR}
plotsdir="/cfu/scratch/${USER}/analysis"
[[ -d $plotsdir ]] || mkdir -p $plotsdir
#
# Write the R script testing ncdf (in temporary plot_test in the workdir)
#
obs=${DATADIR}/${data_obs}
#era=${DATADIR}/eraint/gm_tas_${type}_eraint.nc

# 
# the following piece of code tries to extract the observational data based on the year and month
#
nt_obs=`cdo ntime $obs`

for ((i=1;i<=$nt_obs;i++)) do
yy=`cdo showyear -seltimestep,$i $obs`
mm=`cdo showmon -seltimestep,$i $obs`
if [[ $yy -eq $yy1 && $mm -eq $mm1 ]]; then
st_obs=$i
break
fi

done

if [[ $format -eq 1 ]]
then
output=precip_${expid}_${type}_${YYINI}-${YYEND}.ps
plot_option=postscript
display=gv
else
output=precip_${expid}_${type}_${YYINI}-${YYEND}.png
plot_option=png
display=eog
fi


#output=precip_${expid}_${type}_${YYINI}-${YYEND}.ps

#ghnc=${DATADIR}/ghnc/gm_tas_ghcn.nc

cat>$WORKDIR/plot_test<<EOF

library(ncdf)


var_mod=array(dim=c($nt,5,$ndata))
var_obs=array(dim=c($nt))

for (i in c($cyear)) {
for (j in c("0","1","2","3","4")) {
file=paste("${DATADIR}/${expid}/",i,"${MMDD}","/gm_${var}_${type}_${expid}_",i,"$MMDD","_fc",j,"_","${suffix}",".nc",sep="")
fnc=open.ncdf(file)
tvar=get.var.ncdf(fnc,"$var")
index_j=as.integer(j)+1
index_i=(as.integer(i)-1960)/5+1
index_t1=((as.integer(i)-1960)/5)*60+1
index_t2=index_t1+59
#var_mod[index_t1:index_t2,index_j,index_i]=tvar
var_mod[index_t1:index_t2,index_j,index_i]=tvar*1000*8
}
}

file_obs=open.ncdf("${obs}")

tmp=get.var.ncdf(file_obs,"$var")
obs=tmp*3600*24*1000

index_t1=$st_obs
index_t2=index_t1+$nt-1
var_obs=obs[index_t1:index_t2]
var_obs_ts=ts(var_obs,start=c($YYINI,11),end=c($LASTYEAR,10),frequency=12)


ulimit=max(var_mod,var_obs,na.rm=TRUE)+0.2
llimit=min(var_mod,var_obs,na.rm=TRUE)
middle=(ulimit+llimit)/2+(ulimit-llimit)*0.2
right=$nt+$nt/12
#
#
#postscript("$plotsdir/${output}",width=550,height=550)
${plot_option}("$plotsdir/${output}",width=550,height=300)
#par(mai=c(1,1,1,2.5))
plot(var_obs_ts,type="l",ylim=c(llimit,ulimit),col=1,ylab="Precipitation (mm/Day)",main="precipitation for $type")

color=rainbow($ndata)
for (i in 1:$ndata) {
par(new=TRUE)
matplot(var_mod[,1:5,i],type="l",ylim=c(llimit,ulimit),col=color[i],ylab="",labels=FALSE,axes=FALSE)
} 

par(new=TRUE)
#matplot(t2[,1:5,1],type="l",ylim=c(llimit,ulimit),col=2:6,ylab="",labels=FALSE,axes=FALSE)
par(new=TRUE)
#matplot(t2[,1:5,2],type="l",ylim=c(llimit,ulimit),col=2:6,ylab="",labels=FALSE,axes=FALSE)
par(xpd=TRUE)
#legend(0,ulimit,c("GPCC","fc0","fc1","fc2","fc3","fc4"),lwd=c(1,1),col=1:6)
#legend(right,middle,c("GPCC","fc0","fc1","fc2","fc3","fc4"),lwd=c(1,1),col=1:6)
legend(0,ulimit,"GPCC",lwd=1,col=1)


dev.off()
#
# Closing the R script
#
EOF
#cat plot_test # uncommented: it shows the R script in the screen
#
# Run the R script
#
R CMD BATCH $WORKDIR/plot_test
echo "Please go to ${plotsdir} to check the plots and the log files"
cp plot_test  /cfu/scratch/$USER/log 
cp plot_test.Rout  /cfu/scratch/$USER/log
#
rm -rf $WORKDIR
${display} ${plotsdir}/${output}
