# Checking 
#!/bin/sh
#set -evx # uncommented: it prints the commands in the screen
#
# 


DATADIR=/cfu/scratch/${USER}/sst
WORKDIR="/tmp/sst_$$"
expid=b013
MMDD=1101
YYINI=1960
YYEND=2005
YYINT=5
type=global
type=land
type=sea
var=SSTK
lonmin=-180
lonmax=180
latmin=-60
latmax=65
format=1  # plot format,  1 for postscript and 0 for png

# Check arguments 
check.arg(){
if [ "$1" = "" ]
then
  echo "Usage: please specify one of the arguments of global/land/sea!" 
  exit
fi
}

#

###
if [[ $latmin -lt 0 ]]; then
latname1=$((latmin*-1))S
elif [[ $latmin -eq 0 ]];then
latname1=$latmin
else [[ $latmin -gt 0 ]]
latname1=${latmin}N
fi


if [[ $latmax -lt 0 ]];then
latname2=$((latmax*-1))S
elif [[ $latmax -eq 0 ]];then
latname2=$latmax
else 
[[ $latmax -gt 0 ]]
latname2=${latmax}N
fi



if [[ $lonmin -lt 0 ]]; then
lonname1=$((lonmin*-1))W
elif [[ $lonmin -eq 0 ]];then
lonname1=$lonmin
else [[ $lonmin -gt 0 ]]
lonname1=${lonmin}E
fi


if [[ $lonmax -lt 0 ]];then
lonname2=$((lonmax*-1))W
elif [[ $lonmax -eq 0 ]];then
lonname2=$lonmax
else
[[ $lonmax -gt 0 ]]
lonname2=${lonmax}E
fi

if [[ $ifglobal -eq 1 ]]; then 
suffix=global
para=""
else
suffix=${lonname1}-${lonname2}_${latname1}-${latname2}
para="-sellonlatbox,$lonmin,$lonmax,$latmin,$latmax"
fi



####


title="sea surface temperature for ${latname1}-${latname2} (C)"



LASTYEAR=$((YYEND+5))

ndata=$(((YYEND-YYINI)/5+1)) # calculate the number of start dates
nt=$(((YYEND-YYINI+5)*12)) # number of months for ploting, et. number of timesteps

cdate=`seq $YYINI $YYINT $YYEND`
echo $ndata $cdate

cyear=""

for ((i=1;i<=$ndata;i++));do

tmpc=`echo $cdate|cut -f$i -d" "`
if [[ i -eq 1 ]]; then
cyear=${cyear}${tmpc}
else
cyear=${cyear}","${tmpc}
fi
done
echo $cyear

yy1=$YYINI
mm1=`echo $MMDD|cut -c1-2`


[[ -d $WORKDIR ]] || mkdir -p $WORKDIR
cd ${WORKDIR}
plotsdir="/cfu/scratch/${USER}/analysis"
[[ -d $plotsdir ]] || mkdir -p $plotsdir
#
# Write the R script testing ncdf (in temporary plot_test in the workdir)
#
obs1=${DATADIR}/noaa/tos_ts_${suffix}.nc
obs2=${DATADIR}/ukmo/tos_ts_${suffix}.nc

# 
# the following piece of code tries to extract the observational data based on the year and month
#
nt_obs1=`cdo ntime $obs1`
nt_obs2=`cdo ntime $obs2`

for ((i=1;i<=$nt_obs1;i++)) do
yy=`cdo showyear -seltimestep,$i $obs1`
mm=`cdo showmon -seltimestep,$i $obs1`
if [[ $yy -eq $yy1 && $mm -eq $mm1 ]]; then
st_obs1=$i
break
fi

done


for ((i=1;i<=$nt_obs2;i++)) do
yy=`cdo showyear -seltimestep,$i $obs2`
mm=`cdo showmon -seltimestep,$i $obs2`
if [[ $yy -eq $yy1 && $mm -eq $mm1 ]]; then
st_obs2=$i
break
fi

done



if [[ $format -eq 1 ]]
then
output=${var}_${expid}_${suffix}_${YYINI}-${YYEND}.ps
plot_option=postscript
display=gv
else
output=${var}_${expid}_${suffix}_${YYINI}-${YYEND}.png
plot_option=png
display=eog
fi


#output=sst_${expid}_${type}_${YYINI}-${YYEND}.png

#ghnc=${DATADIR}/ghnc/gm_tas_ghcn.nc

cat>$WORKDIR/plot_test<<EOF

library(ncdf)


sst_model=array(dim=c($nt,5,$ndata))
sst_obs=array(dim=c($nt,2))

for (i in c($cyear)) {
for (j in c("0","1","2","3","4")) {
file=paste("${DATADIR}/${expid}/",i,"${MMDD}","/gm_${var}_sea_${expid}_",i,"$MMDD","_fc",j,"_${suffix}.nc",sep="")
fnc=open.ncdf(file)
tvar=get.var.ncdf(fnc,"$var")
index_j=as.integer(j)+1
index_i=(as.integer(i)-1960)/5+1
index_t1=((as.integer(i)-1960)/5)*60+1
index_t2=index_t1+59
sst_model[index_t1:index_t2,index_j,index_i]=tvar-273
}
}

# assign noaa observation data 
file=paste("${DATADIR}/noaa/tos_ts_","${suffix}.nc",sep="")
fnc=open.ncdf(file)
tvar=get.var.ncdf(fnc,"tos")-273.15
index_t1=as.integer(${st_obs1})
index_t2=index_t1+$nt-1
sst_obs[,1]=tvar[index_t1:index_t2]
#
# assign ukmo observation data
#
file=paste("${DATADIR}/ukmo/tos_ts_","${suffix}.nc",sep="")
 fnc=open.ncdf(file)
 tvar=get.var.ncdf(fnc,"tos")-273.15
 index_t1=as.integer(${st_obs2})
 index_t2=index_t1+$nt-1
 sst_obs[,2]=tvar[index_t1:index_t2]



empty=array(dim=$nt)
empty_ts=ts(empty,start=c($YYINI,11),end=c($LASTYEAR,10),frequency=12)



ulimit=max(sst_obs,sst_model,na.rm=TRUE)+0.5
llimit=min(sst_obs,sst_model,na.rm=TRUE)-0.5
#
${plot_option}("$plotsdir/${output}",width=550,height=300)
#png("$plotsdir/${output}",width=550,height=300)

plot(empty_ts,ylim=c(llimit,ulimit),ylab="")

par(new=TRUE)
matplot(sst_obs[,1],lty=1,type="l",ylim=c(llimit,ulimit),col=1,ylab="${title}",main="${title}",labels=FALSE,axes=FALSE)
par(new=TRUE)
matplot(sst_obs[,2],lty=2,type="l",ylim=c(llimit,ulimit),col=1,ylab="${title}",main="${title}",labels=FALSE,axes=FALSE)



color=rainbow($ndata)
for (i in 1:$ndata) {
par(new=TRUE)
matplot(sst_model[,1:5,i],type="l",lty=c(1),ylim=c(llimit,ulimit),col=color[i],ylab="",labels=FALSE,axes=FALSE)
} 

par(new=TRUE)
#matplot(t2[,1:5,1],type="l",ylim=c(llimit,ulimit),col=2:6,ylab="",labels=FALSE,axes=FALSE)
par(new=TRUE)
#matplot(t2[,1:5,2],type="l",ylim=c(llimit,ulimit),col=2:6,ylab="",labels=FALSE,axes=FALSE)
#par(new=TRUE)
#matplot(t2[,1:5,3],type="l",ylim=c(llimit,ulimit),col=2:6,ylab="",labels=FALSE,axes=FALSE)
par(xpd=TRUE)
#legend(0,ulimit,c("Ncep Reanalysis","fc0","fc1","fc2","fc3","fc4"),lwd=c(1,1),col=1:6)
legend(0,ulimit,c("NOAA","UKMO"),lty=c(1,2),col=c(1,1))


dev.off()
#
# Closing the R script
#
EOF
#cat plot_test # uncommented: it shows the R script in the screen
#
# Run the R script
#
R CMD BATCH $WORKDIR/plot_test
echo "Please go to ${plotsdir} to check the plots and the log files"
cp plot_test  /cfu/scratch/$USER/log 
cp plot_test.Rout  /cfu/scratch/$USER/log
#
rm -rf $WORKDIR
chmod 775 ${plotsdir}/${output}
${display} ${plotsdir}/${output}
