# Checking 
#!/bin/sh
#set -evx # uncommented: it prints the commands in the screen
#
# 


DATADIR=/cfu/scratch/${USER}/t2
WORKDIR="/cfu/scratch/${USER}/$$"
expid=b013
MMDD=1101
YYINI=1960
YYEND=1970
YYINT=5
type=global
type=land
type=sea
type=$1
var=T2M
# Check arguments 

if [ "$1" = "" ]
then
  echo "Usage: please specify one of the arguments of global/land/sea!" 
  exit
fi


#






LASTYEAR=$((YYEND+5))

ndata=$(((YYEND-YYINI)/5+1)) # calculate the number of start dates
nt=$(((YYEND-YYINI+5)*12)) # number of months for ploting, et. number of timesteps

cdate=`seq $YYINI $YYINT $YYEND`
echo $ndata $cdate

cyear=""

for ((i=1;i<=$ndata;i++));do

tmpc=`echo $cdate|cut -f$i -d" "`
if [[ i -eq 1 ]]; then
cyear=${cyear}${tmpc}
else
cyear=${cyear}","${tmpc}
fi
done
echo $cyear

yy1=$YYINI
mm1=`echo $MMDD|cut -c1-2`


[[ -d $WORKDIR ]] || mkdir -p $WORKDIR
cd ${WORKDIR}
plotsdir="/cfu/scratch/${USER}/analysis"
[[ -d $plotsdir ]] || mkdir -p $plotsdir
#
# Write the R script testing ncdf (in temporary plot_test in the workdir)
#
ncep=${DATADIR}/ncep/gm_tas_${type}_ncep.nc
era=${DATADIR}/eraint/gm_tas_${type}_eraint.nc

# 
# the following piece of code tries to extract the observational data based on the year and month
#
nt_ncep=`cdo ntime $ncep`
nt_era=`cdo ntime ${era}`

for ((i=1;i<=$nt_ncep;i++)) do
yy=`cdo showyear -seltimestep,$i $ncep`
mm=`cdo showmon -seltimestep,$i $ncep`
if [[ $yy -eq $yy1 && $mm -eq $mm1 ]]; then
st_ncep=$i
break
fi

done



output=t2_${expid}_${type}_${YYINI}-${YYEND}.ps
#output=t2_${expid}_${type}_${YYINI}-${YYEND}.png

#ghnc=${DATADIR}/ghnc/gm_tas_ghcn.nc





cat>$WORKDIR/plot_test<<EOF

library(ncdf)


t2=array(dim=c($nt,5,$ndata))
t2_ncep=array(dim=c($nt))

for (i in c($cyear)) {
#for (j in c("0","1","2","3","4")) {
for (j in c("0","1","2","3")) {
file=paste("${DATADIR}/${expid}/",i,"${MMDD}","/gm_${var}_${type}_${expid}_",i,"$MMDD","_fc",j,".nc",sep="")
fnc=open.ncdf(file)
tvar=get.var.ncdf(fnc,"$var")
index_j=as.integer(j)+1
index_i=(as.integer(i)-1960)/5+1
index_t1=((as.integer(i)-1960)/5)*60+1
index_t2=index_t1+59
t2[index_t1:index_t2,index_j,index_i]=tvar
}
}

ncep_nc=open.ncdf("${ncep}")
era_nc=open.ncdf("${era}")


ncep=get.var.ncdf(ncep_nc,"air")
era=get.var.ncdf(era_nc,"tas")


index_t1=$st_ncep
index_t2=index_t1+$nt-1
t2_ncep=ncep[index_t1:index_t2]
t2_ncep_ts=ts(t2_ncep,start=c($YYINI,11),end=c($LASTYEAR,10),frequency=12)


ulimit=max(t2,t2_ncep,na.rm=TRUE)+0.5
llimit=min(t2,t2_ncep,na.rm=TRUE)-0.5
middle=(ulimit+llimit)/2+(ulimit-llimit)*0.2
right=$nt+$nt/12
#
#
postscript("$plotsdir/${output}",width=550,height=550)
#png("$plotsdir/${output}",width=550,height=300)
#${plot_option}("$plotsdir/${output}",width=550,height=300)
#par(mai=c(1,1,1,2.5))
#plot(t2_ncep_ts,type="l",ylim=c(llimit,ulimit),col=1,ylab="Temperature (K)",main="Time series of monthly-mean 2-meter temperature for $type")
#plot(t2_ncep_ts,lty=c(1),type="l",ylim=c(llimit,ulimit),col=1,ylab="Temperature (K)",main="Time series of monthly-mean 2-meter temperature for $type")
plot(t2_ncep_ts,lty=c(1),type="l",ylim=c(llimit,ulimit),col=1,ylab="Temperature (K)",main="$type")

color=rainbow($ndata)
for (i in 1:$ndata) {
par(new=TRUE)
matplot(t2[,1:5,i],type="l",lty=c(1),ylim=c(llimit,ulimit),col=color[i],ylab="",labels=FALSE,axes=FALSE)
} 

par(new=TRUE)
#matplot(t2[,1:5,1],type="l",ylim=c(llimit,ulimit),col=2:6,ylab="",labels=FALSE,axes=FALSE)
par(new=TRUE)
#matplot(t2[,1:5,2],type="l",ylim=c(llimit,ulimit),col=2:6,ylab="",labels=FALSE,axes=FALSE)
#par(new=TRUE)
#matplot(t2[,1:5,3],type="l",ylim=c(llimit,ulimit),col=2:6,ylab="",labels=FALSE,axes=FALSE)
par(xpd=TRUE)
#legend(0,ulimit,c("Ncep Reanalysis","fc0","fc1","fc2","fc3","fc4"),lwd=c(1,1),col=1:6)
legend(0,ulimit,"Ncep Reanalysis",lwd=1,col=1)


dev.off()
#
# Closing the R script
#
EOF
#cat plot_test # uncommented: it shows the R script in the screen
#
# Run the R script
#
R CMD BATCH $WORKDIR/plot_test
echo "Please go to ${plotsdir} to check the plots and the log files"
cp plot_test  /cfu/scratch/$USER/log 
cp plot_test.Rout  /cfu/scratch/$USER/log
#
rm -rf $WORKDIR
gv  ${plotsdir}/${output}
