# Checking 
#!/bin/sh
#set -evx # uncommented: it prints the commands in the screen
#
# 


DATADIR=/cfu/data/ukmo/hadisst/monthly_mean/ice
WORKDIR="/scratch/tmp/$$"
WORKDIR="/cfu/scratch/${USER}/grid_area_$$"
CON_DIR="/cfu/pub/scripts/CDFTOOLS/constant_files"
FILEIN=ice_hadisst_187001-201009.nc
FILEOUT=grid_area.nc
VARIN=sea_ice_area_fraction
VAROUT=grid_area
R=6371220 # mean radius of earth (meter)
PI=3.1415926


[[ -d $WORKDIR ]] || mkdir -p $WORKDIR
cd ${WORKDIR}

#creat a output file 
cdo seltimestep,1 ${DATADIR}/${FILEIN} ${FILEOUT}
ncks -h -O -v time ${DATADIR}/${FILEIN} time.nc
ncrename -v ${VARIN},${VAROUT} ${FILEOUT}
ncwa -O -h -a time ${FILEOUT} tmp.nc;rm ${FILEOUT}
ncks -v lon,lat,grid_area tmp.nc ${FILEOUT}

for v in cell_methods actual_range description;do
ncatted -h -a ${v},grid_area,d,, ${FILEOUT}
done

ncatted -h -a long_name,grid_area,m,c,"Lon/Lat Grid box area" ${FILEOUT}
ncatted -h -a units,grid_area,m,c,"m3" ${FILEOUT}
ncatted -h -a standard_name,grid_area,m,c,"lon_lat_grid_box_area" ${FILEOUT}

cp ${CON_DIR}/ice_template.nc ice_hadisst_N.nc
cp ${CON_DIR}/ice_template.nc ice_hadisst_S.nc
cp ${CON_DIR}/grid_area.nc .

for D in S; do

case ${D} in 
  N)
  j1=0
  j2=59
  ;;
  S)
  j1=120
  j2=179
  ;;
esac

cat>$WORKDIR/test.ncl<<EOF
load "/usr/share/ncarg/nclscripts/csm/gsn_code.ncl"
load "/usr/share/ncarg/nclscripts/csm/gsn_csm.ncl"  
load "/usr/share/ncarg/nclscripts/csm/contributed.ncl"  


begin 
 fice=addfile("${DATADIR}/${FILEIN}","w")
 farea=addfile("grid_area.nc","w")

 fout=addfile("ice_hadisst_${D}.nc","w")
 frac=fice->sea_ice_area_fraction 
 dimsize_v=dimsizes(fice->sea_ice_area_fraction)
 nlon=dimsize_v(2)
 nlat=dimsize_v(1)  
 nt=dimsize_v(0)
 grid_area=farea->grid_area

 do k=0,nt-1
 sia=0.
 sie=0.
  do i=0,nlon-1
   do j=${j1},${j2}
   
   if (.not.ismissing(frac(k,j,i))) then
     if (frac(k,j,i).gt.0.15) then
    
      sia=sia+frac(k,j,i)*grid_area(j,i)
      sie=sie+grid_area(j,i)
     end if
   end if

   end do 
  end do   

   fout->sia(k)=sia/10^12
   fout->sie(k)=sie/10^12

 end do


end

EOF
ncl $WORKDIR/test.ncl
ncks -h -A time.nc ice_hadisst_${D}.nc
ncatted -h -a units,sia,m,c,"million km2" ice_hadisst_${D}.nc
ncatted -h -a units,sie,m,c,"million km2" ice_hadisst_${D}.nc
#cdo divc,10^9 ice_hadisst_${D}.nc toto.nc; rm ice_hadisst_${D}.nc; mv toto.nc ice_hadisst_${D}.nc
done


cd ${WORKDIR}
#
#rm -rf $WORKDIR
