#!/bin/sh
set -evx 

DATADIR=/cfu/scratch/${USER}/sst
WORKDIR=/cfu/scratch/${USER}/tmp/anomaly_sst_$$
EXPID=b014
MMDD=1101
YYINI=1960
YYEND=2005
YYINT=5
TYPE=global  # Please specify one of global/land/sea 
VAR=SSTK
PLOT_TYPE=png
width=700
height=300
LONMIN=-180
LONMAX=180
LATMIN=-60
LATMAX=65

# Check arguments 
check_arg(){
if [ "$1" = "" ]
then
  echo "Usage: please specify one of the arguments of global/land/sea!" 
  exit
fi
}
#check_arg
#
###
if [[ $LATMIN -lt 0 ]]; then
latname1=$((LATMIN*-1))S
elif [[ $LATMIN -eq 0 ]];then
latname1=$LATMIN
else [[ $LATMIN -gt 0 ]]
latname1=${LATMIN}N
fi


if [[ $LATMAX -lt 0 ]];then
latname2=$((LATMAX*-1))S
elif [[ $LATMAX -eq 0 ]];then
latname2=$LATMAX
else 
[[ $LATMAX -gt 0 ]]
latname2=${LATMAX}N
fi


if [[ $LONMIN -lt 0 ]]; then
lonname1=$((LONMIN*-1))W
elif [[ $LONMIN -eq 0 ]];then
lonname1=$LONMIN
else [[ $LONMIN -gt 0 ]]
lonname1=${LONMIN}E
fi


if [[ $LONMAX -lt 0 ]];then
lonname2=$((LONMAX*-1))W
elif [[ $LONMAX -eq 0 ]];then
lonname2=$LONMAX
else
[[ $LONMAX -gt 0 ]]
lonname2=${LONMAX}E
fi

if [[ $IFGLOBAL -eq 1 ]]; then 
suffix=""
para=""
title="${TYPE}"
else
suffix=_${lonname1}-${lonname2}_${latname1}-${latname2}
para="-sellonlatbox,$LONMIN,$LONMAX,$LATMIN,$LATMAX"
title="${TYPE} (${lonname1}-${lonname2}_${latname1}-${latname2})"
fi


####


LASTYEAR=$((YYEND+5))

ndata=$(((YYEND-YYINI)/YYINT+1)) # calculate the number of start dates
nt=$(((YYEND-YYINI+YYINT)*12)) # number of months for ploting, et. number of timesteps

cdate=`seq $YYINI $YYINT $YYEND`
echo $ndata $cdate

cyear=""

for ((i=1;i<=$ndata;i++));do

tmpc=`echo $cdate|cut -f$i -d" "`
if [[ i -eq 1 ]]; then
cyear=${cyear}${tmpc}
else
cyear=${cyear}","${tmpc}
fi
done
echo $cyear

yy1=$YYINI
mm1=`echo $MMDD|cut -c1-2`


[[ -d $WORKDIR ]] || mkdir -p $WORKDIR
cd ${WORKDIR}
plotsdir="/cfu/scratch/${USER}/analysis"
[[ -d $plotsdir ]] || mkdir -p $plotsdir
#
# Write the R script testing ncdf (in temporary plot_test in the workdir)
#


# 
# the following piece of code tries to extract the observational data based on the year and month
#


case ${PLOT_TYPE} in 
  ps)
  output=clim_${VAR}_${EXPID}_${suffix}_${YYINI}-${YYEND}.ps
  plot_option=postscript
  display=gv
  ;;
  png)
  output=clim_${VAR}_${EXPID}_${suffix}_${YYINI}-${YYEND}.png
  plot_option=png
  display=eog
esac

echo "$plotsdir/${output}"

cat>$WORKDIR/plot_test<<EOF

library(ncdf)

${plot_option}("$plotsdir/${output}",width=$width,height=$height)
#postscript("$plotsdir/${output}",width=800,height=600)
#par(mfrow=c(3,1))

maxmoc_model=array(dim=c($nt,5,$ndata))
#maxmoc_obs=array(dim=c($nt,5))
model_clim=array(dim=c($YYINT*12))
#initialize that array
model_clim[]=0
print("Computing model climate")

for (i in c($cyear)) {
for (j in c("0","1","2","3","4")) {
file=paste("${DATADIR}/${EXPID}/",i,"${MMDD}","/gm_${VAR}_${EXPID}_",i,"$MMDD","_fc",j,"${suffix}.nc",sep="")
fnc=open.ncdf(file)
tvar=get.var.ncdf(fnc,"$VAR")
index_j=as.integer(j)+1
index_i=(as.integer(i)-${YYINI})/${YYINT}+1
index_t1=((as.integer(i)-${YYINI})/${YYINT})*${YYINT}*12+1
index_t2=index_t1+${YYINT}*12-1
print(index_j)
print(index_i)
print(index_t1)
print(index_t2)
maxmoc_model[index_t1:index_t2,index_j,index_i]=tvar
model_clim[1:60]=model_clim[1:60]+maxmoc_model[index_t1:index_t2,index_j,index_i]
}
}
model_clim=model_clim/($ndata*5)

print("Computing anomalies")
#Compute anomalies
anomalies=array(dim=c($YYINT*12,6,$ndata))
anomalies[]=0

for (i in c($cyear)) {
for (j in c("0","1","2","3","4")) {
index_j=as.integer(j)+1
index_i=(as.integer(i)-${YYINI})/${YYINT}+1
index_t1=((as.integer(i)-${YYINI})/${YYINT})*${YYINT}*12+1
index_t2=index_t1+${YYINT}*12-1
print(index_j)
print(index_i)
print(index_t1)
print(index_t2)
for ( k in 1:60 ) {
anomalies[k,index_j,index_i]=maxmoc_model[index_t1+k-1,index_j,index_i]-model_clim[k]
}
}
}

#Do an ensemble mean of those anomalies
for (j in 1:5) {
anomalies[,6,]=anomalies[,6,]+anomalies[,j,]
}
anomalies[,6,]=anomalies[,6,]/5
print("done!")

print("Smoothing anomalies")
#Applying running means anomalies
smt_anomalies=array(dim=c($YYINT*12,6,$ndata))

for (i in c($cyear)) {
for (j in 1:6) {
index_i=(as.integer(i)-${YYINI})/${YYINT}+1
for ( k in 4:56 ) {
smt_anomalies[k,j,index_i]=(anomalies[k-3,j,index_i]+anomalies[(k+3),j,index_i])/12+(anomalies[k-1,j,index_i]+anomalies[k-2,j,index_i]+anomalies[k,j,index_i]+anomalies[k+1,j,index_i]+anomalies[k+2,j,index_i])/6
}
}
}

#Putting everything back into a big area
print("putting things back into bigger area")
anom2=array(dim=c($nt,6,$ndata))
for (i in c($cyear)) {
for (j in 1:6) {
index_i=(as.integer(i)-${YYINI})/${YYINT}+1
index_t1=((as.integer(i)-${YYINI})/${YYINT})*${YYINT}*12+1
index_t2=index_t1+${YYINT}*12-1
anom2[index_t1:index_t2,j,index_i]=smt_anomalies[1:60,j,index_i]
}
}

empty=array(dim=$nt)
empty_ts=ts(empty,start=c($YYINI,11),end=c($LASTYEAR,10),frequency=12)

ulimit=max(anomalies,na.rm=TRUE)+0.5
print(ulimit)
llimit=min(anomalies,na.rm=TRUE)-0.5
print(llimit)


plot(empty_ts,ylim=c(llimit,ulimit),ylab="")
color=rainbow($ndata)

for (i in 1:$ndata) {
par(new=TRUE)
matplot(anom2[,1:5,i],type="l",lty=c(1),ylim=c(llimit,ulimit),col=color[i],ylab="",labels=FALSE,axes=FALSE)
par(new=TRUE)
matplot(anom2[,6,i],type="l",lty=1,lwd=3,lend=2,ylim=c(llimit,ulimit),col=color[i],ylab="",labels=FALSE,axes=FALSE)
} 

#plot(empty_ts,ylim=c(ulimit,llimit),ylab="")

#for (i in 1:$ndata) {
#par(new=TRUE)
#matplot(anom2[,6,i],type="l",lty=1,lwd=3,lend=2,ylim=c(ulimit,llimit),col=color[i],ylab="",labels=FALSE,axes=FALSE)
#} 


#matplot(model_clim,type="l",lty=c(1),col=1,ylab="",labels=TRUE,axes=TRUE)



dev.off()
#
# Closing the R script
#
EOF
#cat plot_test # uncommented: it shows the R script in the screen
#
# Run the R script
#
R CMD BATCH $WORKDIR/plot_test
echo "Please go to ${plotsdir} to check the plots and the log files"
cp plot_test  /cfu/scratch/$USER/log 
cp plot_test.Rout  /cfu/scratch/$USER/log
#
chmod -R 775 ${plotsdir}
${display} ${plotsdir}/${output}
