#!/bin/bash
##$ -N MOC
##$ -S /bin/bash
##$ -o /share/scratch/cfu/$USER/logs
##$ -j y
##$ -V
##$ -q serial.q

#
# This script is to compute area averaged AMOC from the NEMO output
#
# Written by Hui Du 
#
# Created:   May 25, 2011
#

set -exv

#
## General Settings ###
#
BASIN=atl  # atl, pac, ind
LATMIN=30.  #degree
LATMAX=40.  #degree
DEPMIN=-2000. #meters
DEPMAX=-1000. # meters
GRID=grid_V
EXPID=$1  # experiment ID
MEMBER_LST=( fc0 fc1 fc2 fc3 fc4 )
MEMBER_LST=( MyMEMBER )

MEMBER_LST_OBS=( opa0 opa1 opa2 opa3 opa4 )
SDATE_LST=( 19601101 19651101 19701101 19751101 19801101 19851101 19901101 19951101 20001101 20051101  )
SDATE=$2
SAVEDIR="/cfunas/diagnostics/postprocessed/moc/${EXPID}"
#SAVEDIR=$HOME
DATADIR="/cfunas/diagnostics/postprocessed/moc/${EXPID}"
DATA=model  #obs/model
#DATA=obs  #obs/model
WORKDIR="/var/tmp/$USER/moc"
MASK_FILE=ecearth_mm_lsm.nc
PATH_MASK="/cfu/pub/scripts/CDFTOOLS/constant_files"
ifglobal=0
#SCRIPTDIR="/share/data/cfu/common/scripts"
#
## End of general Settings #####
#
CDFTOOLS=/opt/cdftools/bin
CON_FILES=/cfu/pub/scripts/CDFTOOLS/constant_files
#PATH=${PATH}:/share/apps/cdftools-2.1/intel11/bin:/share/apps/cdo-1.4.5.1/intel11/bin/:/share/apps/nco-3.9.9/intel11/bin/:/share/apps/ferret/bin/:/share/apps/netcdf-3.6.0-p1/intel10/bin/
mkdir -p ${SAVEDIR} ${WORKDIR}

cd ${WORKDIR}

if [[ $LATMIN -lt 0 ]]; then
latname1=$((LATMIN*-1))S
elif [[ $LATMIN -eq 0 ]];then
latname1=$LATMIN
else [[ $LATMIN -gt 0 ]]
latname1=${LATMIN}N
fi


if [[ $LATMAX -lt 0 ]];then
latname2=$((LATMAX*-1))S
elif [[ $LATMAX -eq 0 ]];then
latname2=$LATMAX
else 
[[ $LATMAX -gt 0 ]]
latname2=${LATMAX}N
fi



if [[ $LONMIN -lt 0 ]]; then
lonname1=$((LONMIN*-1))W
elif [[ $LONMIN -eq 0 ]];then
lonname1=$LONMIN
else [[ $LONMIN -gt 0 ]]
lonname1=${LONMIN}E
fi


if [[ $LONMAX -lt 0 ]];then
lonname2=$((LONMAX*-1))W
elif [[ $LONMAX -eq 0 ]];then
lonname2=$LONMAX
else
[[ $LONMAX -gt 0 ]]
lonname2=${LONMAX}E
fi

if [[ $ifglobal -eq 1 ]]; then 
suffix=global
para=""
else
suffix=${lonname1}-${lonname2}_${latname1}-${latname2}
para="-sellonlatbox,$LONMIN,$LONMAX,$LATMIN,$LATMAX"
fi


suffix=40N55N_1-2km
suffix=ORCA1_30N40N_1-2km


	### Actual Computation ###

cd ${WORKDIR}; rm -rf * 

  ln -sf $CON_FILES/mask.nc .
  ln -sf $CON_FILES/mesh_hgr.nc .
  ln -sf $CON_FILES/mesh_zgr.nc .
  ln -sf $CON_FILES/new_maskglo.nc .

case ${DATA} in 
model)
##########################
for mem in  ${MEMBER_LST[@]}; do
  echo "******************** Start $mem **********************"
    output=moc_${EXPID}_${SDATE}_${mem}_${suffix}.nc
    filein=moc_${EXPID}_${SDATE}_${mem}.nc

    cp ${DATADIR}/${filein} moc.nc 
    ncrename -d y,lat -v nav_lat,lat moc.nc
   # ncwa -O -a x moc.nc moc.nc    

   ncks -O -v zomsfatl,time moc.nc tmp.nc; rm -f moc.nc
   ncdump tmp.nc > tmp.cdl
   sed -e "s/lat(lat, x)/lat(lat)/g" tmp.cdl > tmp2.cdl
   sed -e "s/zomsfatl(time_counter, depthw, lat, x)/zomsfatl(time_counter, depthw, lat)/g" tmp2.cdl > tmp.cdl
   ncgen -o tmp.nc tmp.cdl


    ncks -d lat,${LATMIN},${LATMAX} -d depthw,${DEPMIN},${DEPMAX} tmp.nc area_moc.nc
    cdo vertmean area_moc.nc area_ave_moc.nc; rm area_moc.nc
    ncap -O -s "coslat[lat]=cos(lat[lat]*3.141592657/180.0)" area_ave_moc.nc area_ave_moc2.nc
    ncwa -w coslat -a lat area_ave_moc2.nc area_ave_moc3.nc
    ncks -O -v zomsfatl,time area_ave_moc3.nc area_ave_moc3.nc
    rm area_ave_moc.nc area_ave_moc2.nc; 
    chmod 770 area_ave_moc3.nc
 #   mv area_ave_moc3.nc member_moc_${mem}.nc
    mv area_ave_moc3.nc ${SAVEDIR}/${output} 

	 

    echo "******************** END $mem  *********************"
  done  #loop for memeber 
  
#  ncecat member*.nc ${output}; rm member*.nc
#  ncrename -d record,ensemble ${output}
#  ncpdq -O -h -a time,ensemble ${output} ${output}; chmod 770 ${output}
#  mv ${output} ${SAVEDIR}

;;

obs)   # case conditions for model or observation


DATADIR=/cfunas/diagnostics/postprocessed/moc/nemovar
SAVEDIR=/cfunas/diagnostics/postprocessed/moc/nemovar
output=moc_${suffix}.nc
for mem in ${MEMBER_LST_OBS[@]}; do # loop for mems
 echo "******************** $mem *********************"

    filein=moc_${mem}.nc

    cp ${DATADIR}/${filein} moc.nc
    ncrename -d y,lat -v nav_lat,lat moc.nc
   # ncwa -O -a x moc.nc moc.nc    

   ncks -O -v zomsfatl,time moc.nc tmp.nc
   ncdump tmp.nc > tmp.cdl
   sed -e "s/lat(lat, x)/lat(lat)/g" tmp.cdl > tmp2.cdl
   sed -e "s/zomsfatl(time_counter, depthw, lat, x)/zomsfatl(time_counter, depthw, lat)/g" tmp2.cdl > tmp.cdl
   ncgen -o tmp.nc tmp.cdl


    ncks -d lat,${LATMIN},${LATMAX} -d depthw,${DEPMIN},${DEPMAX} tmp.nc area_moc.nc
    cdo vertmean area_moc.nc area_ave_moc.nc; rm area_moc.nc
    ncap -O -s "coslat[lat]=cos(lat[lat]*3.141592657/180.0)" area_ave_moc.nc area_ave_moc2.nc
    ncwa -w coslat -a lat area_ave_moc2.nc area_ave_moc3.nc
    ncks -O -v zomsfatl,time area_ave_moc3.nc area_ave_moc3.nc
    rm area_ave_moc.nc area_ave_moc2.nc;
    chmod 770 area_ave_moc3.nc
    ncwa -h -O -a x area_ave_moc3.nc area_ave_moc3.nc
    mv area_ave_moc3.nc ${SAVEDIR}/moc_${mem}_${suffix}.nc

done # loop for mems


function combine_mem(){
  ncecat member*.nc ${output}; rm member*.nc
  ncrename -d record,ensemble ${output}
  ncpdq -O -h -a time,ensemble ${output} ${output}; chmod 770 ${output}
  mv ${output} ${SAVEDIR}
}
;;


esac

rm -r ${WORKDIR}

